<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Returns an array with all coupon codes attached to the given affiliate.
 *
 * @param int $affiliate_id
 * 
 * @return array
 * 
 */
function slicewp_get_affiliate_coupons( $affiliate_id ) {

    $coupons = array();

    /**
     * Filter to add affiliate coupons.
     * Each integration should use this hook to append coupons.
     * 
     * @param array $coupons
     * @param int   $affiliate_id
     * 
     */
    $coupons = apply_filters( 'slicewp_get_affiliate_coupons', $coupons, $affiliate_id );

    return $coupons;

}


/**
 * Adds a new "Coupons" tab in the affiliate account.
 *
 * @param array $tabs
 *
 * @return array
 *
 */
function slicewp_affiliate_account_tabs_coupons( $tabs ) {

	// Get current affiliate.
	$affiliate = slicewp_get_affiliate_by_user_id( get_current_user_id() );

	// Get affiliate coupons.
	$coupons = slicewp_get_affiliate_coupons( $affiliate->get( 'id' ) );

	if ( empty( $coupons ) ) {
		return $tabs;
	}

	$tabs = array_merge( 
		array_slice( $tabs, 0, array_search( 'creatives', array_keys( $tabs ) ) ),
		array( 
			'coupons' => array(
				'label' => __( 'Coupons', 'slicewp' ),
				'icon'  => slicewp_get_svg( 'outline-tag' )
			)),
		array_slice( $tabs, array_search( 'creatives', array_keys( $tabs ) ), count( $tabs ) )
	);

	return $tabs;

}
add_filter( 'slicewp_affiliate_account_tabs', 'slicewp_affiliate_account_tabs_coupons' );


/**
 * Outputs the affiliate coupon codes in the affiliate account page.
 *
 */
function slicewp_affiliate_account_tab_content_coupons( $slug, $name, $templates, $args ) {

	if ( 'affiliate-area/affiliate-account-tab-coupons' != $slug ) {
		return;
	}

	// Get affiliate coupons.
	$coupons = slicewp_get_affiliate_coupons( absint( $args['affiliate_id'] ) );

	if ( empty( $coupons ) ) {
		return;
	}

	?>

		<p class="slicewp-tab-description"><?php echo __( 'The following coupons have been linked to your account. You will receive a commission for each purchase made using these coupons.', 'slicewp' ); ?></p>

		<table class="slicewp-list-table">

			<thead>
				<tr>
					<th class="slicewp-column-coupon_code"><?php echo __( 'Coupon Code', 'slicewp' ); ?></th>
					<th class="slicewp-column-amount"><?php echo __( 'Amount', 'slicewp' ); ?></th>
				<tr>
			</thead>
			
			<tbody>
				<?php foreach ( $coupons as $coupon ): ?>
					<tr>
						<td class="slicewp-column-coupon_code"><?php echo wp_kses_post( $coupon['code'] ); ?></td>
						<td class="slicewp-column-amount"><?php echo wp_kses_post( $coupon['amount'] ); ?></td>
					</tr>
				<?php endforeach; ?>
			</tbody>

		</table>

	<?php

}
add_action( 'slicewp_get_template_part', 'slicewp_affiliate_account_tab_content_coupons', 10, 4 );