<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Include the affiliate field in Easy Digital Downloads discount pages
add_action( 'edd_add_discount_form_bottom', 'slicewp_add_affiliate_coupon_edd' );
add_action( 'edd_edit_discount_form_bottom', 'slicewp_add_affiliate_coupon_edd' );

// Save the affiliate id in the discount meta
add_action( 'edd_post_insert_discount', 'slicewp_save_affiliate_coupon_edd', 10, 2 );
add_action( 'edd_post_update_discount', 'slicewp_save_affiliate_coupon_edd', 10, 2 );

// Save the affiliate id associated to the discount used in payment
add_filter( 'slicewp_referrer_affiliate_id_edd', 'slicewp_get_coupon_affiliate_id_edd', 10, 2 );


/**
 * Show the affiliate field in Easy Digital Downloads discount page
 * 
 * @param int $discount_id
 *
 */
function slicewp_add_affiliate_coupon_edd( $discount_id = 0 ) {

    $affiliate_id = get_post_meta( $discount_id, 'slicewp_affiliate_id', true );
    
    if ( ! empty ( $affiliate_id ) ) {

        $affiliate    = slicewp_get_affiliate( $affiliate_id );
        $affiliate_id = ( ! is_null( $affiliate ) ? $affiliate_id : 0 );

        $user            = get_userdata( ( ! is_null( $affiliate ) ? $affiliate->get( 'user_id' ) : 0 ) );
        $user_first_name = ( ! empty( $user ) ? $user->first_name : '' );
        $user_last_name  = ( ! empty( $user ) ? $user->last_name : '' );
        $user_email      = ( ! empty( $user ) ? $user->user_email : '' );

    }
    
?>

    <table class="form-table">
		<tbody>
            <tr>
                <th scope="row" valign="top">
					<label for="slicewp-affiliate"><?php echo __( 'Affiliate Name', 'slicewp' ); ?></label>
				</th>
				<td>
                    <input id="slicewp-affiliate" class="slicewp-field-users-autocomplete" data-affiliates="include" data-return-value="affiliate_id" autocomplete="off" name="user_search" type="text" value="<?php echo ( ! empty( $_POST['user_search'] ) ? esc_attr( $_POST['user_search'] ) : ( ! empty( $affiliate_id ) ? ( $user_first_name . ' ' . $user_last_name . ' (' . $user_email . ')' ) : '' ) ); ?>" />
                    <input type="hidden" name="slicewp_affiliate_id" value="<?php echo ( ! empty( $_POST['slicewp_affiliate_id'] ) ? esc_attr( $_POST['slicewp_affiliate_id'] ) : ( ! empty( $affiliate_id ) ? $affiliate_id : '' ) ); ?>" />
                    <?php wp_nonce_field( 'slicewp_user_search', 'slicewp_user_search_token', false ); ?>
					<p class="description"><?php echo __( 'Enter the affiliate name that you want to be associated with this discount.', 'slicewp' ); ?></p>
				</td>
			</tr>
        </tbody>
    </table>

<?php

}


/**
 * Saves the affiliate id in the discount post meta.
 * 
 * @param array $discount
 * @param int   $discount_id
 *
 */
function slicewp_save_affiliate_coupon_edd( $discount, $discount_id = 0 ) {

    if ( empty( $_POST['edd-action'] ) ) {
        return;
    }

    if ( ! in_array( $_POST['edd-action'], array( 'add_discount', 'edit_discount' ) ) ) {
        return;
    }

    if ( ! isset( $_POST['slicewp_affiliate_id'] ) ) {
        return;
    }

    // Check if the affiliate was deleted from the form and remove it from discount
    if ( empty( $_POST['slicewp_affiliate_id'] ) ) {

        delete_post_meta( $discount_id, 'slicewp_affiliate_id' );
        return;

    }

    // Save the affiliate id in the discount
    update_post_meta( $discount_id, 'slicewp_affiliate_id', absint( $_POST['slicewp_affiliate_id'] ) );

}


/**
 * Saves the affiliate id associated to the Discount used in payment
 *
 * @param int $affiliate_id 
 * @param int $payment_id
 * 
 * @return int
 * 
 */
function slicewp_get_coupon_affiliate_id_edd( $affiliate_id, $payment_id ) {

    // Get the payment data
    $payment_data = edd_get_payment_meta( $payment_id );

    // Verify if any discounts were used in payment
    if ( empty( $payment_data['user_info']['discount'] ) || $payment_data['user_info']['discount'] == 'none' ) {
        return $affiliate_id;
    }

    // Get the discounts used in payment
    $discounts = array_map( 'trim', explode( ',', $payment_data['user_info']['discount'] ) );

    if ( empty( $discounts ) ) {
        return $affiliate_id;
    }

    // Parse all the discounts used in payment
    foreach( $discounts as $discount_code ) {

        // Save the discount id
        $discount_id = edd_get_discount_id_by_code( $discount_code );
        
        // Get the affiliate id associated with the discount
        $discount_affiliate_id = get_post_meta( $discount_id, 'slicewp_affiliate_id', true );

        if ( ! empty( $discount_affiliate_id ) ) {
            return absint( $discount_affiliate_id );
        }

    }

    // The discounts are not associated to any affiliate
    return $affiliate_id;

}