<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

// Include the affiliate field in Paid Member Subscription discount pages.
add_action( 'pms_view_meta_box_discount_codes_bottom', 'slicewp_add_affiliate_coupon_pms' );

// Save the affiliate id in the discount meta.
add_action( 'pms_save_meta_box_pms-discount-codes', 'slicewp_save_affiliate_coupon_pms' );

// Save the affiliate id associated to the discount used in payment.
add_filter( 'slicewp_referrer_affiliate_id_pms', 'slicewp_get_coupon_affiliate_id_pms', 10, 2 );


/**
 * Show the affiliate field in Paid Member Subscriptions discount page.
 * 
 * @param int $discount_id
 *
 */
function slicewp_add_affiliate_coupon_pms( $discount_id = 0 ) {

    $affiliate_id = get_post_meta( $discount_id, 'slicewp_affiliate_id', true );
    
    if ( ! empty ( $affiliate_id ) ) {

        $affiliate    = slicewp_get_affiliate( $affiliate_id );
        $affiliate_id = ( ! is_null( $affiliate ) ? $affiliate_id : 0 );

        $user            = get_userdata( ( ! is_null( $affiliate ) ? $affiliate->get( 'user_id' ) : 0 ) );
        $user_first_name = ( ! empty( $user ) ? $user->first_name : '' );
        $user_last_name  = ( ! empty( $user ) ? $user->last_name : '' );
        $user_email      = ( ! empty( $user ) ? $user->user_email : '' );

    }

    ?>

        <div class="pms-meta-box-field-wrapper cozmoslabs-form-field-wrapper">

            <label for="pms-discount-code" class="pms-meta-box-field-label cozmoslabs-form-field-label"><?php echo __( 'Affiliate Name', 'slicewp' ); ?></label>

            <input id="slicewp-affiliate" class="slicewp-field-users-autocomplete" data-affiliates="include" data-return-value="affiliate_id" autocomplete="off" name="user_search" type="text" value="<?php echo ( ! empty( $_POST['user_search'] ) ? esc_attr( $_POST['user_search'] ) : ( ! empty( $affiliate_id ) ? ( $user_first_name . ' ' . $user_last_name . ' (' . $user_email . ')' ) : '' ) ); ?>" />
            <input type="hidden" name="slicewp_affiliate_id" value="<?php echo ( ! empty( $_POST['slicewp_affiliate_id'] ) ? esc_attr( $_POST['slicewp_affiliate_id'] ) : ( ! empty( $affiliate_id ) ? $affiliate_id : '' ) ); ?>" />
            <?php wp_nonce_field( 'slicewp_user_search', 'slicewp_user_search_token', false ); ?>

            <p class="cozmoslabs-description cozmoslabs-description-align-right"><?php echo __( 'Enter the affiliate name that you want to be associated with this discount.', 'slicewp' ); ?></p>

        </div>

    <?php

}


/**
 * Saves the affiliate id in the discount post meta
 * 
 * @param array $discount
 * @param int   $discount_id
 *
 */
function slicewp_save_affiliate_coupon_pms( $discount_id = 0 ) {

    // Check if the affiliate was deleted from the form and remove it from discount
    if ( empty( $_POST['slicewp_affiliate_id'] ) ) {

        delete_post_meta( $discount_id, 'slicewp_affiliate_id' );
        return;

    }

    // Save the affiliate id in the discount
    update_post_meta( $discount_id, 'slicewp_affiliate_id', absint( $_POST['slicewp_affiliate_id'] ) );

}


/**
 * Saves the affiliate id associated to the Discount used in payment
 *
 * @param int $affiliate_id 
 * @param int $payment_id
 * 
 * @return int
 * 
 */
function slicewp_get_coupon_affiliate_id_pms( $affiliate_id, $payment_id ) {

    // Get the payment data
    $payment_data = pms_get_payment( $payment_id );

    // Verify if any discounts were used in payment
    if ( empty( $payment_data->discount_code ) ) {
        return $affiliate_id;
    }

    // Get the discount
    $discount = pms_in_get_discount_by_code( $payment_data->discount_code );

    // Get the affiliate id associated with the discount
    $discount_affiliate_id = get_post_meta( $discount->id, 'slicewp_affiliate_id', true );

    if ( ! empty( $discount_affiliate_id ) ) {
        return absint( $discount_affiliate_id );
    }

    // The discount is not associated to any affiliate
    return $affiliate_id;

}