<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * List table class outputter for Landing_Pages
 *
 */
Class SliceWP_WP_List_Table_Landing_Pages extends SliceWP_WP_List_Table {

	/**
	 * The number of landing pages that should appear in the table
	 *
	 * @access private
	 * @var int
	 *
	 */
	private $items_per_page;

	/**
	 * The data of the table
	 *
	 * @access public
	 * @var array
	 *
	 */
	public $data = array();


	/**
	 * Constructor
	 *
	 */
	public function __construct() {

		parent::__construct( array(
			'plural' 	=> 'slicewp_landing_pages',
			'singular' 	=> 'slicewp_landing_page',
			'ajax' 		=> false
		));

		$this->items_per_page = 10;
		$this->paged 		  = ( ! empty( $_GET['paged'] ) ? (int)$_GET['paged'] : 1 );

		$this->set_pagination_args( array(
            'total_items' => slicewp_alp_get_affiliate_landing_pages_table_data( array( 's' => ( ! empty( $_GET['s'] ) ? $_GET['s'] : '' ) ), true ),
            'per_page'    => $this->items_per_page
        ));

		// Get and set table data
		$this->set_table_data();
		
		// Add column headers and table items
		$this->_column_headers = array( $this->get_columns(), array(), $this->get_sortable_columns() );
		$this->items 		   = $this->data;

	}


	/**
	 * Returns all the columns for the table
	 *
	 */
	public function get_columns() {

		$columns = array(
			'id'                    => __( 'ID', 'slicewp' ),
			'title'                 => __( 'Page Title', 'slicewp' ),
			'affiliate'             => __( 'Affiliate Name', 'slicewp' ),
			'visits'                => __( 'Visits', 'slicewp' ),
			'conversions'           => __( 'Conversions', 'slicewp' ),
			'actions'               => ''
		);

		/**
		 * Filter the columns of the landing pages table
		 *
		 * @param array $columns
		 *
		 */
		return apply_filters( 'slicewp_list_table_landing_pages_columns', $columns );

	}


	/**
	 * Returns all the sortable columns for the table
	 *
	 */
	public function get_sortable_columns() {

		$columns = array(
			'id'          => array( 'id', false ),
			'visits'      => array( 'visits', false ),
			'conversions' => array( 'conversions', false )
		);

		/**
		 * Filter the sortable columns of the landing pages table
		 *
		 * @param array $columns
		 *
		 */
		return apply_filters( 'slicewp_list_table_landing_pages_sortable_columns', $columns );

	}


	/**
	 * Gets the affiliates data and sets it
	 *
	 */
	private function set_table_data() {

		// Get the landing pages
		$args = array(
			'number'  => $this->items_per_page,
			'offset'  => ( $this->get_pagenum() - 1 ) * $this->items_per_page,
			's'       => ( ! empty( $_GET['s'] ) ? sanitize_text_field( $_GET['s'] ) : '' ),
			'orderby' => ( ! empty( $_GET['orderby'] ) ? sanitize_text_field( $_GET['orderby'] ) : 'id' ),
			'order'	  => ( ! empty( $_GET['order'] ) ? sanitize_text_field( $_GET['order'] ) : 'desc' )
		);

		$landing_pages = slicewp_alp_get_affiliate_landing_pages_table_data( $args );

		if ( empty( $landing_pages ) )
			return;

		foreach ( $landing_pages as $landing_page ) {

			$row_data = $landing_page;

			/**
			 * Filter the affiliate row data
			 *
			 * @param array 		 $row_data
			 * @param slicewp_Affiliate $affiliate
			 *
			 */
			$row_data = apply_filters( 'slicewp_list_table_landing_pages_row_data', $row_data, $landing_page );

			$this->data[] = $row_data;

		}

	}


	/**
	 * Returns the HTML that will be displayed in each columns
	 *
	 * @param array $item 			- data for the current row
	 * @param string $column_name 	- name of the current column
	 *
	 * @return string
	 *
	 */
	public function column_default( $item, $column_name ) {

		return isset( $item[ $column_name ] ) ? $item[ $column_name ] : '-';

	}


	/**
	 * Returns the HTML that will be displayed in the "title" column
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_title( $item ) {

		if ( is_null( $item['title'] ) ) {

			$output = __( '(unnamed page)', 'slicewp' );

		} else {

			$output  = '<span>';
			$output .= '	<a href="' . esc_url( $item['permalink'] ) . '" target="_blank">' . $item['title'] . '</a>';
			$output .= '	<span class="slicewp-tooltip-wrapper">';
			$output .= '		<span class="dashicons dashicons-admin-links"></span>';
			$output .= '		<span class="slicewp-tooltip-message">';
			$output .= '			<span>' . __( 'Copy the affiliate landing page link', 'slicewp' ) . '</span>';
			$output .= '			<span style="display: none;">' . __( 'Copied!', 'slicewp' ) . '</span>';
			$output .= '			<span class="slicewp-tooltip-arrow"></span>';
			$output .= '		</span>';
			$output .= '	</span>';
			$output .= '</span>';
	
		}

		return $output;

	}


	/**
	 * Returns the HTML that will be displayed in the "name" column
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_affiliate( $item ) {

		$affiliate_name = slicewp_get_affiliate_name( $item['affiliate_id'] );

		if ( is_null( $affiliate_name ) ) {

			$output = __( '(inexistent affiliate)', 'slicewp' );

		} else {

			$output = '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-affiliates', 'subpage' => 'edit-affiliate', 'affiliate_id' => $item['affiliate_id'] ) , admin_url( 'admin.php' ) ) ) . '">' . $affiliate_name . '</a>';

		}

		return $output;

	}


	/**
	 * Returns the HTML that will be displayed in the "visits" column
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_visits( $item ) {

		$output = '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-visits', 'landing_url' => esc_url( $item['permalink'] ), 'affiliate_id' => $item['affiliate_id'] ) , admin_url( 'admin.php' ) ) ) . '">' . $item['visits'] . '</a>';

		return $output;

	}


	/**
	 * Returns the HTML that will be displayed in the "conversions" column
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_conversions( $item ) {

		// Get the visits
		$args = array(
			'affiliate_id' => $item['affiliate_id'],
			'landing_url'  => $item['permalink'],
			'converted'    => true
		);

		$visits = slicewp_get_visits( $args );

		// Get visit ids
		$visit_ids = array();

		foreach ( $visits as $visit )
			$visit_ids[] = $visit->get( 'id' );

		$output = '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-commissions', 'affiliate_id' => $item['affiliate_id'], 'visit_id' => ( ! empty( $visit_ids ) ? implode( ',', $visit_ids ) : '' ) ) , admin_url( 'admin.php' ) ) ) . '">' . $item['conversions'] . '</a>';

		return $output;

	}


	/**
	 * Returns the HTML that will be displayed in the "actions" column
	 *
	 * @param array $item - data for the current row
	 *
	 * @return string
	 *
	 */
	public function column_actions( $item ) {

		/**
		 * Set actions
		 *
		 */

		$output  = '<div class="row-actions">';
		$output .= '<a href="' . esc_url( add_query_arg( array( 'post' => $item['id'], 'action' => 'edit' ) , admin_url( 'post.php' ) ) ) . '" class="slicewp-button-secondary">' . __( 'Edit', 'slicewp' ) . '</a>';
		$output .= '</div>';

		return $output;

	}


	/**
	 * HTML display when there are no items in the table
	 *
	 */
	public function no_items() {

		echo __( 'No landing pages found.', 'slicewp' );

	}

}