<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Affiliate Landing Pages" add-on class.
 * 
 */
class SliceWP_Add_On_Affiliate_Landing_Pages extends SliceWP_Add_On {

	/**
	 * Construct.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'affiliate_landing_pages';

		// Name.
		$this->name = 'Affiliate Landing Pages';

		// Description.
		$this->description = 'Create dedicated landing pages for your affiliates, by linking posts and pages to affiliates.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-affiliate-landing-pages.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/affiliate-landing-pages/';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';
		
		parent::__construct();

		if ( $this->is_active() ) {

			// Frontend scripts.
			add_action( 'slicewp_enqueue_front_end_scripts', array( $this, 'register_front_end_scripts' ) );
			add_action( 'slicewp_affiliate_account_tab_affiliate_links_top', array( $this, 'enqueue_front_end_scripts' ) );

		}

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'base/functions.php',
			'users/functions.php',
			'admin/functions.php',
			'admin/functions-actions-ajax.php'
		);

		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


	/**
	 * Registers and enqueues the scripts and style for the user area.
	 *
	 */
	public function register_front_end_scripts( $hook ) {

		// Plugin script.
		wp_register_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script', $this->get_dir_url() . 'assets/js/script-front-end.js', array(), $this->get_parent_plugin_version() );

	}


	/**
	 * Enqueues the scripts for the user area.
	 * 
	 */
	public function enqueue_front_end_scripts() {

		// Enqueue the front-end script.
		wp_enqueue_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script' );

	}

}


/**
 * Registers the Affiliate Landing Pages add-on.
 * 
 * @param array
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_affiliate_landing_pages( $add_ons ) {

	$add_ons['affiliate_landing_pages'] = 'SliceWP_Add_On_Affiliate_Landing_Pages';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_affiliate_landing_pages', 150 );