<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Affiliate Leaderboard
add_shortcode( 'slicewp_affiliate_leaderboard', 'slicewp_alb_shortcode_affiliate_leaderboard' );


/**
 * Generates the shortcode for the affiliate leaderboard.
 *
 */
function slicewp_alb_shortcode_affiliate_leaderboard( $atts ) {

	if ( is_admin() ) {
		return;
	}

	if ( defined( 'REST_REQUEST' ) && REST_REQUEST ) {
		return;
	}

	// Prepare the default attributes
	$atts = shortcode_atts( array(
		'id'		=> '',
		'number'	=> 10,
		'columns'	=> array( 'commissions_amount' ),
		'orderby'	=> '',
		'date'		=> 'all_time',
		'date_min'	=> '',
		'date_max'	=> '',
	), $atts );

	// Get the leaderboard data sets
	$leaderboard_data_sets = slicewp_alb_get_registered_leaderboard_data_sets();

	// Register the affiliate leaderboard date ranges
	$leaderboard_dates = slicewp_alb_get_registered_leaderboard_date_intervals();

	// Check the 'columns' attribute
	if ( ! empty( $atts['columns'] ) && ! is_array( $atts['columns'] ) ) {

		$atts['columns'] = array_map( 'trim', explode( ',', $atts['columns'] ) );
		$atts['columns'] = array_intersect( $atts['columns'], array_keys( $leaderboard_data_sets ) );

	}

	if ( empty( $atts['columns'] ) ) {
		$atts['columns'] = array( array_key_first( $leaderboard_data_sets ) );
	}

	// Check the 'orderby' attribute
	if ( empty( $atts['orderby'] ) || ! in_array( $atts['orderby'], $atts['columns'] ) ) {
		$atts['orderby'] = $atts['columns'][array_key_first($atts['columns'])];
	}

	// Check the 'date' attribute
	if ( empty( $atts['date'] ) || ! array_key_exists( $atts['date'], $leaderboard_dates ) ) {
		$atts['date'] = array_key_first( $leaderboard_dates );
	}

	// Check if we have 'range' for date attribute
	if ( 'range' == $atts['date'] && ! empty ( $atts['date_min'] ) ) {

		$date_min = new DateTime( $atts['date_min'] );
		$date_max = ( ! empty( $atts['date_max'] ) ? ( new DateTime( $atts['date_max'] ) )->setTime( 23, 59, 59 ) : new DateTime( 'now', wp_timezone() ) );

		$atts['date_min'] = $date_min->format( 'Y-m-d H:i:s' );
		$atts['date_max'] = $date_max->format( 'Y-m-d H:i:s' );

	} else {

		$atts['date_min'] = $leaderboard_dates[$atts['date']]['date_min'];
		$atts['date_max'] = $leaderboard_dates[$atts['date']]['date_max'];

	}

	// Get the affiliates leaderboard data
	$leaderboard_data = slicewp_alb_get_affiliate_leaderboard_data( $atts );

	// Prepare the template args
	array_unshift( $atts['columns'], 'affiliate_name' );

	foreach ( $atts['columns'] as $data_set ) {

		$data_sets[$data_set] = $leaderboard_data_sets[$data_set]['name'];

	}

	$args = array(
		'data_sets'	=> $data_sets,
		'data'		=> $leaderboard_data
	);

	ob_start();

	slicewp_get_template_part( 'affiliate-leaderboard/affiliate-leaderboard', null, $args );

	$return = ob_get_contents();

	ob_end_clean();

	// Show the Affiliate Leaderboard
	return $return;

}