jQuery( function($) {

	/**
	 * Connect to ConvertKit
	 *
	 */
	$(document).on( 'click', '#slicewp-connect-convertkit', function(e){

		e.preventDefault();

		$button = $(this);
		
		// Exit if button is disabled
		if ( $button.hasClass( 'slicewp-disabled' ) ) {
			return false;
		}

		// Exit if the API key field is empty
		if ( $button.siblings( 'input[type="password"]' ).val() == '' ) {
			$button.siblings( 'input[type="password"]' ).focus();
			return false;
		}

		// Disable API key field
		$button.siblings( 'input[type="password"]' ).attr( 'disabled', 'true' );

		// Disable the button
		$button.addClass( 'slicewp-disabled' );

		// Show spinner
		$button.addClass( 'slicewp-spinner-active' );

		// Add a spinner over API settings
		if ( $( '#slicewp-convertkit-integration-fields' ).children().length > 0 ) {
			$( '#slicewp-convertkit-integration-fields' ).prepend( '<div class="slicewp-overlay"><div class="spinner"></div></div>' );
		}

		// Prepare AJAX call data
		var data = {
			action			: 'slicewp_convertkit_integration_action_ajax_connect',
			slicewp_token	: $( '#slicewp_token' ).val(),
			api_key			: $( '#slicewp-convertkit-api-key' ).val(),
			audience_id		: $( '#slicewp-convertkit-select-audience' ).val()
		}

		// Make AJAX call
		$.post( ajaxurl, data, function( response ) {

			// Remove API notice
			$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).remove();

			// Re-enable API key field
			$button.siblings( 'input[type="password"]' ).removeAttr( 'disabled' );

			// Re-enable the button
			$button.removeClass( 'slicewp-disabled' );

			// Hide spinner
			$button.removeClass( 'slicewp-spinner-active' );

			if ( response.success == true ) {

				// Remove API fields
				$( '#slicewp-convertkit-integration-fields' ).remove();

				// Output the API message
				$button.closest( '.slicewp-field-wrapper' ).append( '<div class="slicewp-field-notice slicewp-field-notice-success">' + response.data.message + '</div>' );
				$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).fadeIn();

				// Output the API fields
				$fields = $( response.data.integration_fields );
				
				// Check if we have select fields
				if ( $fields.find( 'select' ) ) {

					$this = $fields.find( 'select' );

					$this.each( function() {

						$(this).select2({
							minimumResultsForSearch : 20,
							placeholder : $(this).attr( 'placeholder' )
						}).on('select2:open', function() {
							var container = $('.select2-container').last();
							container.addClass('slicewp-select2-container');
						})

					})

				}

				// Show the fields
				$fields.hide();
				$fields.insertAfter( '#slicewp-field-wrapper-convertkit-api-key' );
				$fields.fadeIn();

				// Trigger a change to add the required property on tags input if needed
				$( '#slicewp-convertkit-enabled' ).trigger('change');

			} else {

				// Output the API message
				$button.closest( '.slicewp-field-wrapper' ).append( '<div class="slicewp-field-notice slicewp-field-notice-error">' + response.data.message + '</div>' );
				$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice' ).fadeIn();

				// Remove spinner from API settings
				if ( $( '#slicewp-convertkit-integration-fields' ).children().length > 0 ) {
					$( '#slicewp-convertkit-integration-fields' ).children( '.slicewp-overlay' ).remove();
				}

			}

		});

	});


	/**
	 * Change the select2 properties for multiple select
	 *
	 */
	$('.slicewp-select2-convertkit-tags').each( function() {

		var $this = $(this);

		$this.select2({
			dropdownPosition : 'below',
			placeholder : $this.attr( 'placeholder' )
		}).on('select2:open', function() {
			var container = $('.select2-container').last();
			container.addClass('slicewp-select2-container');
		});

	});


	/**
	 * Add the required property for tags when ConvertKit is enabled
	 *
	 */
	$(document).on( 'change', '#slicewp-convertkit-enabled', function() {

		if ( $(this).is( ':checked' ) ) {

			$( '#slicewp-convertkit-tags-select' ).prop( 'required', true );

		} else {
			
			$( '#slicewp-convertkit-tags-select' ).prop( 'required', false );

		}

	});

    $( '#slicewp-convertkit-enabled' ).trigger('change');

});