<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Adds the ConvertKit mailing list agreement checkbox on the registration form.
 *
 * @param array $fields
 *
 */
function slicewp_register_mailing_list_agreement_field_convertkit( $form ) {

	if ( 'affiliate_registration' != $form ) {
		return;
	}

	// Check if the mailing list agreement has to be shown on the affiliate registration form
	$enabled = slicewp_get_setting( 'convertkit_enabled' );
	$api_key = slicewp_get_setting( 'convertkit_api_key' );
	$tags 	 = slicewp_get_setting( 'convertkit_tags' );

	if ( ! empty( $enabled ) && ! empty( $api_key ) && ! empty( $tags ) ) {

	?>

		<!-- Affiliate Mailing List Agreement -->
		<div class="slicewp-field-wrapper slicewp-field-wrapper-convertkit-mailing-list-agreement">

			<div class="slicewp-field-label-wrapper">

				<input id="slicewp-convertkit-mailing-list-agreement" name="convertkit_mailing_list_agreement" type="checkbox" value="1" <?php checked( ! empty( $_POST['convertkit_mailing_list_agreement'] ), '1' ) ?>/>
				<label for="slicewp-convertkit-mailing-list-agreement"><?php echo ( ! empty( slicewp_get_setting( 'convertkit_mailing_list_agreement_label' ) ) ? slicewp_get_setting( 'convertkit_mailing_list_agreement_label' ) :  __( 'Join our mailing list.', 'slicewp' ) ); ?></label>

			</div>

		</div><!-- / Affiliate Mailing List Agreement -->

	<?php

	}

}
add_action( 'slicewp_form_fields', 'slicewp_register_mailing_list_agreement_field_convertkit', 20 );


/**
 * Subscribe the affiliate to the mailing list.
 *
 * @param int $affiliate_id
 *
 */
function slicewp_subscribe_affiliate_convertkit( $affiliate_id ) {

	// Check for affiliate id
	if ( empty( $affiliate_id ) ) {
		return;
	}

	if ( doing_action( 'slicewp_register_affiliate' ) ) {

		// Check if the user wants to join the email list
		if ( empty( $_POST['convertkit_mailing_list_agreement'] ) ) {
			return;
		}

		// Save the affiliate mailing consent in affiliate meta
		slicewp_update_affiliate_meta( $affiliate_id, 'convertkit_mailing_list_agreement', 1 );

	}

	if ( doing_action( 'slicewp_update_affiliate' ) ) {

		// Check if we are reviewing the affiliate
		if ( 'review_affiliate' != $_POST['slicewp_action'] ) {
			return;
		}

		// Check if the user wants to join the email list
		if ( empty( slicewp_get_affiliate_meta( $affiliate_id, 'convertkit_mailing_list_agreement', true ) ) ) {
			return;
		}

	}

	// Check if the affiliate has 'active' status
	$affiliate = slicewp_get_affiliate( $affiliate_id );
	
	if ( 'active' != $affiliate->get('status') )
		return;

	// Prepare the affiliate data for mailing list
	$user = new WP_User( $affiliate->get('user_id') );

	$subscriber_data = array(
		'email'			=> $user->user_email,
		'first_name'	=> ! empty( $user->first_name ) ? $user->first_name : '',
		'last_name'		=> ! empty( $user->last_name ) ? $user->last_name : '',
	);

	// Subscribe the affiliate to the mailing list
	$initialized = slicewp()->services['convertkit']->init( slicewp_get_setting( 'convertkit_api_key' ) );

	// Check for errors
	if ( ! $initialized ) {

		slicewp_add_log( 'ConvertKit API: init() failed. Error: ' . slicewp()->services['convertkit']->get_last_error() );
		return;

	}

	slicewp()->services['convertkit']->add_subscriber( $subscriber_data );

}
add_action( 'slicewp_register_affiliate', 'slicewp_subscribe_affiliate_convertkit', 30 );
add_action( 'slicewp_update_affiliate', 'slicewp_subscribe_affiliate_convertkit', 30 );