jQuery( function($) {

	/**
	 * Hide "Required Affiliate Fields" options
	 *
	 */
	$('#slicewp-required-field-website').closest('.slicewp-field-wrapper').hide();

	if ( $('#slicewp-required-field-website').closest('.slicewp-field-wrapper').hasClass('slicewp-last') ) {
		$('#slicewp-required-field-website').closest('.slicewp-field-wrapper').removeClass('slicewp-last');
		$('#slicewp-required-field-website').closest('.slicewp-field-wrapper').siblings('.slicewp-field-wrapper').last().addClass('slicewp-last');
	}


	/**
	 * Sortable on affiliate fields
	 *
	 */
	$('#slicewp-affiliate-fields-editor-fields-settings-wrapper').sortable({
		handle: '.slicewp-sort-handle',
		revert: 80,
		placeholder: 'slicewp-sort-placeholder',
		containment: '#wpwrap'
	});


	/**
	 * Sortable on field options
	 *
	 */
	$('.slicewp-field-settings-options').sortable({
		handle: '.slicewp-sort-handle-option',
		revert: 80,
		placeholder: 'slicewp-sort-placeholder',
		containment: '#wpwrap'
	});


	/**
	 * Adds the "slicewp-last" class to the last field wrapper in each fields tab
	 *
	 */
	$('.slicewp-affiliate-fields-field-tab').each( function() {
		$(this).find('.slicewp-field-wrapper').last().addClass('slicewp-last');
	});

	/**
	 * Opens/closes the editor field settings panel
	 *
	 */
	$(document).on( 'click', '.slicewp-affiliate-fields-editor-field-wrapper .slicewp-edit-field, .slicewp-affiliate-fields-editor-field-wrapper .slicewp-affiliate-fields-editor-field-name, .slicewp-affiliate-fields-editor-field-wrapper .slicewp-affiliate-fields-editor-field-type', function(e) {

		e.preventDefault();

		$(this).closest('.slicewp-affiliate-fields-editor-field-wrapper').toggleClass('slicewp-active');
		$(this).closest('.slicewp-affiliate-fields-editor-field-wrapper').find('.slicewp-affiliate-fields-editor-field-body').slideToggle( 200 );

	});


	/**
	 * Handles nav tabs in the field editor panel
	 *
	 */
	$(document).on( 'click', '.slicewp-affiliate-fields-field-nav-tab a', function(e) {

		e.preventDefault();

		var tab = $(this).attr('data-tab');

		// Set the nav tab to active
		$(this).parent().find('a').removeClass('slicewp-active');
		$(this).addClass('slicewp-active').blur();

		// Show the appropiate tab
		$(this).closest('.slicewp-affiliate-fields-editor-field-body').find('.slicewp-affiliate-fields-field-tab' ).hide();
		$(this).closest('.slicewp-affiliate-fields-editor-field-body').find('.slicewp-affiliate-fields-field-tab[data-tab="' + tab + '"]').show();

	});


	/**
	 * Handles the change of the field header label when completing the field label option.
	 *
	 */
	$(document).on( 'keyup', '[id^="slicewp-field-setting-label-"]', function() {

		var name 	  = ( $(this).val() != '' ? $(this).val() : $(this).closest('.slicewp-affiliate-fields-editor-field-wrapper').find('.slicewp-affiliate-fields-editor-field-type').html() );
		var $required = $(this).closest('.slicewp-affiliate-fields-editor-field-wrapper').find('.slicewp-affiliate-fields-editor-field-name span');

		$(this).closest('.slicewp-affiliate-fields-editor-field-wrapper').find('.slicewp-affiliate-fields-editor-field-name').html( name ).append( $required );

	});


	/**
	 * Handles the required asterix for the field name.
	 *
	 */
	$(document).on( 'change', '[id^="slicewp-field-setting-is-required-"]', function() {

		var $name_wrapper = $(this).closest('.slicewp-affiliate-fields-editor-field-wrapper').find('.slicewp-affiliate-fields-editor-field-name');

		// Remove the asterix span
		$name_wrapper.find('span').remove();

		// Add the asterix span back if the required is checked
		if ( $(this).is(':checked') ) {

			$name_wrapper.append('<span>*</span>');

		}

	});


	/**
	 * Remove field functionality
	 *
	 */
	$(document).on( 'click', '.slicewp-affiliate-fields-editor-field-wrapper .slicewp-trash', function(e) {

		e.preventDefault();

		$(this).blur();

		// Bail if field cannot be removed
		if ( $(this).hasClass('slicewp-disabled') ) {
			alert( 'This field is required and cannot be removed.' );
			return false;
		}

		// Confirm removing the field
		var confirmation = confirm( 'Are you sure you want to remove this field?' );
		var $this 		 = $(this);

		if ( confirmation ) {

			$this.closest('.slicewp-affiliate-fields-editor-field-wrapper').fadeOut( 200, 'linear', function() {

				$this.closest('.slicewp-affiliate-fields-editor-field-wrapper').remove();

				// Enable/disable field types that are unique
		    	maybe_disable_select_new_field_options();

			});

		}

	});


	/**
	 * Add new field functionality
	 *
	 */
	$(document).on( 'change', '#slicewp-affiliate-fields-editor-select-new', function() {

		if ( $(this).val() != '' ) {
			$('#slicewp-affiliate-fields-editor-select-add-new').removeClass('slicewp-disabled').attr('disabled', false);
		} else {
			$('#slicewp-affiliate-fields-editor-select-add-new').addClass('slicewp-disabled').attr('disabled', true);
		}

	});

	$(document).on( 'click', '#slicewp-affiliate-fields-editor-select-add-new', function(e) {

		e.preventDefault();

		if ( $(this).hasClass('slicewp-disabled') ) {
			return false;
		}

		if ( $('#slicewp-affiliate-fields-editor-select-new').val() == '' ) {
			return false;
		}

		var $this = $(this);

		// Add animations
		$this.addClass( 'slicewp-disabled' ).attr( 'disabled', true );
		$this.find('.spinner').css( 'display', 'inline-block' );
		$this.find('span').hide();

		$('#slicewp-affiliate-fields-editor-select-new').attr( 'disabled', true );

		// Prepare data
		var data = {
			action 		    : 'slicewp_affiliate_fields_editor_add_new_field',
			field_type	    : $('#slicewp-affiliate-fields-editor-select-new').val(),
			fields_last_key : $('#slicewp-affiliate-fields-editor-fields-last-key').val(),
			slicewp_token   : $('#slicewp_token').val()
		};

		$.post( ajaxurl, data, function( response ) {

			if ( response != 0 ) {

				$('#slicewp-affiliate-fields-editor-fields-settings-wrapper').append( response );

				// Remove animations
				$this.find('.spinner').hide();
				$this.find('span').show();

				$('#slicewp-affiliate-fields-editor-select-new').attr( 'disabled', false ).find('option').attr( 'selected', false ).first().attr( 'selected', true ).trigger('change');

				// Increment last key
				$('#slicewp-affiliate-fields-editor-fields-last-key').val( ( parseInt( $('#slicewp-affiliate-fields-editor-fields-last-key').val() ) + 1 ) );

				// Enable select2 for new field options panel
				$('#slicewp-affiliate-fields-editor-fields-settings-wrapper > div').last().find('.slicewp-select2').select2({
	                minimumResultsForSearch : 20
	            }).on('select2:open', function() {
	                var container = $('.select2-container').last();
	                container.addClass('slicewp-select2-container');
	                container.find('.select2-search__field').attr( 'placeholder', 'Type to search...' );
	            });

		        // Enable sortable for new field options
		        if( $('#slicewp-affiliate-fields-editor-fields-settings-wrapper > div').last().find('.slicewp-field-settings-options').length > 0 ) {

					$('#slicewp-affiliate-fields-editor-fields-settings-wrapper > div').last().find('.slicewp-field-settings-options').sortable({
						handle: '.slicewp-sort-handle-option',
						revert: 80,
						placeholder: 'slicewp-sort-placeholder',
						containment: '#wpwrap'
					});

		        }

		        // Enable/disable field types that are unique
		        maybe_disable_select_new_field_options();

			}

		});

	});


	/**
	 * Checks the existing field types in the form if they are unique or not.
	 * If they are, the "disabled" attribute will be added to the options that are already added as fields.
	 *
	 */
	function maybe_disable_select_new_field_options() {

		var existing_field_types = [];
		var all_field_types 	 = slicewp_affiliate_fields_editor_field_types;

		// Enable all options
		$('#slicewp-affiliate-fields-editor-select-new option').attr( 'disabled', false );

		// Disable all options that are unique
		$('.slicewp-affiliate-fields-editor-field-wrapper').each( function() {

			var field_type = $(this).find('input[type="hidden"]').first().val();

			if( typeof all_field_types[field_type] != 'undefined' && all_field_types[field_type]['form_unique'] ) {
				$('#slicewp-affiliate-fields-editor-select-new option[value="' + field_type + '"]').attr( 'disabled', true );
			}

		});

		// Reinitialize select2
		$('#slicewp-affiliate-fields-editor-select-new').select2('destroy').select2({
            minimumResultsForSearch : Infinity
        }).on('select2:open', function() {
            var container = $('.select2-container').last();
            container.addClass('slicewp-select2-container');
        });

	}


	/**
	 * Unlock field key for editing.
	 *
	 */
	$(document).on( 'click', '.slicewp-field-setting-key-wrapper a', function(e) {

		e.preventDefault();

		var $input = $(this).siblings('input').first();

		$(this).hide();
		$input.removeAttr( 'readonly' ).focus();
		$input[0].setSelectionRange( $input.val().length, $input.val().length );

		$(this).closest('.slicewp-field-wrapper').find( '.slicewp-field-notice-warning' ).fadeIn();

	});


	/**
	 * Add new option for checkboxes, radio and select fields.
	 *
	 */
	$(document).on( 'click', '.slicewp-field-settings-option-add', function(e) {

		e.preventDefault();

		var $options_wrapper = $(this).closest('.slicewp-field-settings-options');
		var $current_option  = $(this).closest('.slicewp-field-settings-option');
		var $new_field 		 = $options_wrapper.siblings('.slicewp-field-settings-option-placeholder').first().clone();
		var $option_key 	 = $options_wrapper.siblings('input[type="hidden"]').first();

		// Set data for the new field
		$new_field.removeClass('slicewp-field-settings-option-placeholder');
		$new_field.find('input').each( function() {
			$(this).attr( 'name', $(this).attr( 'data-name' ).replace( '#option_key', parseInt( $option_key.val() ) ) ).removeAttr( 'data-name' )
		});

		// Append the field
		$current_option.after( $new_field );

		// Increment option key
		$option_key.val( ( parseInt( $option_key.val() ) + 1 ) );

		// Focus the first text input
		$new_field.find('input[type="text"]').first().focus();

		// Show "remove" option link if just one option remains.
		if ( $options_wrapper.children().length > 1 ) {
			$options_wrapper.find('.slicewp-field-settings-option .slicewp-field-settings-option-remove').removeClass('slicewp-disabled');
		}

	});


	/**
	 * Remove option for checkboxes, radio and select fields.
	 *
	 */
	$(document).on( 'click', '.slicewp-field-settings-option-remove', function(e) {

		e.preventDefault();

		if ( $(this).hasClass('slicewp-disabled') ) {
			return false;
		}

		var $options_wrapper = $(this).closest('.slicewp-field-settings-options');

		// Remove option wrapper
		$(this).closest('.slicewp-field-settings-option').remove();

		// Hide "remove" option link if just one option remains
		if ( $options_wrapper.children().length == 1 ) {
			$options_wrapper.find('.slicewp-field-settings-option .slicewp-field-settings-option-remove').addClass('slicewp-disabled');
		}

	});


	/**
	 * Makes sure only one radio is marked as checked for field options.
	 *
	 */
	$(document).on( 'click', '.slicewp-field-settings-options input[type="radio"]', function(e) {

		$(this).closest('.slicewp-field-settings-options').find( 'input[type="radio"]' ).prop( 'checked', false );
		$(this).prop( 'checked', true );

	});


	/**
	 * Make sure users can only add lowercase alphanumerical, underscores and hyphens for field options values.
	 *
	 */
	$(document).on( 'keydown', '.slicewp-field-settings-option-value, .slicewp-field-setting-key-wrapper > input', function(e) {

		var regexp = /^[a-z0-9-_]+$/;

		// Hide errors if the correct key is pressed.
		if ( e.key.length == 1 && e.key.match( /[a-z0-9-_]+$/ ) ) {
			$(this).closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice-key-char-check' ).fadeOut( 1 );
			$(this).closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice-key-empty' ).fadeOut( 1 );
		}

		if ( e.keyCode == 8 || e.keyCode == 9 || e.keyCode == 189 || e.keyCode == 37 || e.keyCode == 39 ) {
			return true;
		}

		if ( String.fromCharCode( e.keyCode ).toLowerCase().match( regexp ) ) {
			return true;
		}

        return false;

	});

	$(document).on( 'keyup', '.slicewp-field-settings-option-value, .slicewp-field-setting-key-wrapper > input', function(e) {

		var target_value = e.target.value;

		var start = e.target.selectionStart;
	    var end   = e.target.selectionEnd;

		var regexp = /[^a-z0-9-_]+$/;

		// Turn the string lower case.
	    e.target.value = e.target.value.toLowerCase();

		// Make sure only alphanumerical, underscores and hyphens are allowed.
		e.target.value = e.target.value.replace( regexp, '' );

		// Make sure the string doesn't start with an underscore or hyphen.
		if ( e.target.value.charAt( 0 ) == '_' || e.target.value.charAt( 0 ) == '-' ) {

			e.target.value = e.target.value.slice( 1 );

			start = 0;
			end   = 0;

		}

	    e.target.setSelectionRange( start, end );

		// Show error notice for unaccepted chars.
		if ( target_value != e.target.value || e.key == ' ' ) {

			$(this).closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice-key-char-check' ).fadeIn();

		}

		// Show error notice for empty key value.
		if ( e.target.value == '' ) {

			$(this).closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice-key-empty' ).fadeIn();

		}

	});


	/**
	 * Parses the given string and returns a slug.
	 *
	 * @param string str
	 *
	 * @return string
	 *
	 */
	function string_to_slug( str ) {

		str = str.replace(/^\s+|\s+$/g, ''); // trim
		str = str.toLowerCase();

		// remove accents, swap ñ for n, etc.
		var from = "àáäâèéëêìíïîòóöôùúüûñçěščřžýúůďťň·/_,:;";
		var to   = "aaaaeeeeiiiioooouuuuncescrzyuudtn______";

		for ( var i=0, l=from.length ; i<l ; i++ ) {
			str = str.replace(new RegExp(from.charAt(i), 'g'), to.charAt(i));
		}

		str = str.replace('.', '_') // replace a dot by a dash 
			.replace(/[^a-z0-9 -]/g, '') // remove invalid chars
			.replace(/\s+/g, '_') // collapse whitespace and replace by a dash
			.replace(/-+/g, '_') // collapse dashes
			.replace( /\//g, '' ); // collapse all forward-slashes

		return str;

	}

});