<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Validates and handles the exporting of the actual file.
 *
 */
function slicewp_admin_action_batch_export_file() {

	// Verify for nonce
	if ( empty( $_REQUEST['slicewp_token'] ) || ! wp_verify_nonce( $_REQUEST['slicewp_token'], 'slicewp_batch_export_file' ) ) {

		wp_die( __( 'Invalid or expired nonce. Please try again.', 'slicewp' ), __( 'Error', 'slicewp' ), array( 'response' => 403 ) );

	}

	// Verify for export type
	if ( empty( $_REQUEST['export_type'] ) ) {

		wp_die( __( 'Export type is missing.', 'slicewp' ), __( 'Error', 'slicewp' ), array( 'response' => 403 ) );

	}

	// Verify for file name
	if ( empty( $_REQUEST['file_name'] ) ) {

		wp_die( __( 'File name is missing.', 'slicewp' ), __( 'Error', 'slicewp' ), array( 'response' => 403 ) );

	}


	// Prepare args to load the processor
	$processor_name = 'export_' . sanitize_text_field( $_REQUEST['export_type'] );

	$args = array(
		'file_name' => sanitize_text_field( $_REQUEST['file_name'] )
	);
	
	// Load processor
	$processor = slicewp()->services['batch_processor_manager']->load_processor( $processor_name, $args );


	// Bail if the processor doesn't exist.
	if ( is_null( $processor ) ) {

		wp_die( __( 'Could not load batch processor to download export file.', 'slicewp' ), __( 'Error', 'slicewp' ), array( 'response' => 403 ) );

	}


	// If all is good by now, export file.
	$processor->init();
	$processor->export();

}
add_action( 'slicewp_admin_action_batch_export_file', 'slicewp_admin_action_batch_export_file', 50 );