<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

// Check for lead id
if ( empty( $_GET['lead_id'] ) ) {
	return;
}

// Get the lead
$lead = slicewp_get_lead( absint( $_GET['lead_id'] ) );

if ( empty( $lead ) ) {
	return;
}

// Get the affiliate data.
$affiliate = slicewp_get_affiliate( $lead->get( 'affiliate_id' ) );
$user 	   = get_user_by( 'id', $affiliate->get( 'user_id' ) );
$affiliate_email = $user->user_email;

// Check if we have a custom affiliate commission rate for leads.
$commission_rate_lead = ( ! empty( slicewp_get_affiliate_meta( $lead->get( 'affiliate_id' ), 'enable_commission_rates', true ) ) ? slicewp_get_affiliate_meta( $lead->get( 'affiliate_id'), 'commission_rate_lead', true ) : '' );

// Determine the commission amount.
$commission_amount = ( ! empty( $commission_rate_lead ) ? $commission_rate_lead : slicewp_get_setting( 'commission_rate_lead' ) );

?>

<div class="wrap slicewp-wrap slicewp-wrap-add-lead-commission">

	<form action="" method="POST">

		<!-- Page Heading -->
		<h1 class="wp-heading-inline"><?php echo __( 'Add a New Lead Commission', 'slicewp' ); ?></h1>
		<hr class="wp-header-end" />

		<div id="slicewp-content-wrapper">

			<!-- Primary Content -->
			<div id="slicewp-primary">

				<!-- Postbox -->
				<div class="slicewp-card slicewp-first">

					<div class="slicewp-card-header">
						<span class="slicewp-card-title"><?php echo __( 'Lead Commission Details', 'slicewp' ); ?></span>
					</div>

					<!-- Form Fields -->
					<div class="slicewp-card-inner">

						<!-- Lead Commission Affiliate ID -->
						<div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

							<div class="slicewp-field-label-wrapper">
								<label for="slicewp-lead-commission-affiliate-id"><?php echo __( 'Affiliate', 'slicewp' ); ?></label>
							</div>
							
							<input id="slicewp-lead-commission-affiliate-id" type="text" value="<?php echo( slicewp_get_affiliate_name( $lead->get( 'affiliate_id' ) ) . ' (' . $affiliate_email . ')' ); ?>" disabled/>
							<input type="hidden" name="affiliate_id" value="<?php echo $lead->get( 'affiliate_id' ); ?>" />
							
						</div>

						<!-- Lead Commission Amount -->
						<div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

							<div class="slicewp-field-label-wrapper">
								<label for="slicewp-lead-commission-amount">
									<?php echo __( 'Amount', 'slicewp' ); ?>
									<?php
										$currency_symbol = slicewp_get_currency_symbol( slicewp_get_setting( 'active_currency', 'USD' ) );
										echo ' (' . $currency_symbol . ')';
									?>
								</label>
							</div>
							
							<input id="slicewp-lead-commission-amount" name="amount" type="number" step="any" value="<?php echo esc_attr( ! empty( $_POST['amount'] ) ? $_POST['amount'] : $commission_amount ); ?>" />

						</div>

						<!-- Lead Commission Reference -->
						<div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

							<div class="slicewp-field-label-wrapper">
								<label for="slicewp-lead-commission-reference"><?php echo __( 'Reference', 'slicewp' ); ?></label>
							</div>
							
							<input id="slicewp-lead-commission-reference" name="entry_id" type="text" value="<?php echo esc_attr( $lead->get( 'entry_id' ) ) ; ?>" disabled />
							<input type="hidden" name="reference" value="<?php echo $lead->get( 'entry_id' ); ?>" />

						</div>

						<!-- Lead Origin -->
						<div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

							<div class="slicewp-field-label-wrapper">
								<label for="slicewp-lead-commission-origin"><?php echo __( 'Origin', 'slicewp' ); ?></label>
							</div>
							
							<select id="slicewp-lead-commission-origin" name="origin" class="slicewp-select2" disabled>

								<?php 
									foreach ( slicewp()->integrations as $integration_slug => $integration ) {
										echo '<option value="' . esc_attr( $integration_slug ) . '"' . selected( $lead->get( 'origin' ), $integration_slug, false ) . '>' . $integration->get( 'name' ) . '</option>';
									}
								?>

							</select>

							<input type="hidden" name="origin" value="<?php echo $lead->get( 'origin' ); ?>" />

						</div>

						<!-- Lead Commission Status -->
						<div class="slicewp-field-wrapper slicewp-field-wrapper-inline slicewp-last">

							<div class="slicewp-field-label-wrapper">
								<label for="slicewp-lead-commission-status"><?php echo __( 'Status', 'slicewp' ); ?> *</label>
							</div>
							
							<select id="slicewp-lead-commission-status" name="status" class="slicewp-select2">

								<?php 
									foreach ( slicewp_get_commission_available_statuses() as $status_slug => $status_name ) {
										echo '<option value="' . esc_attr( $status_slug ) . '"' . selected( 'unpaid', $status_slug, false ) . '>' . esc_html( $status_name ) . '</option>';
									} 
								?>

							</select>

						</div>

						<!-- Visit ID -->
						<input type="hidden" name="visit_id" value="<?php echo absint( $lead->get( 'visit_id' ) ); ?>" />
		
					</div>

				</div>

				<?php 

					/**
					 * Hook to add extra cards if needed
					 *
					 */
					do_action( 'slicewp_view_commissions_add_lead_commission_bottom' );

				?>

			</div>

			<!-- Sidebar Content -->
			<div id="slicewp-secondary">

				<?php 

					/**
					 * Hook to add extra cards if needed in the sidebar
					 *
					 */
					do_action( 'slicewp_view_commissions_add_lead_commission_secondary' );

				?>

			</div><!-- / Sidebar Content -->

		</div>

		<!-- Action and nonce -->
		<input type="hidden" name="slicewp_action" value="add_lead_commission" />
		<?php wp_nonce_field( 'slicewp_add_lead_commission', 'slicewp_token', false ); ?>

		<!-- Submit -->
		<input type="submit" class="slicewp-form-submit slicewp-button-primary" value="<?php echo __( 'Add Lead Commission', 'slicewp' ); ?>" />
		
	</form>

</div>