<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Add lead configuration in the form settings
add_filter( 'gform_form_settings_fields', 'slicewp_add_lead_conversion_configuration_gfo' );
add_filter( 'gform_form_settings', 'slicewp_add_lead_conversion_configuration_legacy_gfo', 10, 2 );

add_filter( 'gform_tooltips', 'slicewp_add_tooltips_lead_configuration_gfo' );

// Save the lead conversion form settings
add_action( 'gform_pre_form_settings_save', 'slicewp_save_form_settings_gfo' );

// Insert a new unpaid commission
add_action( 'gform_entry_created', 'slicewp_register_lead_gfo', 10, 2 );
add_action( 'gform_entry_created', 'slicewp_add_lead_commission_gfo', 15, 2 );

// Add the entry edit link in leads table
add_filter( 'slicewp_list_table_entry_item', 'slicewp_list_table_leads_add_entry_edit_link_gfo', 10, 2 );


/**
 * Outputs the HTML for Entry in leads table
 *
 * @param array $tooltips
 *
 * @return array
 *
 */
function slicewp_list_table_leads_add_entry_edit_link_gfo( $output, $item ) {

	if ( empty( $item ) )
		return $output;

	if ( empty( $item['origin'] ) || $item['origin'] != 'gfo' )
		return $output;
		
	$output = '<a href="' . esc_url( add_query_arg( array( 'page' => 'gf_entries', 'view' => 'entry', 'id' => absint( $item['form_id'] ), 'lid' => absint( $item['entry_id'] ) ), admin_url( 'admin.php' ) ) ) . '">' . $item['entry_id'] . '</a>';

	return $output;

}


/**
 * Adds the SliceWP tooltips in Gravity Forms
 *
 * @param array $tooltips
 *
 * @return array
 *
 */
function slicewp_add_tooltips_lead_configuration_gfo( $tooltips ) {

	$tooltips['slicewp_enable_leads_registration'] 		= '<h6>' . esc_html__( 'Leads Registration', 'slicewp' ) . '</h6>' . esc_html__( 'Check this option to register leads in SliceWP.', 'slicewp' );
	$tooltips['slicewp_register_commissions_on_submit']	= '<h6>' . esc_html__( 'Commission Registration', 'slicewp' ) . '</h6>' . esc_html__( 'Check this option to automatically create a commissions when a referred visitor submits the form.', 'slicewp' );

	return $tooltips;

}


/**
 * Adds the lead commissions in form settings
 *
 * @param array $fields
 *
 * @return array
 *
 */
function slicewp_add_lead_conversion_configuration_gfo( $fields ) {

	$fields['slicewp_lead_commission'] = array(
		'title'  => esc_html__( 'Lead Commissions', 'slicewp' ),
		'fields' => array(
			array(
				'name'    => 'slicewp_enable_leads_registration',
				'type'    => 'checkbox',
				'label'   => __( 'Leads registration', 'slicewp' ),
				'tooltip' => gform_tooltip( 'slicewp_enable_leads_registration', '', true ),
				'choices' => array(
					array(
						'name'  => 'slicewp_enable_leads_registration',
						'label' => __( 'Enable lead registration', 'slicewp' ),
					)
				)
			),
			array(
				'name'    => 'slicewp_register_commissions_on_submit',
				'type'    => 'checkbox',
				'label'   => __( 'Commissions registration', 'slicewp' ),
				'tooltip' => gform_tooltip( 'slicewp_register_commissions_on_submit', '', true ),
				'choices' => array(
					array(
						'name'  => 'slicewp_register_commissions_on_submit',
						'label' => __( 'Register commissions on submit', 'slicewp' ),
					)
				)
			)
		)
	);
						

	return $fields;

}


/**
 * Adds the lead commissions in form settings
 *
 * @param array $form_settings
 * @param array $form
 *
 * @return array
 *
 */
function slicewp_add_lead_conversion_configuration_legacy_gfo( $form_settings, $form ) {

	if ( class_exists( 'GFForms' ) && isset( GFForms::$version ) && version_compare( GFForms::$version, '2.5.0' ) >= 0 )
		return $form_settings;

	if ( class_exists( 'GFCommon' ) && isset( GFCommon::$version ) && version_compare( GFCommon::$version, '2.5.0' ) >= 0 )
		return $form_settings;

	$lead_registration			= rgar( $form, 'slicewp_enable_leads_registration' );
	$commission_registration	= rgar( $form, 'slicewp_register_commissions_on_submit' );

	$tr_lead_registration = '
	<tr>
		<th>
			' . __( 'Leads registration', 'slicewp' ) . ' ' . gform_tooltip( 'slicewp_enable_leads_registration', '', true ) . '
		</th>
		<td>
			<input type="checkbox" id="slicewp_enable_leads_registration" name="slicewp_enable_leads_registration" value="1" ' . checked( 1, $lead_registration, false ) . ' />
			<label for="slicewp_enable_leads_registration">' . __( 'Enable lead registration', 'slicewp' ) . '</label>
		</td>
	</tr>';

	$tr_commission_registration = '
	<tr>
		<th>
			' . __( 'Commissions registration', 'slicewp' ) . ' ' . gform_tooltip( 'slicewp_register_commissions_on_submit', '', true ) . '
		</th>
		<td>
			<input type="checkbox" id="slicewp_register_commissions_on_submit" name="slicewp_register_commissions_on_submit" value="1" ' . checked( 1, $commission_registration, false ) . ' />
			<label for="slicewp_register_commissions_on_submit">' . __( 'Register commissions on submit', 'slicewp' ) . '</label>
		</td>
	</tr>';

	$leads_configuration = array(
		'lead_registration' 		=> $tr_lead_registration,
		'commission_registration'	=> $tr_commission_registration
	);

	$form_settings += array( __( 'Lead Commissions', 'gravityforms' ) => $leads_configuration );

	return $form_settings;

}


/**
 * Saves the lead conversion settings
 *
 * @param array $form
 *
 * @return array
 *
 */
function slicewp_save_form_settings_gfo( $form ) {

	$form['slicewp_enable_leads_registration']		= ( ! empty( rgpost( 'slicewp_enable_leads_registration' ) ) ? 1 : 0 );
	$form['slicewp_register_commissions_on_submit']	= ( ! empty( rgpost( 'slicewp_register_commissions_on_submit' ) ) ? 1 : 0 );

	return $form;

}


/**
 * Registers the lead
 *
 * @param array $entry
 * @param array $form
 * 
 */
function slicewp_register_lead_gfo( $entry, $form ) {

	// Check if leads registration is enabled for this form
	$leads_registration = rgar( $form, 'slicewp_enable_leads_registration' );

	if ( empty( $leads_registration ) )
		return;

	// Get and check to see if referrer exists
	$affiliate_id = slicewp_get_referrer_affiliate_id();
	$visit_id	  = slicewp_get_referrer_visit_id();


	/**
	 * Filters the referrer affiliate ID for Gravity Forms.
	 * This is mainly used by add-ons for different functionality.
	 *
	 * @param int $affiliate_id
	 * @param int $entry
	 *
	 */
	$affiliate_id = apply_filters( 'slicewp_referrer_affiliate_id_gfo', $affiliate_id, $entry );

	if ( empty( $affiliate_id ) )
		return;

	// Verify if the affiliate is valid
	if ( ! slicewp_is_affiliate_valid( $affiliate_id ) ) {

		slicewp_add_log( 'GFO: Lead was not created because the affiliate is not valid.' );
		return;

	}

	// Check to see if a commission for this lead has been registered
	$leads = slicewp_get_leads( array( 'entry_id' => $entry['id'], 'origin' => 'gfo' ) );

	if ( ! empty( $leads ) ) {

		slicewp_add_log( 'GFO: Lead was not created because another lead for this entry exists.' );
		return;

	}

	// Get the emails filled in the form entry
	$customer_emails = slicewp_get_form_entry_emails_gfo( $entry, $form );

	// Check to see if the affiliate made the entry
	if ( empty( slicewp_get_setting( 'affiliate_own_commissions' ) ) ) {

		$affiliate = slicewp_get_affiliate( $affiliate_id );

		if ( is_user_logged_in() && get_current_user_id() == $affiliate->get( 'user_id' ) ) {

			slicewp_add_log( 'GFO: Lead was not created because the lead is also the affiliate.' );
			return;

		}

		if ( ! empty( $customer_emails ) ) {

			foreach ( $customer_emails as $customer_email ) {

				if ( slicewp_affiliate_has_email( $affiliate_id, $customer_email ) ) {

					slicewp_add_log( 'GFO: Lead was not created because the lead is also the affiliate.' );
					return;

				}

			}

		}

	}

	if ( ! empty( $customer_emails ) ) {

		// Get the customer names
		$customer_names = slicewp_get_form_entry_names_gfo( $entry, $form );

	}

	// Prepare lead data
	$lead_data = array(
		'affiliate_id'		=> absint( $affiliate_id ),
		'visit_id'			=> ( ! is_null( $visit_id ) ? absint( $visit_id ) : 0 ),
		'origin'			=> 'gfo',
		'form_id'			=> absint( $form['id'] ),
		'entry_id'			=> absint( $entry['id'] ),
		'date_created'		=> slicewp_mysql_gmdate(),
		'date_modified'		=> slicewp_mysql_gmdate(),
		'email'				=> ! empty( $customer_emails ) ? $customer_emails[0] : '',
		'first_name'		=> ! empty( $customer_names ) ? $customer_names[0]['first_name'] : '',
		'last_name'			=> ! empty( $customer_names ) ? $customer_names[0]['last_name'] : ''
	);

	// Insert the lead
	$lead_id = slicewp_insert_lead( $lead_data );

	if ( ! empty( $lead_id ) ) {

		slicewp_add_log( sprintf( 'GFO: Lead #%s has been successfully inserted.', $lead_id ) );

		// Add note in Gravity Forms
		GFAPI::add_note( $entry['id'], 0, 'SliceWP', sprintf( __( 'Lead #%s was added for affiliate %s.', 'slicewp' ), $lead_id, slicewp_get_affiliate_name( $lead_data['affiliate_id'] ) ) );

	} else {

		slicewp_add_log( 'GFO: Lead could not be inserted due to an unexpected error.' );

	}

}


/**
 * Adds the lead commission
 *
 * @param array $entry
 * @param array $form
 * 
 */
function slicewp_add_lead_commission_gfo( $entry, $form ) {

	// Check if commission registration is enabled for this form
	$commisions_registration = rgar( $form, 'slicewp_register_commissions_on_submit' );

	if ( empty( $commisions_registration ) )
		return;		
	
	// Get and check to see if referrer exists
	$affiliate_id = slicewp_get_referrer_affiliate_id();
	$visit_id	  = slicewp_get_referrer_visit_id();


	/**
	 * Filters the referrer affiliate ID for Gravity Forms.
	 * This is mainly used by add-ons for different functionality.
	 *
	 * @param int $affiliate_id
	 * @param int $entry
	 *
	 */
	$affiliate_id = apply_filters( 'slicewp_referrer_affiliate_id_gfo', $affiliate_id, $entry );

	if ( empty( $affiliate_id ) )
		return;

	// Verify if the affiliate is valid
	if ( ! slicewp_is_affiliate_valid( $affiliate_id ) ) {

		slicewp_add_log( 'GFO: Commission was not created because the affiliate is not valid.' );
		return;

	}

	// Check to see if a commission for this lead has been registered
	$commissions = slicewp_get_commissions( array( 'reference' => $entry['id'], 'origin' => 'gfo' ) );

	if ( ! empty( $commissions ) ) {

		slicewp_add_log( 'GFO: Commission was not created because another commission for the reference and origin already exists.' );
		return;

	}

	// Get the emails filled in the form entry
	$customer_emails = slicewp_get_form_entry_emails_gfo( $entry, $form );

	// Check to see if the affiliate made the entry
	if ( empty( slicewp_get_setting( 'affiliate_own_commissions' ) ) ) {

		$affiliate = slicewp_get_affiliate( $affiliate_id );

		if ( is_user_logged_in() && get_current_user_id() == $affiliate->get('user_id') ) {

			slicewp_add_log( 'GFO: Pending commission was not created because the customer is also the affiliate.' );
			return;

		}

		if ( ! empty( $customer_emails ) ) {

			foreach ( $customer_emails as $customer_email ) {

				if ( slicewp_affiliate_has_email( $affiliate_id, $customer_email ) ) {

					slicewp_add_log( 'GFO: Pending commission was not created because the customer is also the affiliate.' );
					return;

				}

			}

		}

	}

	if ( ! empty( $customer_emails ) ) {

		// Get the customer names
		$customer_names = slicewp_get_form_entry_names_gfo( $entry, $form );

	}

	// Process the customer
	$customer_args = array(
		'email'   	 	=> ( ! empty( $customer_emails ) ? $customer_emails[0] : '' ),
		'user_id' 	 	=> ( is_user_logged_in() ? get_current_user_id() : '' ),
		'first_name'	=> ( ! empty( $customer_names ) ? $customer_names[0]['first_name'] : '' ),
		'last_name'		=> ( ! empty( $customer_names ) ? $customer_names[0]['last_name'] : '' )
	);

	$customer_id = slicewp_process_customer( $customer_args );

	if ( $customer_id )
		slicewp_add_log( sprintf( 'GFO: Customer #%s has been successfully processed.', $customer_id ) );
	else
		slicewp_add_log( 'GFO: Customer could not be processed due to an unexpected error.' );

	// Calculate commission amount
	$args = array(
		'origin'		=> 'gfo',
		'type'			=> 'lead',
		'affiliate_id'	=> $affiliate_id,
		'customer_id'	=> $customer_id
	);

	$commission_amount = slicewp_calculate_commission_amount( 0, $args );

	// Prepare commission data
	$commission_data = array(
		'affiliate_id'	=> $affiliate_id,
		'visit_id'		=> ( ! is_null( $visit_id ) ? absint( $visit_id ) : 0 ),
		'date_created'	=> slicewp_mysql_gmdate(),
		'date_modified'	=> slicewp_mysql_gmdate(),
		'type'			=> 'lead',
		'status'		=> 'unpaid',
		'reference'		=> absint( $entry['id'] ),
		'customer_id'	=> absint( $customer_id ),
		'origin'		=> 'gfo',
		'amount'		=> slicewp_sanitize_amount( $commission_amount ),
		'currency'		=> slicewp_get_setting( 'active_currency', 'USD' )
	);

	// Insert the commission
	$commission_id = slicewp_insert_commission( $commission_data );

	if ( ! empty( $commission_id ) ) {

		// Update the visit with the newly inserted commission_id
		if ( ! is_null( $visit_id ) ) {

			slicewp_update_visit( $visit_id, array( 'date_modified' => slicewp_mysql_gmdate(), 'commission_id' => $commission_id ) );

		}

		// Get the lead created for this entry
		$leads_args = array(
			'origin'   => 'gfo',
			'entry_id' => absint( $entry['id'] )
		);

		$leads = slicewp_get_leads( $leads_args );

		if ( ! empty( $leads ) ) {

			// Update the lead with the commission id
			slicewp_update_lead( $leads[0]->get( 'id' ), array( 'commission_id' => $commission_id ) );
		
		}
		
		// Add note in Gravity Forms
		GFAPI::add_note( $entry['id'], 0, 'SliceWP', sprintf( __( 'Commission #%s, having value %s was added for affiliate %s.', 'slicewp' ), $commission_id, slicewp_format_amount( $commission_data['amount'], slicewp_get_setting( 'active_currency', 'USD' ) ), slicewp_get_affiliate_name( $commission_data['affiliate_id'] ) ) );

		slicewp_add_log( sprintf( 'GFO: Lead commission #%s has been successfully inserted.', $commission_id ) );

	} else {

		slicewp_add_log( 'GFO: Lead commission could not be inserted due to an unexpected error.' );
		return;

	}

}
