<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Lead Commissions" add-on class.
 * 
 */
class SliceWP_Add_On_Lead_Commissions extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'lead_commissions';

		// Name.
		$this->name = 'Lead Commissions';

		// Description.
		$this->description = 'Set up a pay-per-lead affiliate program with the Lead Commissions add-on for SliceWP. Reward affiliates for leads sent your way.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-lead-commissions.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/lead-commissions/';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

		add_action( 'slicewp_activated_add_on', array( $this, 'set_general_settings' ) );
		
		add_action( 'slicewp_activated_add_on', array( $this, 'set_forced_core_update' ) );
		add_filter( 'slicewp_update_check_do_update', array( $this, 'do_forced_core_update' ) );

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'base/functions.php',
			'base/lead/functions.php',
			'base/lead/class-lead.php',
			'base/lead/class-object-db-leads.php',
			'base/integrations/gravity-forms/functions.php',
			'base/integrations/ninja-forms/functions.php',
			'base/integrations/ws-form/functions.php',
			'admin/leads/functions.php',
			'admin/leads/functions-actions-leads.php',
			'admin/leads/class-list-table-leads.php',
			'admin/leads/class-submenu-page-leads.php'
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


	/**
	 * Sets the default general settings on add-on activation.
	 * 
	 * @param string $add_on_slug
	 * 
	 */
	public function set_general_settings( $add_on_slug ) {

		if ( $add_on_slug != $this->slug ) {
			return;
		}

		$settings = slicewp_get_option( 'settings', array() );

		if ( ! is_array( $settings ) ) {
			return;
		}

		if ( ! isset( $settings['commission_rate_lead'] ) ) {
			$settings['commission_rate_lead'] = 5;
		}

		slicewp_update_option( 'settings', $settings );

	}


	/**
	 * Set force update core on add-on activation.
	 * 
	 * @param string $add_on_slug
	 * 
	 */
	public function set_forced_core_update( $add_on_slug ) {

		if ( $add_on_slug != $this->slug ) {
			return;
		}

		slicewp_update_option( 'force_core_update', 1 );

	}


	/**
	 * Force update core procedure if needed.
	 * 
	 * @param bool $do_update
	 * 
	 * @return bool
	 * 
	 */
	public function do_forced_core_update( $do_update ) {

		if ( ! $this->is_active() ) {
			return $do_update;
		}

		$_do_update = slicewp_get_option( 'force_core_update' );

		if ( ! empty( $_do_update ) ) {

			$do_update = true;

			slicewp_update_option( 'force_core_update', '' );
			
		}

		return $do_update;

	}

}


/**
 * Registers the Lead Commissions add-on.
 * 
 * @param array $add_ons
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_lead_commissions( $add_ons ) {

	$add_ons['lead_commissions'] = 'SliceWP_Add_On_Lead_Commissions';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_lead_commissions', 130 );