<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Attempts to connect Mailchimp and retrieve data
 *
 */
function slicewp_mailchimp_integration_action_ajax_connect() {

	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die(0);
	}

	if ( empty( $_POST['api_key'] ) ) {
		wp_die(0);
	}

	$api_key = sanitize_text_field( $_POST['api_key'] );
	$audience_id = slicewp_get_setting( 'mailchimp_audience' );

	// Connect to Mailchimp
	$initialized = slicewp()->services['mailchimp']->init( $api_key );

	// Check for errors
	if ( ! $initialized ) {

		// Return with fail message
		wp_send_json( array( 'success' => false, 'data' => array( 'message' => __( 'Invalid MailChimp API key supplied.', 'slicewp' ) ) ) );

	} else {

		// Output the fields
		slicewp()->services['mailchimp']->save_api_data();
		slicewp()->services['mailchimp']->output_audiences();
		slicewp()->services['mailchimp']->output_tags( $audience_id );

		$integration_fields  = '<div id="slicewp-mailchimp-integration-fields" style="display: block; position: relative;">';
		$integration_fields .= ob_get_contents();
		ob_end_clean();
		$integration_fields .= '</div>';

		// Return with a success message
		wp_send_json( array( 'success' => true, 'data' => array( 'message' =>  __( 'Connected succesfully to Mailchimp.', 'slicewp' ), 'integration_fields' => $integration_fields ) ) );
	
	}

}
add_action( 'wp_ajax_slicewp_mailchimp_integration_action_ajax_connect', 'slicewp_mailchimp_integration_action_ajax_connect' );


/**
 * Gets the tags for the selected audience
 *
 */
function slicewp_mailchimp_integration_action_ajax_get_tags() {

	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_settings' ) ) {
		wp_die(0);
	}

	if ( empty( $_POST['audience_id'] ) ) {
		wp_die(0);
	}

	$audience_id = sanitize_text_field( $_POST['audience_id'] );

	// Connect to Mailchimp
	$initialized = slicewp()->services['mailchimp']->init( slicewp_get_setting( 'mailchimp_api_key' ) );

	// Check for errors
	if ( ! $initialized ) {

		// Return with fail message
		wp_send_json( array( 'success' => false, 'data' => array( 'message' => __( 'Invalid MailChimp API key supplied.', 'slicewp' ) ) ) );

	} else {

		// Output the audience tags
		slicewp()->services['mailchimp']->output_tags( $audience_id );

		$tags_field = ob_get_contents();
		ob_end_clean();

		// Return with a success message
		wp_send_json( array( 'success' => true, 'data' => array( 'tags_field' => $tags_field ) ) );

	}

}
add_action( 'wp_ajax_slicewp_mailchimp_integration_action_ajax_get_tags', 'slicewp_mailchimp_integration_action_ajax_get_tags' );