jQuery( function($) {

    /**
     * Move the multi-currency general settings card right after the currency card.
     * 
     */
    var setting_card = $('#slicewp-card-settings-multi-currency').detach();
    $('#slicewp-card-settings-currency').after( setting_card );
    $('#slicewp-card-settings-multi-currency').show();


    /**
     * Initialize select2.
     * 
     */
    if( $.fn.select2 ) {

        $('.slicewp-currency-exchange-rate:not(.slicewp-currency-exchange-rate-placeholder) select').each( function() {

            var $select = $(this);
    
            $select.addClass( 'slicewp-select2' );
    
            $select.select2( {
                minimumResultsForSearch : 20,
                templateSelection: function( option ) {
    
                    if ( ! option.id ) {
                        return option.text;
                    }
    
                    return option.id;
    
                }
            }).on('select2:open', function() {
    
                var container = $('.select2-container').last();
    
                container.addClass('slicewp-select2-container slicewp-select2-container-currency-exchange');;
                
                container.find( '.select2-search__field' ).attr( 'placeholder', 'Type to search...' );

                // Focus the search field for single selects.
                if ( typeof $select.attr( 'multiple' ) == 'undefined' ) {
                    container.find('.select2-search__field')[0].focus();
                }
    
            });
    
            $select.siblings( '.select2-container' ).addClass( 'slicewp-select2' );
    
        });

    }


    /**
     * Adds a new currency exchange rate.
     * 
     */
    $(document).on( 'click', '#slicewp-add-currency-exchange-rate', function(e) {

        e.preventDefault();

        var $new_field = $(this).siblings( '.slicewp-currency-exchange-rate-placeholder' ).first().clone();
		var $rate_key  = $(this).siblings( 'input[type="hidden"]' ).last();

        // Set data for the new field.
		$new_field.removeClass( 'slicewp-currency-exchange-rate-placeholder' );
		$new_field.find('[data-name]').each( function() {
			$(this).attr( 'name', $(this).attr( 'data-name' ).replace( '#rate_key', parseInt( $rate_key.val() ) ) ).removeAttr( 'data-name' )
		});

        // Append the field.
		$(this).before( $new_field );

        // Initialize select2.
        var $select = $new_field.find( 'select' );
    
        $select.addClass( 'slicewp-select2' );

        $select.select2( {
            minimumResultsForSearch : 20,
            templateSelection: function( option ) {

                if ( ! option.id ) {
                    return option.text;
                }

                return option.id;

            }
        }).on('select2:open', function() {

            var container = $('.select2-container').last();

            container.addClass('slicewp-select2-container slicewp-select2-container-currency-exchange');;
            
            container.find( '.select2-search__field' ).attr( 'placeholder', 'Type to search...' );

            // Focus the search field for single selects.
            if ( typeof $select.attr( 'multiple' ) == 'undefined' ) {
                container.find('.select2-search__field')[0].focus();
            }

        });

        $select.siblings( '.select2-container' ).addClass( 'slicewp-select2' );

        // Increment option key
		$rate_key.val( ( parseInt( $rate_key.val() ) + 1 ) );

    });


    /**
     * Removes the currency exchange rate that is clicked.
     * 
     */
    $(document).on( 'click', '.slicewp-remove-currency-exchange-rate', function(e) {

        e.preventDefault();

        // Remove the level.
        $(this).closest( '.slicewp-currency-exchange-rate' ).remove();

    });


    /**
     * Adapts the HTML of the exchange rate elements when a currency is selected.
     * 
     */
    $(document).on( 'change', '.slicewp-currency-exchange-rate select[name*="[currency]"]', function(e) {

        $(this).closest( '.slicewp-currency-exchange-rate' ).attr( 'data-currency', $(this).val() );

    });


    /**
     * Show/hide the exchange rate update method settings panel.
     * 
     */
    $(document).on( 'change', '#slicewp-exchange-rates-update-method', function(e) {

        $('.slicewp-exchange-rates-update-method-settings').hide();

        if ( $('.slicewp-exchange-rates-update-method-settings[data-method="' + $(this).val() + '"]').length != 0 ) {
            $('.slicewp-exchange-rates-update-method-settings[data-method="' + $(this).val() + '"]').show();
        }

        if ( $(this).val() == 'manual' ) {
            $('#slicewp-fetch-currency-exchange-rates').hide();
        } else {
            $('#slicewp-fetch-currency-exchange-rates').css( 'display', 'inline-flex' );
        }

    });

    $('#slicewp-exchange-rates-update-method').trigger( 'change' );


    /**
     * Connect/disconnect Open Exchange Rates API.
     * 
     */
     $(document).on( 'click', '#slicewp-connect-openexchangerates', function(e) {

        e.preventDefault();

        $button = $(this);
		
		// Exit if button is disabled
		if ( $button.hasClass( 'slicewp-disabled' ) ) {
			return false;
		}

		// Exit if the API key field is empty
		if ( $button.siblings( 'input[type="password"]' ).val() == '' ) {
			$button.siblings( 'input[type="password"]' ).focus();
			return false;
		}

		// Disable API key field
		$button.siblings( 'input[type="password"]' ).attr( 'disabled', 'true' );

		// Disable the button
		$button.addClass( 'slicewp-disabled' );

		// Show spinner
		$button.addClass( 'slicewp-spinner-active' );

		// Prepare AJAX call data
		var data = {
			action		  : 'slicewp_action_ajax_connect_openexchangerates',
			slicewp_token : $( '#slicewp_token' ).val(),
			app_id		  : $button.siblings( 'input[type="password"]' ).val()
		}

		// Make AJAX call
		$.post( ajaxurl, data, function( response ) {

			// Remove API notice.
			$button.closest( '.slicewp-exchange-rates-update-method-settings' ).find( '.slicewp-field-notice' ).remove();

			// Re-enable the field.
			$button.siblings( 'input[type="password"]' ).removeAttr( 'disabled' );

			// Re-enable the button.
			$button.removeClass( 'slicewp-disabled' );
			
			// Hide spinner.
			$button.removeClass( 'slicewp-spinner-active' );

			if ( response.success == true ) {

				$button.parent().after( '<div class="slicewp-field-notice slicewp-field-notice-success">' + response.data.message + '</div>' );
				$button.closest( '.slicewp-exchange-rates-update-method-settings' ).find( '.slicewp-field-notice' ).fadeIn();

                $('#slicewp-fetch-currency-exchange-rates').removeClass( 'slicewp-disabled' );

			} else {

				// Show the error message
				$button.parent().after( '<div class="slicewp-field-notice slicewp-field-notice-error">' + response.data.message + '</div>' );
				$button.closest( '.slicewp-exchange-rates-update-method-settings' ).find( '.slicewp-field-notice' ).fadeIn();

                $('#slicewp-fetch-currency-exchange-rates').addClass( 'slicewp-disabled' );

			}

		});

    });


    /**
     * Connect/disconnect ExchangeRate-API.
     * 
     */
     $(document).on( 'click', '#slicewp-connect-exchangerate-api', function(e) {

        e.preventDefault();

        $button = $(this);
		
		// Exit if button is disabled.
		if ( $button.hasClass( 'slicewp-disabled' ) ) {
			return false;
		}

		// Exit if the API key field is empty.
		if ( $button.siblings( 'input[type="password"]' ).val() == '' ) {
			$button.siblings( 'input[type="password"]' ).focus();
			return false;
        }

        // Set action.
        var action = $button.attr( 'data-action' );

		// Disable API key field.
		$button.siblings( 'input[type="password"]' ).attr( 'disabled', 'true' );

		// Disable the button.
		$button.addClass( 'slicewp-disabled' );

		// Show spinner.
		$button.addClass( 'slicewp-spinner-active' );

		// Prepare AJAX call data.
		var data = {
			action		  : 'slicewp_action_ajax_' + action + '_exchangerate_api',
			slicewp_token : $( '#slicewp_token' ).val(),
			api_key		  : $button.siblings( 'input[type="password"]' ).val()
		}

		// Make AJAX call.
		$.post( ajaxurl, data, function( response ) {

			// Remove API notice.
			$button.closest( '.slicewp-exchange-rates-update-method-settings' ).find( '.slicewp-field-notice' ).remove();

			// Re-enable the field.
			$button.siblings( 'input[type="password"]' ).removeAttr( 'disabled' );

			// Re-enable the button.
			$button.removeClass( 'slicewp-disabled' );
			
			// Hide spinner.
			$button.removeClass( 'slicewp-spinner-active' );

			if ( response.success == true ) {

                // If action is connect.
                if ( action == 'connect' ) {

                    $('#slicewp-fetch-currency-exchange-rates').removeClass( 'slicewp-disabled' );

                    $button.find( 'span[data-connected="false"]' ).hide();
                    $button.find( 'span[data-connected="true"]' ).show();

                }

                // Is action is disconnect.
                if ( action == 'disconnect' ) {

                    $('#slicewp-fetch-currency-exchange-rates').addClass( 'slicewp-disabled' );

                    $button.find( 'span[data-connected="true"]' ).hide();
                    $button.find( 'span[data-connected="false"]' ).show();

                    $('#slicewp-exchangerate-api-api-key').val( '' );

                }

                // Switch actions on the button.
                $button.attr( 'data-action', ( action == 'connect' ? 'disconnect' : 'connect' ) );

                // Show the success message.
				$button.parent().after( '<div class="slicewp-field-notice slicewp-field-notice-success">' + response.data.message + '</div>' );
				$button.closest( '.slicewp-exchange-rates-update-method-settings' ).find( '.slicewp-field-notice' ).fadeIn();

			} else {

				// Show the error message.
				$button.parent().after( '<div class="slicewp-field-notice slicewp-field-notice-error">' + response.data.message + '</div>' );
				$button.closest( '.slicewp-exchange-rates-update-method-settings' ).find( '.slicewp-field-notice' ).fadeIn();

                $('#slicewp-fetch-currency-exchange-rates').addClass( 'slicewp-disabled' );

			}

		});

    });


    /**
     * Call to fetch new currency exchange rates.
     * 
     */
    $(document).on( 'click', '#slicewp-fetch-currency-exchange-rates', function(e) {

        e.preventDefault();

        $button = $(this);
		
		// Exit if button is disabled.
		if ( $button.hasClass( 'slicewp-disabled' ) ) {
			return false;
		}

        // Add overlay with spinner.
		$button.closest( '.slicewp-field-wrapper' ).css( { position: 'relative' } ).append( '<div class="slicewp-overlay"><div class="spinner"></div></div>' );

        // Remove field notice.
        $button.siblings( '.slicewp-field-notice:not(.slicewp-field-notice-last-updated)' ).remove();

        // Prepare AJAX call data.
        var currencies = [];

        $('.slicewp-currency-exchange-rate:not(.slicewp-currency-exchange-rate-placeholder)').each( function() {
            currencies.push( $(this).attr( 'data-currency' ) );
        });

		var data = {
			action		  : 'slicewp_action_ajax_multi_currency_fetch_update_rates',
			slicewp_token : $( '#slicewp_token' ).val(),
			currencies    : currencies
		}

        // Make AJAX call.
		$.post( ajaxurl, data, function( response ) {
			
			// Remove overlay with spinner.
			$button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-overlay' ).remove();

			if ( response.success == true ) {

                // Update the last updated timestamp.
                if ( typeof response.data.last_updated != 'undefined' ) {
                    $button.closest( '.slicewp-field-wrapper' ).find( '.slicewp-field-notice-last-updated span' ).html( response.data.last_updated );
                }

                // Update the rates.
                if ( typeof response.data.rates != 'undefined' ) {

                    for ( var currency in response.data.rates ) {

                        if ( response.data.rates[currency] ) {
                            $('.slicewp-currency-exchange-rate[data-currency="' + currency + '"]').find( 'input[name^="multi_currency[currency_exchange_rates]"]' ).val( response.data.rates[currency] );
                        }

                    }

                }

				$button.after( '<div class="slicewp-field-notice slicewp-field-notice-success">' + response.data.message + '</div>' );
				$button.siblings( '.slicewp-field-notice' ).fadeIn();

			} else {

				// Show the error message.
				$button.after( '<div class="slicewp-field-notice slicewp-field-notice-error">' + response.data.message + '</div>' );
				$button.siblings( '.slicewp-field-notice' ).fadeIn();

			}

		});

    });

});