<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Multi-level Affiliates" add-on class.
 * 
 */
class SliceWP_Add_On_Multi_Level_Affiliates extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'multi_level_affiliates';

		// Name.
		$this->name = 'Multi-level Affiliates';

		// Description.
		$this->description = 'Allow your affiliates to invite other people to join your affiliate program and be rewarded extra commissions for sales referred to you by the newly recruited affiliates.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-multi-level-affiliates.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/multi-level-affiliates/';

		// Settings URL.
		$this->settings_url = add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'general' ), admin_url( 'admin.php' ) ) . '#slicewp-card-settings-multi-level-affiliates';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

		if ( $this->is_active() ) {

			add_action( 'slicewp_enqueue_front_end_scripts', array( $this, 'register_front_end_scripts' ) );

			add_filter( 'slicewp_template_paths', array( $this, 'register_template_paths' ) );

		}

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'base/functions.php',
			'admin/functions.php',
			'admin/class-admin-affiliates-tree-diagram.php',
			'users/functions.php',
			'users/class-affiliates-tree-diagram.php',
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


	/**
	 * Registers and enqueues the scripts and style for the user area.
	 *
	 */
	public function register_front_end_scripts( $hook ) {

		// Plugin script.
		wp_register_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script-front-end', $this->get_dir_url() . 'assets/js/script-front-end.js', array( 'slicewp-script' ), $this->get_parent_plugin_version() );

	}


	/**
	 * Register the affiliate leaderboard templates directory.
	 *
	 * @param array $template_paths
	 *
	 * @return array
	 *
	 */
	public function register_template_paths( $template_paths ) {

		$template_paths[125] = untrailingslashit( $this->get_dir_path() ) . '/templates/';

		return $template_paths;

	}

}


/**
 * Registers the Multi-level Affiliates add-on.
 * 
 * @param array $add_ons
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_multi_level_affiliates( $add_ons ) {

	$add_ons['multi_level_affiliates'] = 'SliceWP_Add_On_Multi_Level_Affiliates';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_multi_level_affiliates', 50 );