var slicewp_payout_requests_front_end = function() {

	/**
	 * Event handler for dynamically added elements.
	 *
	 * @param {string}   event_types
	 * @param {string}   selector
	 * @param {function} callback
	 *
	 */
	function on( event_types, selector, callback ) {

		var event_types = event_types.split( ' ' );

		for ( var i = 0; i < event_types.length; i++ ) {

			document.body.addEventListener( event_types[i], function( event ) {

				for ( var target = event.target; target && target != this; target = target.parentNode ) {

					if ( target.matches( selector ) ) {

						callback.call( target, event );
						break;

					}

				}

			}, false );

		}

	}


    /**
     * Opens the "Payout Request" overlay.
     * 
     */
     on( 'click', '.slicewp-button-view-request-payout', function(e) {

        e.preventDefault();

        this.blur();

        var overlay = this.parentNode.querySelector( '.slicewp-global-overlay-payout-request' );

        if ( overlay ) {
            window.slicewp.show_overlay( overlay );
        }

    });


    /**
     * Closes the "Payout Request" overlay on success confirmation button click.
     * 
     */
    on( 'click', '.slicewp-payout-request-success button', function(e) {

        e.preventDefault();

        this.blur();

        var overlay = this.closest( '.slicewp-global-overlay' );

        if ( overlay ) {
            window.slicewp.close_overlay( overlay );
        }

    });


    /**
     * Handles the "invoice" file field.
     * 
     */
    on( 'change', '[name="payout_request_invoice"]', function() {

        if ( this.files && this.files.length > 0 ) {
            this.closest( 'label' ).querySelector( 'span' ).innerHTML = this.files[0].name;
        }

    });


	/**
     * Trigger AJAX call to request the payout.
     * 
     */
    on( 'click', '.slicewp-button-request-payout', function(e) {

        e.preventDefault();

        var global_overlay = this.closest( '.slicewp-global-overlay-inner' );

        // Add loading animation.
        if ( ! global_overlay.querySelector( 'slicewp-loading-overlay' ) ) {

            var overlay = document.createElement( 'div' );
            var loader  = document.createElement( 'span' );

            overlay.setAttribute( 'class', 'slicewp-loading-overlay' );
            loader.setAttribute( 'class', 'slicewp-loader' );

            overlay.appendChild( loader );
            global_overlay.appendChild( overlay );

            setTimeout( function() {
                global_overlay.querySelector( '.slicewp-loading-overlay' ).classList.add( 'slicewp-active' );
            }, 1 );
            
        }

        // Prepare AJAX call data.
        var data = new FormData();

        data.append( 'action', 'slicewp_action_ajax_create_payout_request' );
        data.append( 'affiliate_id', this.closest( 'form' ).querySelector( '[name="payout_request_affiliate_id"]' ).value );
        data.append( 'invoice', ( this.closest( 'form' ).querySelector( '[name="payout_request_invoice"]' ) ? this.closest( 'form' ).querySelector( '[name="payout_request_invoice"]' ).files[0] : '' ) );
        data.append( 'slicewp_token', this.closest( 'form' ).querySelector( '[name="slicewp_token"]' ).value );

        var request = new XMLHttpRequest();

        request.open( 'POST', window.slicewp.ajaxurl, true );

        request.onload = function () {

            if ( this.status >= 200 && this.status < 400 ) {
                
                var response = JSON.parse( this.response );
                
                setTimeout( function() {

                    // Output the error message from the response.
                    if ( ! response.success && response.data ) {

                        if ( ! global_overlay.querySelector( '.slicewp-error' ) ) {

                            var error = document.createElement( 'div' );
                        
                            error.setAttribute( 'class', 'slicewp-user-notice slicewp-error' );
                            error.appendChild( document.createTextNode( response.data.message ) );

                            global_overlay.querySelector( 'form' ).prepend( error );

                        } else {

                            global_overlay.querySelector( '.slicewp-error' ).innerHTML = response.data.message;

                        }

                    }

                    // Show the success message.
                    if ( response.success ) {

                        global_overlay.querySelector( 'form' ).remove();
                        global_overlay.querySelector( '.slicewp-payout-request-success' ).style.display = 'block';

                        // Remove the payout eligibility notification card and replace it with 
                        if ( response.data && response.data.html ) {

                            var temp_wrapper = document.createElement( 'div' );
                            var current_card = document.querySelector( '.slicewp-button-view-request-payout' ).closest( '.slicewp-card' );

                            current_card.parentNode.insertBefore( temp_wrapper, current_card );
                            
                            temp_wrapper.appendChild( current_card );
                            temp_wrapper.innerHTML = response.data.html

                            while ( temp_wrapper.firstChild) {
                                temp_wrapper.parentNode.insertBefore( temp_wrapper.firstChild, temp_wrapper );
                            }

                            temp_wrapper.remove();

                        } else {

                            document.querySelector( '.slicewp-button-view-request-payout' ).closest( '.slicewp-card' ).remove();

                        }

                    }

                    // Remove animation.
                    if ( response != 0 ) {
                        global_overlay.querySelector( '.slicewp-loading-overlay' ).remove();
                    }
                    
                }, 750 );

            }

        };

        request.send( data );

    });


    /**
     * Trigger AJAX call to cancel the payout request.
     * 
     */
    on( 'click', '.slicewp-button-cancel-payout-request', function(e) {

        e.preventDefault();

        if ( ! confirm( this.getAttribute( 'data-confirmation-message' ) ) ) {
            return false;
        }

        var cancel_button = this;

        // Add loading animation.
        if ( ! cancel_button.closest( '.slicewp-card' ).querySelector( 'slicewp-loading-overlay' ) ) {

            var overlay = document.createElement( 'div' );
            var loader  = document.createElement( 'span' );

            overlay.setAttribute( 'class', 'slicewp-loading-overlay slicewp-active' );
            loader.setAttribute( 'class', 'slicewp-loader' );

            overlay.appendChild( loader );
            cancel_button.closest( '.slicewp-card' ).appendChild( overlay );
            
        }

        // Prepare AJAX call data.
        var data = new FormData();

        data.append( 'action', 'slicewp_action_ajax_cancel_payout_request' );
        data.append( 'affiliate_id', this.getAttribute( 'data-affiliate-id' ) );
        data.append( 'payment_id', this.getAttribute( 'data-payment-id' ) );
        data.append( 'slicewp_token', this.getAttribute( 'data-nonce' ) );

        var request = new XMLHttpRequest();

        request.open( 'POST', window.slicewp.ajaxurl, true );

        request.onload = function () {

            if ( this.status >= 200 && this.status < 400 ) {
                
                var response = JSON.parse( this.response );
                
                setTimeout( function() {

                    // Show the success message.
                    if ( response.success ) {

                        // Remove the payout eligibility notification card and replace it with 
                        if ( response.data && response.data.html ) {

                            var temp_wrapper = document.createElement( 'div' );
                            var current_card = cancel_button.closest( '.slicewp-card' );

                            current_card.parentNode.insertBefore( temp_wrapper, current_card );
                            
                            temp_wrapper.appendChild( current_card );
                            temp_wrapper.innerHTML = response.data.html

                            while ( temp_wrapper.firstChild) {
                                temp_wrapper.parentNode.insertBefore( temp_wrapper.firstChild, temp_wrapper );
                            }

                            temp_wrapper.remove();

                        } else {

                            cancel_button.closest( '.slicewp-card' ).remove();

                        }


                    }
                    
                }, 750 );

            }

        };

        request.send( data );

    });

}

if ( document.readyState === "complete" || ( document.readyState !== "loading" && ! document.documentElement.doScroll ) ) {

	slicewp_payout_requests_front_end();

} else {

	document.addEventListener( "DOMContentLoaded", slicewp_payout_requests_front_end );

}