<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Check for payment.
if ( empty( $_GET['payment_id'] ) ) {
    return;
}

$payment = slicewp_get_payment( absint( $_GET['payment_id'] ) );

if ( is_null( $payment ) ) {
    return;
}

if ( 'paypal_payouts' != $payment->get( 'payout_method' ) ) {
    return;
}

if ( ! in_array( $payment->get( 'status' ), array( 'unpaid', 'requested' ) ) ) {
    return;
}

// Bail if the payment has a PayPal payout batch ID saved.
$payout_batch_id = slicewp_get_payment_meta( $payment->get( 'id' ), 'paypal_payout_batch_id', true );

if ( ! empty( $payout_batch_id ) ) {
    return;
}

// Bail if the affiliate doesn't exist.
$affiliate = slicewp_get_affiliate( $payment->get( 'affiliate_id' ) );

if ( is_null( $affiliate ) ) {
    return;
}

?>

<div id="slicewp-card-do-single-payment" class="slicewp-card">

    <div class="slicewp-card-header">
        <span class="slicewp-card-title"><?php echo __( 'Process Payment', 'slicewp' ); ?></span>
    </div>

    <div class="slicewp-card-inner">
        <p><?php echo sprintf( __( 'This payment, totaling %s, is payable through PayPal Payouts.' ), slicewp_format_amount( $payment->get( 'amount' ), slicewp_get_setting( 'active_currency', 'USD' ) ) ); ?></p>
        <p><?php echo __( 'By clicking the button below, this payment will be processed through your PayPal account. If the payment is successful, all commissions attached to this payment will be marked as paid.', 'slicewp' ) ?></p>
    </div>

    <div class="slicewp-card-footer">

        <?php if ( ! slicewp_has_paypal_api_credentials_set() ): ?>

            <div class="slicewp-field-notice slicewp-field-notice-warning" style="display: block;">
				<p><?php echo sprintf( __( 'Your PayPal credentials are missing. To be able to pay your affiliates using PayPal Payouts, please %sadd your PayPal credentials in SliceWP &rarr; Settings%s', 'slicewp' ), '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'integrations' ), 'admin.php' ) ) . '#slicewp-card-settings-paypal-credentials">', '</a>' ); ?></p>
			</div>

        <?php elseif( empty( $affiliate->get( 'payment_email' ) ) ): ?>

            <div class="slicewp-field-notice slicewp-field-notice-warning" style="display: block;">
				<p><?php echo __( "The affiliate cannot be paid through PayPal Payouts because they don't have a payment email set for their account.", 'slicewp' ); ?></p>
			</div>

        <?php else: ?>

            <?php if ( ! empty( slicewp_get_setting( 'paypal_api_test_mode' ) ) ): ?>

                <div class="slicewp-field-notice slicewp-field-notice-warning" style="display: block; margin-bottom: 10px;">
                    <p><?php echo sprintf( __( '%sPayPal Payouts is in test mode.%s This means that payments will be processed through your PayPal Sandbox account, not your live PayPal Business account.', 'slicewp' ), '<strong>', '</strong>' ); ?></p>
                    <p><?php echo sprintf( __( 'To send real affiliate payments, %sdisable Test Mode from the Settings page%s.', 'slicewp' ), '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'integrations' ), admin_url( 'admin.php' ) ) ) . '#slicewp-card-settings-paypal-credentials">', '</a>' ); ?></p>
                </div>

            <?php endif; ?>

            <a href="<?php echo wp_nonce_url( add_query_arg( array( 'slicewp_action' => 'do_single_payment', 'payout_method' => 'paypal_payouts', 'payment_id' => $payment->get( 'id' ) ) ), 'slicewp_do_single_payment', 'slicewp_token' ); ?>" data-confirmation-message="<?php echo __( 'Are you sure you want to pay this payment through PayPal?', 'slicewp' ); ?>" class="slicewp-button-primary"><?php echo __( 'Pay with PayPal', 'slicewp' ); ?></a>

        <?php endif; ?>

    </div>

</div>