<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Validates and handles the adding of the new performance bonus in the database.
 *
 */
function slicewp_admin_action_add_performance_bonus() {

	// Verify for nonce.
	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_add_performance_bonus' ) ) {
		return;
	}

	// Verify for name.
	if ( empty( $_POST['name'] ) ) {

		slicewp_admin_notices()->register_notice( 'performance_bonus_name_missing', '<p>' . __( 'Please set a name for this bonus.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_name_missing' );

		return;

	}

	// Verify for bonus target type.
	if ( empty( $_POST['target_type'] ) || empty( $_POST['target'] ) ) {

		slicewp_admin_notices()->register_notice( 'performance_bonus_target_missing', '<p>' . __( 'Please select the target your affiliates need to reach to receive this bonus.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_target_missing' );

		return;

	}

    // Verify for the reward.
    if ( empty( $_POST['reward_type'] ) ) {

        slicewp_admin_notices()->register_notice( 'performance_bonus_reward_type_missing', '<p>' . __( 'Please set the reward you wish to offer your affiliates for reaching the set target.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_reward_type_missing' );

		return;

    }

    if ( ( 'commission' == $_POST['reward_type'] && empty( $_POST['reward_commission_amount'] ) ) || ( 'store_credit' == $_POST['reward_type'] && empty( $_POST['reward_store_credit_amount'] ) ) ) {

        slicewp_admin_notices()->register_notice( 'performance_bonus_reward_type_missing', '<p>' . __( 'Please set the reward you wish to offer your affiliates for reaching the set target.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_reward_type_missing' );

		return;

    }

    // Verify the recurrence of this bonus.
    if ( empty( $_POST['recurrence'] ) ) {

        slicewp_admin_notices()->register_notice( 'performance_bonus_recurrence_missing', '<p>' . __( 'Please select the recurrence of this bonus.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_recurrence_missing' );

		return;

    }

    if ( empty( $_POST['status'] ) ) {

        slicewp_admin_notices()->register_notice( 'performance_bonus_status_missing', '<p>' . __( 'Please select the status of this bonus.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_status_missing' );

		return;

    }

	$_POST = stripslashes_deep( $_POST );

	// Prepare performance bonus data to be inserted.
    $bonuses 	   = (array)get_option( 'slicewp_performance_bonuses', array() );
    $last_saved_id = absint( get_option( 'slicewp_performance_bonuses_last_id', 0 ) );
    $bonus_id      = $last_saved_id + 1;

	$bonus_data = array(
        'id'                              => $bonus_id,
        'name'                            => sanitize_text_field( $_POST['name'] ),
        'target_type'                     => sanitize_text_field( $_POST['target_type'] ),
        'target'                          => sanitize_text_field( $_POST['target'] ),
        'reward_type'                     => sanitize_text_field( $_POST['reward_type'] ),
        'reward_commission_amount'        => slicewp_sanitize_amount( ! empty( $_POST['reward_commission_amount'] ) ? sanitize_text_field( $_POST['reward_commission_amount'] ) : 0 ),
        'reward_store_credit_amount'      => slicewp_sanitize_amount( ! empty( $_POST['reward_store_credit_amount'] ) ? sanitize_text_field( $_POST['reward_store_credit_amount'] ) : 0 ),
        'recurrence'                      => sanitize_text_field( $_POST['recurrence'] ),
        'status'		                  => sanitize_text_field( $_POST['status'] ),
        'availability_type'               => sanitize_text_field( ! empty( $_POST['availability_type'] ) ? $_POST['availability_type'] : '' ),
        'availability_affiliate_id'       => ( ! empty( $_POST['availability_affiliate_id'] ) && is_array( $_POST['availability_affiliate_id'] ) ? array_map( 'absint', $_POST['availability_affiliate_id'] ) : array() ),
        'availability_affiliate_group_id' => ( ! empty( $_POST['availability_affiliate_group_id'] ) && is_array( $_POST['availability_affiliate_group_id'] ) ? array_map( 'absint', $_POST['availability_affiliate_group_id'] ) : array() ),
        'date_created'	                  => slicewp_mysql_gmdate(),
        'date_modified'	                  => slicewp_mysql_gmdate()
	);

    $bonuses[$bonus_id] = $bonus_data;

    update_option( 'slicewp_performance_bonuses', $bonuses );
	update_option( 'slicewp_performance_bonuses_last_id', $bonus_id );

	// Redirect to the edit page of the performance bonus with a success message.
	wp_redirect( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'subpage' => 'edit-performance-bonus', 'bonus_id' => $bonus_id, 'slicewp_message' => 'bonus_insert_success' ), admin_url( 'admin.php' ) ) );
	exit;

}
add_action( 'slicewp_admin_action_add_performance_bonus', 'slicewp_admin_action_add_performance_bonus', 50 );


/**
 * Validates and handles the updating of the new performance bonus in the database.
 *
 */
function slicewp_admin_action_update_performance_bonus() {

	// Verify for nonce.
	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_update_performance_bonus' ) ) {
		return;
	}

    // Verify for bonus ID.
	if ( empty( $_POST['bonus_id'] ) ) {

		slicewp_admin_notices()->register_notice( 'bonus_id_missing', '<p>' . __( 'Something went wrong. Could not update the bonus. Please try again.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'bonus_id_missing' );

		return;

	}

	// Verify for bonus's existance.
	$bonus_id = absint( $_POST['bonus_id'] );
    $bonuses  = (array)get_option( 'slicewp_performance_bonuses', array() );

    if ( empty( $bonuses[$bonus_id] ) ) {

        slicewp_admin_notices()->register_notice( 'bonus_not_exists', '<p>' . __( 'Something went wrong. Could not update the bonus. Please try again.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'bonus_not_exists' );

		return;

    }

	// Verify for name.
	if ( empty( $_POST['name'] ) ) {

		slicewp_admin_notices()->register_notice( 'performance_bonus_name_missing', '<p>' . __( 'Please set a name for this bonus.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_name_missing' );

		return;

	}

	// Verify for bonus target type.
	if ( empty( $_POST['target_type'] ) || empty( $_POST['target'] ) ) {

		slicewp_admin_notices()->register_notice( 'performance_bonus_target_missing', '<p>' . __( 'Please select the target your affiliates need to reach to receive this bonus.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_target_missing' );

		return;

	}

    // Verify for the reward.
    if ( empty( $_POST['reward_type'] ) ) {

        slicewp_admin_notices()->register_notice( 'performance_bonus_reward_type_missing', '<p>' . __( 'Please set the reward you wish to offer your affiliates for reaching the set target.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_reward_type_missing' );

		return;

    }

    if ( ( 'commission' == $_POST['reward_type'] && empty( $_POST['reward_commission_amount'] ) ) || ( 'store_credit' == $_POST['reward_type'] && empty( $_POST['reward_store_credit_amount'] ) ) ) {

        slicewp_admin_notices()->register_notice( 'performance_bonus_reward_type_missing', '<p>' . __( 'Please set the reward you wish to offer your affiliates for reaching the set target.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_reward_type_missing' );

		return;

    }

    // Verify the recurrence of this bonus.
    if ( empty( $_POST['recurrence'] ) ) {

        slicewp_admin_notices()->register_notice( 'performance_bonus_recurrence_missing', '<p>' . __( 'Please select the recurrence of this bonus.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_recurrence_missing' );

		return;

    }

    if ( empty( $_POST['status'] ) ) {

        slicewp_admin_notices()->register_notice( 'performance_bonus_status_missing', '<p>' . __( 'Please select the status of this bonus.', 'slicewp' ) . '</p>', 'error' );
		slicewp_admin_notices()->display_notice( 'performance_bonus_status_missing' );

		return;

    }

	$_POST = stripslashes_deep( $_POST );

	// Prepare performance bonus data to be inserted.
	$bonus_data = array(
        'id'                              => $bonus_id,
        'name'                            => sanitize_text_field( $_POST['name'] ),
        'target_type'                     => sanitize_text_field( $_POST['target_type'] ),
        'target'                          => sanitize_text_field( $_POST['target'] ),
        'reward_type'                     => sanitize_text_field( $_POST['reward_type'] ),
        'reward_commission_amount'        => slicewp_sanitize_amount( ! empty( $_POST['reward_commission_amount'] ) ? sanitize_text_field( $_POST['reward_commission_amount'] ) : 0 ),
        'reward_store_credit_amount'      => slicewp_sanitize_amount( ! empty( $_POST['reward_store_credit_amount'] ) ? sanitize_text_field( $_POST['reward_store_credit_amount'] ) : 0 ),
        'recurrence'                      => sanitize_text_field( $_POST['recurrence'] ),
        'status'		                  => sanitize_text_field( $_POST['status'] ),
        'availability_type'               => sanitize_text_field( ! empty( $_POST['availability_type'] ) ? $_POST['availability_type'] : '' ),
        'availability_affiliate_id'       => ( ! empty( $_POST['availability_affiliate_id'] ) && is_array( $_POST['availability_affiliate_id'] ) ? array_map( 'absint', $_POST['availability_affiliate_id'] ) : array() ),
        'availability_affiliate_group_id' => ( ! empty( $_POST['availability_affiliate_group_id'] ) && is_array( $_POST['availability_affiliate_group_id'] ) ? array_map( 'absint', $_POST['availability_affiliate_group_id'] ) : array() ),
        'date_created'	                  => $bonuses[$bonus_id]['date_created'],
        'date_modified'	                  => slicewp_mysql_gmdate()
	);

    $bonuses[$bonus_id] = $bonus_data;

    update_option( 'slicewp_performance_bonuses', $bonuses );

	// Redirect to the edit page of the performance bonus with a success message.
	wp_redirect( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'subpage' => 'edit-performance-bonus', 'bonus_id' => $bonus_id, 'slicewp_message' => 'bonus_update_success' ), admin_url( 'admin.php' ) ) );
	exit;

}
add_action( 'slicewp_admin_action_update_performance_bonus', 'slicewp_admin_action_update_performance_bonus', 50 );


/**
 * Validates and handles the activation of a bonus.
 * 
 */
function slicewp_admin_action_activate_performance_bonus() {

	if ( ! slicewp_verify_request_action( 'activate_performance_bonus' ) ) {
		return;
	}

	if ( empty( $_GET['bonus_id'] ) ) {
		return;
	}

	$bonus_id = absint( $_GET['bonus_id'] );
	$bonuses  = array_filter( (array)get_option( 'slicewp_performance_bonuses', array() ) );

	if ( empty( $bonuses[$bonus_id] ) ) {
		return;
	}

	// Update the bonus data.
	$bonuses[$bonus_id]['status'] 		 = 'active';
	$bonuses[$bonus_id]['date_modified'] = slicewp_mysql_gmdate();
	
	update_option( 'slicewp_performance_bonuses', $bonuses );

	// Redirect to the current page.
	wp_redirect( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'slicewp_message' => 'bonus_activated_success' ), admin_url( 'admin.php' ) ) );
	exit;

}
add_action( 'slicewp_admin_action_activate_performance_bonus', 'slicewp_admin_action_activate_performance_bonus', 50 );


/**
 * Validates and handles the deactivation of a bonus.
 * 
 */
function slicewp_admin_action_deactivate_performance_bonus() {

	if ( ! slicewp_verify_request_action( 'deactivate_performance_bonus' ) ) {
		return;
	}

	if ( empty( $_GET['bonus_id'] ) ) {
		return;
	}

	$bonus_id = absint( $_GET['bonus_id'] );
	$bonuses  = array_filter( (array)get_option( 'slicewp_performance_bonuses', array() ) );

	if ( empty( $bonuses[$bonus_id] ) ) {
		return;
	}

	// Update the bonus data.
	$bonuses[$bonus_id]['status'] 		 = 'inactive';
	$bonuses[$bonus_id]['date_modified'] = slicewp_mysql_gmdate();
	
	update_option( 'slicewp_performance_bonuses', $bonuses );

	// Redirect to the current page.
	wp_redirect( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'slicewp_message' => 'bonus_deactivated_success' ), admin_url( 'admin.php' ) ) );
	exit;

}
add_action( 'slicewp_admin_action_deactivate_performance_bonus', 'slicewp_admin_action_deactivate_performance_bonus', 50 );


/**
 * Validates and handles the deletion of a bonus.
 * 
 */
function slicewp_admin_action_delete_performance_bonus() {

	if ( ! slicewp_verify_request_action( 'delete_performance_bonus' ) ) {
		return;
	}

	if ( empty( $_GET['bonus_id'] ) ) {
		return;
	}

	$bonus_id = absint( $_GET['bonus_id'] );
	$bonuses  = array_filter( (array)get_option( 'slicewp_performance_bonuses', array() ) );

	if ( empty( $bonuses[$bonus_id] ) ) {
		return;
	}

	unset( $bonuses[$bonus_id] );
	
	update_option( 'slicewp_performance_bonuses', $bonuses );

	// Redirect to the current page.
	wp_redirect( add_query_arg( array( 'page' => 'slicewp-performance-bonuses', 'slicewp_message' => 'bonus_delete_success' ), admin_url( 'admin.php' ) ) );
	exit;

}
add_action( 'slicewp_admin_action_delete_performance_bonus', 'slicewp_admin_action_delete_performance_bonus', 50 );