<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Class that handles database queries for the bonus rewards.
 *
 */
Class SliceWP_Object_DB_Bonus_Rewards extends SliceWP_Object_DB {
	
	/**
	 * Construct.
	 *
	 */
	public function __construct() {

		global $wpdb;

		$this->table_name 		 = $wpdb->prefix . 'slicewp_bonus_rewards';
		$this->primary_key 		 = 'id';
		$this->context 	  		 = 'bonus_reward';
		$this->query_object_type = 'SliceWP_Bonus_Reward';

	}


	/**
	 * Return the table columns.
	 *
	 */
	public function get_columns() {

		return array(
			'id' 		    => '%d',
			'affiliate_id'	=> '%d',
			'bonus_id'		=> '%d',
            'type'          => '%s',
			'date_created' 	=> '%s',
			'date_modified' => '%s'
		);

	}


	/**
	 * Returns an array of SliceWP_Bonus_Reward objects from the database
	 *
	 * @param array $args
	 * @param bool  $count - whether to return just the count for the query or not
	 *
	 * @return mixed array|int
	 *
	 */
	public function get_bonus_rewards( $args = array(), $count = false ) {

		global $wpdb;

		$defaults = array(
			'number'    		=> 20,
			'offset'    		=> 0,
			'orderby'   		=> 'id',
			'order'     		=> 'DESC',
			'affiliate_id'		=> 0,
			'bonus_id'			=> 0
		);

		$args = wp_parse_args( $args, $defaults );

		/**
		 * Filter the query arguments just before making the db call.
		 *
		 * @param array $args
		 *
		 */
		$args = apply_filters( 'slicewp_get_bonus_rewards_args', $args );

		// Number args.
		if ( $args['number'] < 1 ) {
            $args['number'] = 999999;
        }

		// Join clause.
		$join = '';

		// Where clause.
		$where = "WHERE 1=1";

		// Affiliate ID where clause
		if ( ! empty( $args['affiliate_id'] ) ) {

			$affiliate_id = absint( $args['affiliate_id'] );
			$where 		 .= " AND affiliate_id = '{$affiliate_id}'";

		}

        // Bonus ID where clause.
		if ( ! empty( $args['bonus_id'] ) ) {

			$bonus_id = absint( $args['bonus_id'] );
			$where   .= " AND bonus_id = '{$bonus_id}'";

		}

		// Include date_min filter in where clause.
		if ( ! empty( $args['date_min'] )) {

			$date_min =  sanitize_text_field( $args['date_min']);
			$where  .= " AND date_created >= '{$date_min}' ";

		}

		// Include date_max filter in where clause.
		if ( ! empty( $args['date_max'] )) {

			$date_max =  sanitize_text_field( $args['date_max']);
			$where  .= " AND date_created <= '{$date_max}' ";

		}

		// Orderby.
		$orderby = sanitize_text_field( $args['orderby'] );

		// Order.
		$order = ( 'DESC' === strtoupper( $args['order'] ) ? 'DESC' : 'ASC' );

		$clauses = compact( 'where', 'join', 'orderby', 'order', 'count' );

		$results = $this->get_results( $clauses, $args, 'slicewp_get_bonus_reward' );

		return $results;

	}

	
	/**
	 * Creates and updates the database table for the bonus rewards.
	 *
	 */
	public function create_table() {

		global $wpdb;

		$table_name 	 = $this->table_name;
		$charset_collate = $wpdb->get_charset_collate();

		$query = "CREATE TABLE {$table_name} (
			id bigint(20) NOT NULL AUTO_INCREMENT,
			affiliate_id bigint(20) NOT NULL,
			bonus_id bigint(20) NOT NULL,
            type tinytext NOT NULL,
			date_created datetime NOT NULL,
			date_modified datetime NOT NULL,
			PRIMARY KEY  id (id),
			KEY affiliate_id (affiliate_id),
			KEY bonus_id (bonus_id)
		) {$charset_collate};";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $query );

	}

}