<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Class that outputs the "bonus rewards" HTML table from the affiliate account.
 * 
 */
class SliceWP_List_Table_Affiliate_Account_Bonus_Rewards extends SliceWP_List_Table {

    /**
     * A string identifying the table.
     * 
     * @access protected
	 * @var    string
     * 
     */
    protected $id = 'affiliate_account_bonus_rewards';


    /**
     * Constructor.
     * 
     */
    public function __construct( $args = array() ) {

        parent::__construct( $args );

        $this->table_columns = array(
            'reward' => __( 'Reward', 'slicewp' ),
            'target' => __( 'Target', 'slicewp' ),
            'date'   => __( 'Date', 'slicewp' )
        );

        $this->no_items      = ( empty( $_GET['list-table-filter-date-start'] ) ? __( 'You have no bonus rewards.', 'slicewp' ) : '' );

        $this->set_table_items_data();

    }


    /**
     * Sets the rewards data.
     * 
     */
    protected function set_table_items_data() {

        $affiliate_id = slicewp_get_current_affiliate_id();

        // Prepare the visits args.
        $visit_args = array(
            'number'		=> $this->items_per_page,
            'offset'		=> ( $this->current_page - 1 ) * $this->items_per_page,
            'affiliate_id'	=> $affiliate_id,
            'date_min'      => ( ! empty( $_GET['list-table-filter-date-start'] ) ? get_gmt_from_date( ( new DateTime( $_GET['list-table-filter-date-start'] . ' 00:00:00' ) )->format( 'Y-m-d H:i:s' ) ) : '' ),
            'date_max'      => ( ! empty( $_GET['list-table-filter-date-end'] ) ? get_gmt_from_date( ( new DateTime( $_GET['list-table-filter-date-end'] . ' 23:59:59' ) )->format( 'Y-m-d H:i:s' ) ) : '' )
        );

        $this->items_total = slicewp_get_bonus_rewards( $visit_args, true );
        $this->items 	   = slicewp_get_bonus_rewards( $visit_args );

    }


    /**
     * Column "reward".
     * 
     * @param array $item
     * 
     * @return string
     * 
     */
    public function column_reward( $item ) {

        $output = '';

        if ( $item['type'] == 'commission' ) {

            $commission_data = slicewp_get_bonus_reward_meta( $item['id'], '_commission_data', true );

            $output = '<div>';

                $output .= slicewp_get_svg( 'outline-cash' );

                $output .= '<div>';
                    $output .= slicewp_format_amount( $commission_data['amount'], slicewp_get_setting( 'active_currency', 'USD' ) );
                    $output .= '<span>' . __( 'Fixed commission', 'slicewp' ) . '</span>';
                $output .= '</div>';

            $output .= '</div>';

        }

        if ( $item['type'] == 'store_credit' ) {

            $store_credit_data = slicewp_get_bonus_reward_meta( $item['id'], '_store_credit_data', true );

            $output = '<div>';

                $output .= slicewp_get_svg( 'outline-wallet' );

                $output .= '<div>';
                    $output .= slicewp_format_amount( $store_credit_data['amount'], slicewp_get_setting( 'active_currency', 'USD' ) );
                    $output .= '<span>' . __( 'Store credit', 'slicewp' ) . '</span>';
                $output .= '</div>';

            $output .= '</div>';

        }

		return $output;

    }


    /**
     * Column "target".
     * 
     * @param array $item
     * 
     * @return string
     * 
     */
    public function column_target( $item ) {

        $target_types = array(
            'referred_orders_count'     => __( 'Referred orders', 'slicewp' ),
            'referred_orders_totals'    => __( 'Referred orders total', 'slicewp' ),
            'earned_commissions_totals' => __( 'Earned commissions total', 'slicewp' )
        );

        $target_data = slicewp_get_bonus_reward_meta( $item['id'], '_target_data', true );

        $output = '';

        if ( ! empty( $target_data ) && is_array( $target_data ) ) {

            $output .= ( in_array( $target_data['target_type'], array( 'referred_orders_totals', 'earned_commissions_totals' ) ) ? slicewp_format_amount( $target_data['target'], slicewp_get_setting( 'active_currency', 'USD' ) ) : $target_data['target'] );
            $output .= '<div>' . $target_types[$target_data['target_type']] . '</div>';

        }

		return $output;

	}


    /**
     * Column "date".
     * 
     * @param array $item
     * 
     * @return string
     * 
     */
    public function column_date( $item ) {

        return slicewp_date_i18n( $item['date_created'] );

    }


    /**
     * Outputs elements before the table.
     * 
     */
    public function output_table_before() {}

}