<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Performance Bonuses" add-on class.
 * 
 */
class SliceWP_Add_On_Performance_Bonuses extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'performance_bonuses';

		// Name.
		$this->name = 'Performance Bonuses';

		// Description.
		$this->description = 'Boost your sales by rewarding affiliates with special bonuses for reaching defined performance targets.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-performance-bonuses.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/performance-bonuses/';

		// Settings URL.
		$this->settings_url = add_query_arg( array( 'page' => 'slicewp-performance-bonuses' ), admin_url( 'admin.php' ) );

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

        if ( $this->is_active() ) {

			// Frontend scripts.
			add_action( 'slicewp_affiliate_account_tab_bonuses_top', array( $this, 'enqueue_front_end_scripts' ) );

		}

		add_action( 'slicewp_activated_add_on', array( $this, 'set_forced_core_update' ) );
		add_filter( 'slicewp_update_check_do_update', array( $this, 'do_forced_core_update' ) );

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		$files = array(
            'base/functions.php',
            'base/bonus-reward/functions.php',
            'base/bonus-reward/class-bonus-reward.php',
            'base/bonus-reward/class-object-db-bonus-rewards.php',
			'base/bonus-reward/class-object-meta-db-bonus-rewards.php',
			'admin/bonuses/functions.php',
            'admin/bonuses/functions-actions.php',
            'admin/bonuses/functions-actions-ajax.php',
            'admin/bonuses/class-list-table-performance-bonuses.php',
            'admin/bonuses/class-submenu-page-bonuses.php',
			'admin/rewards/functions.php',
			'admin/rewards/functions-actions.php',
			'admin/rewards/class-list-table-rewards.php',
			'admin/rewards/class-submenu-page-rewards.php',
            'users/functions.php',
			'users/class-list-table-affiliate-account-bonus-rewards.php',
            'users/class-outputter-affiliate-bonuses.php'
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


	/**
	 * Enqueues the scripts and style for the user area.
	 * 
	 */
	public function enqueue_front_end_scripts() {

		// Print the CSS from the front-end file in the page.
		ob_start();

		if ( file_exists( $this->get_dir_path() . 'assets/css/style-front-end.css' ) ) {
			include $this->get_dir_path() . 'assets/css/style-front-end.css';
		}

		$css = ob_get_contents();
		ob_end_clean();

		printf(
			"<style id='slicewp-" . esc_attr( str_replace( '_', '-', $this->slug ) ) . "-style-front-end-inline-css' type='text/css'>\n%s\n</style>\n",
			$css
		);

	}


	/**
	 * Set force update core on add-on activation.
	 * 
	 * @param string $add_on_slug
	 * 
	 */
	public function set_forced_core_update( $add_on_slug ) {

		if ( $add_on_slug != $this->slug ) {
			return;
		}

		slicewp_update_option( 'force_core_update', 1 );

	}


	/**
	 * Force update core procedure if needed.
	 * 
	 * @param bool $do_update
	 * 
	 * @return bool
	 * 
	 */
	public function do_forced_core_update( $do_update ) {

		if ( ! $this->is_active() ) {
			return $do_update;
		}

		$_do_update = slicewp_get_option( 'force_core_update' );

		if ( ! empty( $_do_update ) ) {

			$do_update = true;

			slicewp_update_option( 'force_core_update', '' );
			
		}

		return $do_update;

	}

}


/**
 * Registers the "Performance Bonuses" add-on.
 * 
 * @param array $add_ons
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_performance_bonuses( $add_ons ) {

	$add_ons['performance_bonuses'] = 'SliceWP_Add_On_Performance_Bonuses';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_performance_bonuses', 40 );