<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Add commission settings in download page
add_action( 'slicewp_gpd_metabox_commission_settings_bottom', 'slicewp_pcr_add_product_commission_settings_gpd', 10 );

// Save the product commission rate settings
add_action( 'getpaid_item_metabox_save', 'slicewp_pcr_save_product_commission_settings_gpd', 15, 2 );

// Calculates the product commission amount
add_filter( 'slicewp_calculate_commission_amount', 'slicewp_pcr_calculate_commission_amount_gpd', 15, 3 );


/**
 * Adds the product commission rate fields in GetPaid add/edit item page
 * 
 * 
 */
function slicewp_pcr_add_product_commission_settings_gpd() {
	
	// Get the commission types supported for GetPaid
	$integration_commission_types = slicewp_get_integration_supports( 'gpd' )['commission_types'];    
	
	if ( empty( $integration_commission_types ) ) {
		return;
	}
	
	global $post;
		
	// Get the comission types data
	$available_commission_types = slicewp_get_available_commission_types( true );
		
	// Add the fields into an option group
	echo '<div class="slicewp-options-group slicewp-hide-if-disabled-commissions">';

		// Parse all the integration commission types
		foreach ( $integration_commission_types as $commission_type ) {
			
			// Accept only supported commission types
			if ( ! in_array( $commission_type, array( 'sale', 'subscription' ) ) ) {
				continue;
			}
			
			// Get the current product commission settings
			$commission_rate_type = get_post_meta( $post->ID, 'slicewp_commission_rate_type_' . $commission_type, true );
			$commission_rate      = get_post_meta( $post->ID, 'slicewp_commission_rate_' . $commission_type, true );

		?>

			<div class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate-type slicewp-commission-type-<?php echo esc_attr( $commission_type ); ?> <?php echo ( $commission_type == 'subscription' ? 'slicewp-show-if-subscription' : 'slicewp-show-if-product' ); ?> form-group row">

				<label for="slicewp-product-commission-rate-type-<?php echo $commission_type; ?>" class="col-sm-3 col-form-label">
					<?php echo sprintf( __( '%s Commission Rate Type', 'slicewp' ), $available_commission_types[$commission_type]['label'] ); ?>
				</label>

				<div class="col-sm-8">

					<?php

						echo aui()->select(
							array(
								'id'				=> 'slicewp-product-commission-rate-type-' . $commission_type,
								'name'				=> 'slicewp_commission_rate_type_' . $commission_type,
								'placeholder'		=> __( 'General settings default', 'slicewp' ),
								'value'				=> esc_attr( $commission_rate_type ),
								'select2'			=> true,
								'data-allow-clear'	=> 'false',
								'no_wrap'			=> true,
								'options'			=> slicewp_get_commission_type_rate_types( $commission_type ),
							)
						);

					?>

				</div>

			</div>
			
			<div class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate slicewp-commission-type-<?php echo esc_attr( $commission_type ); ?> <?php echo ( $commission_type == 'subscription' ? 'slicewp-show-if-subscription' : 'slicewp-show-if-product' ); ?> form-group row">

				<label for="slicewp-product-commission-rate-<?php echo $commission_type; ?>" class="col-sm-3 col-form-label">
					<?php echo sprintf( __( '%s Commission Rate', 'slicewp' ), $available_commission_types[$commission_type]['label'] ); ?>
				</label>

				<div class="col-sm-8">
					<input class="widefat" type="text" name="slicewp_commission_rate_<?php echo $commission_type; ?>" id="slicewp-product-commission-rate-<?php echo $commission_type; ?>" value="<?php echo esc_attr( $commission_rate ); ?>" style="width: 100%;">
				</div>

			</div>

		<?php



		}

	echo '</div>';

}


/**
 * Saves the product commission settings into the item meta
 * 
 * @param int 		 $post_id
 * @param WPInv_Item $item
 * 
 */
function slicewp_pcr_save_product_commission_settings_gpd( $post_id, $item ) {

	// Verify for nonce
	if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_meta' ) ) {
		return $post_id;
	}
	
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}

	if ( wp_is_post_revision( $post_id ) || wp_is_post_autosave( $post_id ) ) {
		return $post_id;
	}

	// Get the commission types supported for GetPaid
	$integration_commission_types = slicewp_get_integration_supports( 'gpd' )['commission_types'];    
	
	if ( empty( $integration_commission_types ) ) {
		return;
	}
			
	// Parse all the integration commission types
	foreach ( $integration_commission_types as $commission_type ) {
		
		// Verify to have only the supported commission rate types
		if ( ! in_array( $commission_type, array( 'sale', 'subscription' ) ) ) {
			continue;
		}
		
		// Update commission rate type
		if ( ! empty( $_POST['slicewp_commission_rate_type_' . $commission_type] ) ) {

			update_post_meta( $post_id, 'slicewp_commission_rate_type_' . $commission_type, sanitize_text_field( $_POST['slicewp_commission_rate_type_' . $commission_type] ) );

		} else {

			delete_post_meta( $post_id, 'slicewp_commission_rate_type_' . $commission_type );

		}

		// Update commission rate
		if ( ! empty( $_POST['slicewp_commission_rate_' . $commission_type] ) ) {

			update_post_meta( $post_id, 'slicewp_commission_rate_' . $commission_type, sanitize_text_field( $_POST['slicewp_commission_rate_' . $commission_type] ) );

		} else {

			delete_post_meta( $post_id, 'slicewp_commission_rate_' . $commission_type );

		}
		
	}

}


/**
 * Calculates the product commission amount
 * 
 * @param float $commission_amount
 * @param float $amount
 * @param array $args
 * 
 * @return float $commission_amount
 * 
 */
function slicewp_pcr_calculate_commission_amount_gpd( $commission_amount, $amount, $args ) {

	// Check that the commission is from GetPaid
	if ( $args['origin'] != 'gpd' ) {
		return $commission_amount;
	}

	// Only sales and subscriptions are treated here
	if ( ! in_array( $args['type'], array( 'sale', 'subscription' ) ) ) {
		return $commission_amount;
	}

	// Check if the commission rate is per order
	if ( slicewp_is_commission_basis_per_order() ) {
		return $commission_amount;
	}

	// Get the product id
	$product_id = absint( $args['product_id'] );

	// Get the product commission type and rate
	$product_commission_rate_type = get_post_meta( $product_id, 'slicewp_commission_rate_type_' . $args['type'], true );
	$product_commission_rate      = get_post_meta( $product_id, 'slicewp_commission_rate_' . $args['type'], true );

	// Check if the product commission type and rate are valid
	if ( ! empty( $product_commission_rate_type ) && ! empty( $product_commission_rate ) && is_numeric( $product_commission_rate ) ) { 

		// Calculate the commission using the product type and rate
		$commission_amount = ( $product_commission_rate_type == 'percentage' ? round( ( $amount * $product_commission_rate / 100 ), 2 ) : $product_commission_rate );

	}

	return $commission_amount;

}