<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

// Add commission settings in membership page.
add_action( 'slicewp_pmpro_commission_settings_bottom', 'slicewp_pcr_add_product_commission_settings_pmpro', 10 );

// Save the product commission rate settings.
add_action( 'pmpro_save_membership_level', 'slicewp_pcr_save_product_commission_settings_pmpro', 15, 1 );

// Calculates the product commission amount.
add_filter( 'slicewp_calculate_commission_amount', 'slicewp_pcr_calculate_commission_amount_pmpro', 15, 3 );


/**
 * Adds the product commission rate fields in PMPRO add/edit membership page.
 *
 */
function slicewp_pcr_add_product_commission_settings_pmpro() {
    
    // Get the commission types supported for Paid Memberships Pro.
    $integration_commission_types = slicewp_get_integration_supports( 'pmpro' )['commission_types'];    
    
    if ( empty( $integration_commission_types ) ) {
        return;
    }
            
    // Check for membership level id.
    if ( empty( $_GET['edit'] ) ) {
        return;
    }

    $level_id = intval( $_GET['edit'] );

    // Get the current product commission settings.
    $commission_rate_type = get_pmpro_membership_level_meta( $level_id, 'slicewp_commission_rate_type_subscription', true );
    $commission_rate      = get_pmpro_membership_level_meta( $level_id, 'slicewp_commission_rate_subscription', true );

    ?>

    <table class="slicewp-options-group slicewp-hide-if-disabled-commissions form-table">
        <tbody>

            <tr class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate-type slicewp-commission-type-subscription">
                <th scope="row" valign="top">
                    <label for="slicewp-product-commission-rate-type-subscription"><?php echo __( 'Commission Rate Type', 'slicewp' ); ?></label>
                </th>
                <td>
                    <select class="regular-text" name="slicewp_commission_rate_type_subscription" id="slicewp-product-commission-rate-type-subscription">
                        <option value=""><?php echo __( 'General Settings Default', 'slicewp' ); ?></option>
                        <?php foreach( slicewp_get_commission_type_rate_types( 'subscription' ) as $rate_type => $rate_type_label ) : ?>
                            <option value="<?php echo esc_attr( $rate_type ); ?>" <?php selected( $commission_rate_type, $rate_type ); ?>><?php echo esc_html( $rate_type_label ); ?></option>
                        <?php endforeach; ?>
                    </select>
                </td>
            </tr>

            <tr class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate slicewp-commission-type-subscription">
                <th scope="row" valign="top">
                    <label for="slicewp-product-commission-rate-subscription"><?php echo __( 'Commission Rate', 'slicewp' ); ?></label>
                </th>
                <td>
                    <input class="regular-text" type="text" name="slicewp_commission_rate_subscription" id="slicewp-product-commission-rate-subscription" value="<?php echo esc_attr( $commission_rate ); ?>">
                </td>
            </tr>

        </tbody>
    </table>

    <?php

}


/**
 * Saves the product commission settings into WordPress options.
 * 
 * @param int $level_id
 * 
 */
function slicewp_pcr_save_product_commission_settings_pmpro( $level_id ) {

    // Verify for nonce.
    if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_membership' ) ) {
        return;
    }

    // Update commission rate type.
    if ( ! empty( $_POST['slicewp_commission_rate_type_subscription'] ) ) {

        update_pmpro_membership_level_meta( $level_id, 'slicewp_commission_rate_type_subscription', sanitize_text_field( $_POST['slicewp_commission_rate_type_subscription'] ) );

    } else {

        delete_pmpro_membership_level_meta( $level_id, 'slicewp_commission_rate_type_subscription' );

    }

    // Update commission rate
    if ( ! empty( $_POST['slicewp_commission_rate_subscription'] ) ) {

        update_pmpro_membership_level_meta( $level_id, 'slicewp_commission_rate_subscription', sanitize_text_field( $_POST['slicewp_commission_rate_subscription'] ) );

    } else {

        delete_pmpro_membership_level_meta( $level_id, 'slicewp_commission_rate_subscription' );

    }

}


/**
 * Calculates the product commission amount.
 * 
 * @param float $commission_amount
 * @param float $amount
 * @param array $args
 * 
 * @return float $commission_amount
 * 
 */
function slicewp_pcr_calculate_commission_amount_pmpro( $commission_amount, $amount, $args ) {

    // Check that the commission is from Paid Memberships Pro.
    if ( $args['origin'] != 'pmpro' ) {
        return $commission_amount;
    }

    // Only subscriptions are treated here.
    if ( $args['type'] != 'subscription' ) {
        return $commission_amount;
    }

    // Get the level id.
    $level_id = absint( $args['product_id'] );

    // Get the product commission type and rate.
    $commission_rate_type = get_pmpro_membership_level_meta( $level_id, 'slicewp_commission_rate_type_subscription', true );
    $commission_rate      = get_pmpro_membership_level_meta( $level_id, 'slicewp_commission_rate_subscription', true );

    // Check if the product commission type and rate are valid.
    if ( ! empty( $commission_rate_type ) && ! empty( $commission_rate ) && is_numeric( $commission_rate ) ) {

        // Calculate the commission using the product type and rate.
        $commission_amount = ( $commission_rate_type == 'percentage' ? round( ( $amount * $commission_rate / 100 ), 2 ) : $commission_rate );

    }

    return $commission_amount;

}