<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Add commission settings in download page
add_filter( 'slicewp_stc_metabox_commission_settings_bottom', 'slicewp_pcr_add_product_commission_settings_stc', 10 );

// Save the product commission rate settings
add_action( 'save_post_sc_product', 'slicewp_pcr_save_product_commission_settings_stc', 15, 2 );

// Add commission settings in category page
add_action( 'slicewp_stc_add_category_form_fields_bottom', 'slicewp_pcr_add_category_commission_settings_stc', 10 );
add_action( 'slicewp_stc_edit_category_form_fields_bottom', 'slicewp_pcr_edit_category_commission_settings_stc', 15, 1 );

// Save the product category commission rate settings
add_action( 'create_sc_product_cat', 'slicewp_pcr_save_category_commission_settings_stc', 15, 3 );
add_action( 'edited_sc_product_cat', 'slicewp_pcr_save_category_commission_settings_stc', 15, 3 );

// Calculates the product commission amount
add_filter( 'slicewp_calculate_commission_amount', 'slicewp_pcr_calculate_commission_amount_stc', 15, 3 );


/**
 * Adds the product commission rate fields in Studiocart add/edit download page
 * 
 * @param array $fields
 * 
 * @return array $fields
 * 
 */
function slicewp_pcr_add_product_commission_settings_stc( $fields ) {
	
    // Get the commission types supported for Studiocart
    $integration_commission_types = slicewp_get_integration_supports( 'stc' )['commission_types'];    

	if ( empty( $integration_commission_types ) ) {
        return;
    }
    
    global $post;

    // Check if is hidden by parent
    $is_hidden_by_parent = false;

	// Get the product categories
	$categories = get_the_terms( $post->ID, 'sc_product_cat' );

	// Get the first category of the product
	if ( ! empty( $categories[0]->term_id ) && get_term_meta( $categories[0]->term_id, 'slicewp_disable_commissions', true ) )
		$is_hidden_by_parent = true;

	// Get the comission types data
    $available_commission_types = slicewp_get_available_commission_types( true );

    // Add the fields into an option group
	$fields['slicewp_options_group_pcr_div'] = array(
		'type'	=> 'html',
		'value' => '<div class="slicewp-options-group slicewp-hide-if-disabled-commissions ' . ( $is_hidden_by_parent ? 'slicewp-hidden-by-parent' : '' ) . '">'
	);

	// Add Product Commissions Rate heading
	$fields['slicewp_heading_pcr'] = array(
		'class'	=> 'widefat',
		'type'	=> 'html',
		'value' => '<div id="slicewp_heading_pcr" class="sc-field sc-row"><h4 style="margin: 0;padding: 0 0 5px;border-bottom: 1px solid #d5d5d5;flex-basis: 100%;">' . __( 'Commission Rates', 'slicewp' ). '</h4></div>'
	);

	// Parse all the integration commission types
	foreach ( $integration_commission_types as $commission_type ) {
		
		// Accept only supported commission types
		if ( ! in_array( $commission_type, array( 'sale', 'subscription' ) ) ) {
            continue;
        }
		
		$fields['slicewp_option_field_wrapper_rate_type_' . $commission_type] = array(
			'type'	=> 'html',
			'value' => '<div class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate-type slicewp-commission-type-' . esc_attr( $commission_type ) . ' ' . ( $commission_type == 'subscription' ? 'slicewp-show-if-subscription' : 'slicewp-show-if-product' ) . '">'
		);

		// Prepare the commission type for select field
		$commissions_select[''] = __( 'General Settings Default', 'slicewp' );

		foreach ( slicewp_get_commission_type_rate_types( $commission_type ) as $rate_type => $rate_type_label ) {
            $commissions_select[$rate_type] = $rate_type_label;
        }

		$fields['slicewp_commission_rate_type_' . $commission_type] = array(
			'class' 		=> '', // if removed a notice will be shown
			'id' 			=> 'slicewp-commission-rate-type-' . $commission_type,
			'label'			=> sprintf( __( '%s Commission Rate Type:', 'slicewp' ), $available_commission_types[$commission_type]['label'] ),
			'type'			=> 'select',
			'selections'    => $commissions_select,
			'value'			=> '' // will be populated by Studiocart, if removed a notice will be shown
		);

		$fields['slicewp_option_field_wrapper_rate_type_' . $commission_type . '_div_end'] = array(
			'type'	=> 'html',
			'value' => '</div>'
		);
		
		$fields['slicewp_option_field_wrapper_rate_' . $commission_type] = array(
			'type'	=> 'html',
			'value' => '<div class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate slicewp-commission-type-' . esc_attr( $commission_type ) . ' ' . ( $commission_type == 'subscription' ? 'slicewp-show-if-subscription' : 'slicewp-show-if-product' ) . '">'
		);

		$fields['slicewp_commission_rate_' . $commission_type] = array(
				'class' 		=> '', // if removed a notice will be shown
				'id' 			=> 'slicewp-commission-rate-' . $commission_type,
				'label'			=> sprintf( __( '%s Commission Rate:', 'slicewp' ), $available_commission_types[$commission_type]['label'] ),
				'type'			=> 'text',
				'value'			=> '' // will be populated by Studiocart, if removed a notice will be shown
		);
			
		$fields['slicewp_option_field_wrapper_rate_' . $commission_type . '_div_end'] = array(
			'type'	=> 'html',
			'value' => '</div>'
		);

	}

	$fields['slicewp_options_group_pcr_div_end'] = array(
		'type'	=> 'html',
		'value' => '</div>'
	);

	return $fields;

}


/**
 * Saves the product commission settings into the product meta
 * 
 * @param int $post_id
 * @param WP_Post $post
 * 
 */
function slicewp_pcr_save_product_commission_settings_stc( $post_id, $post ) {

    // Verify for nonce
    if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_meta' ) ) {
        return $post_id;
    }
    
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return $post_id;
    }

    if ( wp_is_post_revision( $post_id ) || wp_is_post_autosave( $post_id ) ) {
        return $post_id;
    }

    // Get the commission types supported for Studiocart
    $integration_commission_types = slicewp_get_integration_supports( 'stc' )['commission_types'];    
    
    if ( empty( $integration_commission_types ) ) {
        return;
    }
            
    // Parse all the integration commission types
    foreach ( $integration_commission_types as $commission_type ) {
        
        // Verify to have only the supported commission rate types
        if ( ! in_array( $commission_type, array( 'sale', 'subscription' ) ) ) {
            continue;
        }
        
        // Update commission rate type
        if ( ! empty( $_POST['slicewp-commission-rate-type-' . $commission_type] ) ) {

            update_post_meta( $post_id, 'slicewp-commission-rate-type-' . $commission_type, sanitize_text_field( $_POST['slicewp-commission-rate-type-' . $commission_type] ) );

        } else {

            delete_post_meta( $post_id, 'slicewp-commission-rate-type-' . $commission_type );

        }

        // Update commission rate
        if ( ! empty( $_POST['slicewp-commission-rate-' . $commission_type] ) ) {

            update_post_meta( $post_id, 'slicewp-commission-rate-' . $commission_type, sanitize_text_field( $_POST['slicewp-commission-rate-' . $commission_type] ) );

        } else {

            delete_post_meta( $post_id, 'slicewp-commission-rate-' . $commission_type );

        }
        
    }

}


/**
 * Adds the Category Rate and Type fields in the add product category page
 * 
 */
function slicewp_pcr_add_category_commission_settings_stc() {

    ?>

    <div class="slicewp-options-group slicewp-hide-if-disabled-commissions">

        <!-- Category Commission Rate Type -->
        <div class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate-type slicewp-commission-type-sale form-field">

            <label for="slicewp-product-category-commission-rate-type"><?php echo __( 'Commission rate type', 'slicewp' ); ?></label>
            <select name="slicewp_product_category_commission_rate_type" style="width:95%" id="slicewp-product-category-commission-rate-type">
                <option value=""><?php echo __( 'General Settings Default', 'slicewp' ); ?></option>
                <?php foreach ( slicewp_get_commission_type_rate_types( 'sale' ) as $rate_type => $rate_type_label ) : ?>
                    <option value="<?php echo esc_attr( $rate_type ); ?>"><?php echo esc_html( $rate_type_label ); ?></option>
                <?php endforeach; ?>
            </select>
            <p><?php echo __( 'The commission rate type for this product category.', 'slicewp' ); ?></p>

        </div>

        <!-- Category Commission Rate -->
        <div class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate slicewp-commission-type-sale form-field">

            <label for="slicewp-product-category-commission-rate"><?php _e( 'Commission Rate', 'slicewp' ); ?></label>
            <input type="text" name="slicewp_product_category_commission_rate" id="slicewp-product-category-commission-rate">
            <p><?php echo __( 'The commission rate for this download category.', 'slicewp' ); ?></p>

        </div>

    </div>

    <?php

}


/**
 * Adds the Category Rate and Type fields in the edit product category page
 * 
 * @param WP_Term $category
 * 
 */
function slicewp_pcr_edit_category_commission_settings_stc( $category ) {

    // Get the product category commission settings
    $commission_rate_type = get_term_meta( $category->term_id, 'slicewp_commission_rate_type', true );
    $commission_rate      = get_term_meta( $category->term_id, 'slicewp_commission_rate', true );    

?>

    <tr class="slicewp-option-field-wrapper slicewp-hide-if-disabled-commissions slicewp-option-field-wrapper-commission-rate-type slicewp-commission-type-sale form-field">
        <th scope="row">
            <label for="slicewp-product-category-commission-rate-type"><?php echo __( 'Commission Rate Type', 'slicewp' ); ?></label>
        </th>
        <td>
            <select name="slicewp_product_category_commission_rate_type" style="width:95%" id="slicewp-product-category-commission-rate-type">
                <option value=""><?php echo __( 'General Settings Default', 'slicewp' ); ?></option>
                <?php foreach ( slicewp_get_commission_type_rate_types( 'sale' ) as $rate_type => $rate_type_label ) : ?>
                    <option value="<?php echo esc_attr( $rate_type ); ?>"<?php selected( $commission_rate_type, $rate_type );?>><?php echo esc_html( $rate_type_label ); ?></option>
                <?php endforeach; ?>
            </select>
            <p class="description"><?php echo __( 'The commission rate type for this product category.', 'slicewp' ); ?></p>
        </td>
    </tr>

    <tr class="slicewp-option-field-wrapper form-field show slicewp-hide-if-disabled-commissions slicewp-option-field-wrapper-commission-rate slicewp-commission-type-sale">
        <th scope="row">
            <label for="slicewp-product-category-commission-rate"><?php _e( 'Commission Rate', 'slicewp' ); ?></label>
        </th>
        <td>
            <input type="text" name="slicewp_product_category_commission_rate" id="slicewp-product-category-commission-rate" value="<?php echo esc_attr( $commission_rate ); ?>">
            <p class="description"><?php echo __( 'The commission rate for this product category.', 'slicewp' ); ?></p>
        </td>
    </tr>

<?php

}


/**
 * Saves the product category commission rate into the category meta
 * 
 * @param int $category_id
 * 
 */
function slicewp_pcr_save_category_commission_settings_stc( $category_id ) {

    // Update the product category rate type
    if ( ! empty( $_POST['slicewp_product_category_commission_rate_type'] ) ) {

        update_term_meta( $category_id, 'slicewp_commission_rate_type', sanitize_text_field( $_POST['slicewp_product_category_commission_rate_type'] ) );

    } else {

        delete_term_meta( $category_id, 'slicewp_commission_rate_type' );

    }

    // Update the product category rate
    if ( ! empty ( $_POST['slicewp_product_category_commission_rate'] ) ) {

        update_term_meta( $category_id, 'slicewp_commission_rate', sanitize_text_field( $_POST['slicewp_product_category_commission_rate'] ) );

    } else {

        delete_term_meta( $category_id, 'slicewp_commission_rate' );

    }

}


/**
 * Calculates the product commission amount
 * 
 * @param float $commission_amount
 * @param float $amount
 * @param array $args
 * 
 * @return float $commission_amount
 * 
 */
function slicewp_pcr_calculate_commission_amount_stc( $commission_amount, $amount, $args ) {

    // Check that the commission is from Studiocart
    if ( $args['origin'] != 'stc' ) {
        return $commission_amount;
    }

    // Only sales and subscriptions are treated here
    if ( ! in_array( $args['type'], array( 'sale', 'subscription' ) ) ) {
        return $commission_amount;
    }

    // Check if the commission rate is per order
    if ( slicewp_is_commission_basis_per_order() ) {
        return $commission_amount;
    }

    // Get the product id
    $product_id = absint( $args['product_id'] );

    // Get the product commission type and rate
    $product_commission_rate_type = get_post_meta( $product_id, 'slicewp-commission-rate-type-' . $args['type'], true );
    $product_commission_rate      = get_post_meta( $product_id, 'slicewp-commission-rate-' . $args['type'], true );

    // Check if the product commission type and rate are valid
    if ( ! empty( $product_commission_rate_type ) && ! empty( $product_commission_rate ) && is_numeric( $product_commission_rate ) ) { 

        // Calculate the commission using the product type and rate
        $commission_amount = ( $product_commission_rate_type == 'percentage' ? round( ( $amount * $product_commission_rate / 100 ), 2 ) : $product_commission_rate );

        return $commission_amount;

    }

    // Get the categories
    $categories = get_the_terms( $product_id, 'sc_product_cat' );

    // Get the first category
    if ( ! empty( $categories ) ) {
        $category_id = $categories[0]->term_id;
    }

    if ( ! empty( $category_id ) ) {

        // Get the category commission type and rate
        $category_commission_rate_type = get_term_meta( $category_id, 'slicewp_commission_rate_type', true );
        $category_commission_rate      = get_term_meta( $category_id, 'slicewp_commission_rate', true );

        // Check if the category commission type and rate are ok
        if ( ! empty( $category_commission_rate_type ) && ! empty( $category_commission_rate ) && is_numeric( $category_commission_rate ) ) { 

            // Calculate the commission using the category type and rate
            $commission_amount = ( $category_commission_rate_type == 'percentage' ? round( ( $amount * $category_commission_rate / 100 ), 2 ) : $category_commission_rate );

            return $commission_amount;

        }

    }

    // Nothing changed. Return the untouched commission amount.
    return $commission_amount;

}