<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Add product commission rate settings in product page
add_action( 'slicewp_woo_product_data_panel_bottom', 'slicewp_pcr_add_product_commission_settings_woo', 10 );

// Save the product commission rate settings
add_action( 'save_post_product', 'slicewp_pcr_save_product_commission_settings_woo', 15, 2 );

// Add product variation commission rate settings in product page
add_action( 'slicewp_woo_variation_product_data_panel_bottom', 'slicewp_pcr_add_product_variation_commission_settings_woo', 10, 3 );

// Save the product variation commission rate settings
add_action( 'woocommerce_ajax_save_product_variations', 'slicewp_pcr_save_product_variation_commission_settings_woo', 15, 1 );

// Add the product category commission rate settings in the category pages
add_action( 'slicewp_woo_add_product_category_form_fields_bottom', 'slicewp_pcr_add_product_category_commision_settings_woo', 10 );
add_action( 'slicewp_woo_edit_product_category_form_fields_bottom', 'slicewp_pcr_edit_product_category_commision_settings_woo', 10, 1 );

// Save the product category commission rate settings
add_action( 'create_product_cat', 'slicewp_pcr_save_product_category_commission_settings_woo', 15, 3 );
add_action( 'edited_product_cat', 'slicewp_pcr_save_product_category_commission_settings_woo', 15, 3 );

// Calculates the product commission amount
add_filter( 'slicewp_calculate_commission_amount', 'slicewp_pcr_calculate_commission_amount_woo', 15, 3 );


/**
 * Adds the product commission rate settings in the SliceWP product tab
 * 
 *
 */
function slicewp_pcr_add_product_commission_settings_woo() {

    // Get the commission types supported for WooCommerce
    $integration_commission_types = slicewp_get_integration_supports( 'woo' )['commission_types'];

    if ( empty( $integration_commission_types ) ) {
        return;
    }

    global $post;

    // Check if is hidden by parent
    $is_hidden_by_parent = false;

    // Get the product categories
    $categories = get_the_terms( $post->ID, 'product_cat' );

    // Get the first category of the product
    if ( ! empty( $categories[0]->term_id ) && get_term_meta( $categories[0]->term_id, 'slicewp_disable_commissions', true ) ) {
        $is_hidden_by_parent = true;
    }


    // Get the comission types data
    $available_commission_types = slicewp_get_available_commission_types( true );

    // Add the fields into an option group
    echo '<div class="slicewp-options-group options_group slicewp-hide-if-disabled-commissions ' . ( $is_hidden_by_parent ? 'slicewp-hidden-by-parent' : '' ) . '">';

        // Parse all the integration commission types
        foreach ( $integration_commission_types as $commission_type ) {

            // Allow only sale and subscription types
            if ( ! in_array( $commission_type, array( 'sale', 'subscription' ) ) ) {
                continue;
            }

			// Add the commission rate type field
			woocommerce_wp_select( array(
				'id'			=> 'slicewp_product_commission_rate_type_' . $commission_type,
				'label'			=> sprintf( __( '%s Rate Type', 'slicewp' ), $available_commission_types[$commission_type]['label'] ),
				'value'			=> get_post_meta( $post->ID, 'slicewp_commission_rate_type_' . $commission_type, true ),
				'options'		=> array_merge( array( '' => __( 'General Settings Default', 'slicewp' ) ), slicewp_get_commission_type_rate_types( $commission_type ) ),
				'desc_tip'		=> true,
				'description'	=> __( 'The selected commission rate type will be used to calculate the commission for this product.', 'slicewp' ),
				'wrapper_class'	=> 'slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate-type slicewp-commission-type-' . $commission_type . ' ' . ( $commission_type == 'subscription' ? 'slicewp-show-if-subscription' : 'slicewp-show-if-product' )
			) );

            // Add the comission rate field
			woocommerce_wp_text_input( array(
				'id'			=> 'slicewp_product_commission_rate_' . $commission_type,
				'label'			=> sprintf( __( '%s Rate', 'slicewp' ), $available_commission_types[$commission_type]['label'] ),
				'value'			=> get_post_meta( $post->ID, 'slicewp_commission_rate_' . $commission_type, true ),
				'desc_tip'		=> true,
				'description'	=> __( 'This rate will be used to calculate the commission for this product.', 'slicewp' ),
				'wrapper_class'	=> 'slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate slicewp-commission-type-' . $commission_type . ' ' . ( $commission_type == 'subscription' ? 'slicewp-show-if-subscription' : 'slicewp-show-if-product' )
			) );

		}

	echo '</div>';

}


/**
 * Saves the product commission into the product meta
 * 
 * @param int     $post_id
 * @param WP_Post $post
 * 
 */
function slicewp_pcr_save_product_commission_settings_woo( $post_id, $post ) {

	// Verify for nonce
    if ( empty( $_POST['slicewp_token'] ) || ! wp_verify_nonce( $_POST['slicewp_token'], 'slicewp_save_meta' ) ) {
        return $post_id;
    }

    // Verify for autosave
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return $post_id;
    }

    if ( wp_is_post_revision( $post_id ) || wp_is_post_autosave( $post_id ) ) {
        return $post_id;
    }

    // Get the commission types supported for WooCommerce
    $integration_commission_types = slicewp_get_integration_supports( 'woo' )['commission_types'];
    
    if ( empty( $integration_commission_types ) ) {
        return;
    }

    // Parse all the integration commission types
    foreach ( $integration_commission_types as $commission_type ) {

        // Verify to have only the supported commission rate types
        if ( ! in_array( $commission_type, array( 'sale', 'subscription' ) ) ) {
            continue;
        }

        // Update commission rate type in the post meta
        if ( ! empty( $_POST['slicewp_product_commission_rate_type_' . $commission_type] ) ) {

            update_post_meta( $post_id, 'slicewp_commission_rate_type_' . $commission_type, sanitize_text_field( $_POST['slicewp_product_commission_rate_type_' . $commission_type] ) );

        } else {

            delete_post_meta( $post_id, 'slicewp_commission_rate_type_' . $commission_type );

        }

        // Update commission rate
        if ( ! empty( $_POST['slicewp_product_commission_rate_' . $commission_type] ) ) {

            update_post_meta( $post_id, 'slicewp_commission_rate_' . $commission_type, sanitize_text_field( $_POST['slicewp_product_commission_rate_' . $commission_type] ) );

        } else {

            delete_post_meta( $post_id, 'slicewp_commission_rate_' . $commission_type );

        }

    }

}


/**
 * Adds the product variation commission rate settings in the variations tab
 * 
 * @param int     $loop           - position in the loop
 * @param array   $variation_data - variation data
 * @param WP_Post $variation      - post data
 * 
 */
function slicewp_pcr_add_product_variation_commission_settings_woo( $loop, $variation_data, $variation ) {

    // Get the commission types supported for WooCommerce
    $integration_commission_types = slicewp_get_integration_supports( 'woo' )['commission_types'];

    if ( empty( $integration_commission_types ) ) {
        return;
    }

    // Get the comission types data
    $available_commission_types = slicewp_get_available_commission_types( true );

    // Wrap all the fields in a group
    echo '<div class="slicewp-options-group slicewp-hide-if-disabled-commissions">';

        // Parse all the integration commission types
        foreach ( $integration_commission_types as $commission_type ) {

            // Allow only sale and subscription types
            if ( ! in_array( $commission_type, array( 'sale', 'subscription' ) ) ) {
                continue;
            }

            // Get the product variation settings
            $commission_rate_type = get_post_meta( $variation->ID, 'slicewp_commission_rate_type_' . $commission_type, true );
            $commission_rate      = get_post_meta( $variation->ID, 'slicewp_commission_rate_' . $commission_type, true );

            ?>

                <p class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate-type slicewp-commission-type-<?php echo esc_attr( $commission_type ); ?> form-row form-row-full <?php echo ( $commission_type == 'subscription' ? 'slicewp-show-if-subscription' : 'slicewp-show-if-product' ); ?>">
    				<label for="slicewp_product_variation_commission_rate_type_<?php echo $commission_type ?>[<?php echo $variation->ID; ?>]"><?php echo sprintf( __( '%s Rate Type', 'slicewp' ), $available_commission_types[$commission_type]['label'] ); ?></label>
    				<select name="slicewp_product_variation_commission_rate_type_<?php echo $commission_type ?>[<?php echo $variation->ID; ?>]" id="slicewp_product_variation_commission_rate_type_<?php echo $commission_type ?>[<?php echo $variation->ID; ?>]">
    					<option value=""><?php echo __( 'Product Settings Default', 'slicewp' ); ?></option>
    					<?php foreach( slicewp_get_commission_type_rate_types( $commission_type ) as $rate_type => $rate_type_label ) : ?>
    						<option value="<?php echo esc_attr( $rate_type ); ?>"<?php selected( $commission_rate_type, $rate_type ); ?>><?php echo esc_html( $rate_type_label ); ?></option>
    					<?php endforeach; ?>
    				</select>
    			</p>

                <p class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate slicewp-commission-type-<?php echo esc_attr( $commission_type ); ?> form-row form-row-full <?php echo ( $commission_type == 'subscription' ? 'slicewp-show-if-subscription' : 'slicewp-show-if-product' ); ?>">
    				<label for="slicewp_product_variation_commission_rate_<?php echo $commission_type ?>[<?php echo $variation->ID; ?>]"><?php echo sprintf( __( '%s Rate Type', 'slicewp' ), $available_commission_types[$commission_type]['label'] ); ?></label>
    				<input type="text" size="5" name="slicewp_product_variation_commission_rate_<?php echo $commission_type ?>[<?php echo $variation->ID; ?>]" value="<?php echo esc_attr( $commission_rate ); ?>" class="wc_input_price" id="slicewp_product_variation_commission_rate_<?php echo $commission_type ?>[<?php echo $variation->ID; ?>]" />
    			</p>

            <?php   
         
        }

    echo '</div>';
    
}


/**
 * Saves the product variation commission settings into the product meta
 * 
 * @param int $product_id
 * 
 */
function slicewp_pcr_save_product_variation_commission_settings_woo( $product_id = 0 ) {

    // Check for variations
    if ( empty( $_POST['variable_post_id'] ) ) {
        return;
    }
    
    // Get the commission types supported for WooCommerce
    $integration_commission_types = slicewp_get_integration_supports( 'woo' )['commission_types'];

    if ( empty( $integration_commission_types ) ) {
        return;
    }
    
    // Parse all the variations
    foreach ( $_POST['variable_post_id'] as $variation_id ) {
        
        $variation_id = absint( $variation_id );
        
        // Parse all the integration commission types
        foreach ( $integration_commission_types as $commission_type ) {

            // Verify to have only the supported commission rate types
            if ( ! in_array( $commission_type, array( 'sale', 'subscription' ) ) ) {
                continue;
            }

            // Update the product variation commission rate type
            if ( ! empty( $_POST['slicewp_product_variation_commission_rate_type_' . $commission_type] ) && ! empty( $_POST['slicewp_product_variation_commission_rate_type_' . $commission_type][$variation_id] ) ) {

                update_post_meta( $variation_id, 'slicewp_commission_rate_type_' . $commission_type, sanitize_text_field( $_POST['slicewp_product_variation_commission_rate_type_' . $commission_type][$variation_id] ) );

            } else {

                delete_post_meta( $variation_id, 'slicewp_commission_rate_type_' . $commission_type );

            }

            // Update the product variation commission rate
            if ( ! empty( $_POST['slicewp_product_variation_commission_rate_' . $commission_type] ) && ! empty( $_POST['slicewp_product_variation_commission_rate_type_' . $commission_type][$variation_id] ) ) {

                update_post_meta( $variation_id, 'slicewp_commission_rate_' . $commission_type, sanitize_text_field( $_POST['slicewp_product_variation_commission_rate_' . $commission_type][$variation_id] ) );

            } else {

                delete_post_meta( $variation_id, 'slicewp_commission_rate_' . $commission_type );

            }
        }
    }

}


/**
 * Adds the Category Rate and Type fields in the add new product category page
 * 
 */
function slicewp_pcr_add_product_category_commision_settings_woo() {

    ?>

    <div class="slicewp-options-group slicewp-hide-if-disabled-commissions">

        <!-- Category Commission Rate Type -->
        <div class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate-type slicewp-commission-type-sale form-field">

            <label for="slicewp-product-category-commission-rate-type"><?php echo __( 'Commission rate type', 'slicewp' ); ?></label>
            <select name="slicewp_product_category_commission_rate_type" style="width:95%" id="slicewp-product-category-commission-rate-type">
                <option value=""><?php echo __( 'General Settings Default', 'slicewp' ); ?></option>
                <?php foreach( slicewp_get_commission_type_rate_types( 'sale' ) as $rate_type => $rate_type_label ) : ?>
                    <option value="<?php echo esc_attr( $rate_type ); ?>"><?php echo esc_html( $rate_type_label ); ?></option>
                <?php endforeach; ?>
            </select>
            <p><?php echo __( 'The commission rate type for this product category.', 'slicewp' ); ?></p>

        </div>

        <!-- Category Commission Rate -->
        <div class="slicewp-option-field-wrapper slicewp-option-field-wrapper-commission-rate slicewp-commission-type-sale form-field">

            <label for="slicewp-product-category-commission-rate"><?php echo __( 'Commission rate', 'slicewp' ); ?></label>
            <input type="text" name="slicewp_product_category_commission_rate" id="slicewp-product-category-commission-rate">
            <p><?php echo __( 'The commission rate for this product category.', 'slicewp' ); ?></p>

        </div>

    </div>

    <?php

}


/**
 * Adds the Category Rate Type and Category Rate fields in the edit product category page
 * 
 * @param WP_Term $category
 * 
 */
function slicewp_pcr_edit_product_category_commision_settings_woo( $category ) {

    // Get the product category commission settings
    $commission_rate_type = get_term_meta( $category->term_id, 'slicewp_commission_rate_type', true );
    $commission_rate      = get_term_meta( $category->term_id, 'slicewp_commission_rate', true );

    ?>

    <tr class="slicewp-option-field-wrapper slicewp-hide-if-disabled-commissions slicewp-option-field-wrapper-commission-rate-type slicewp-commission-type-sale form-field">
        <th scope="row">
            <label for="slicewp-product-category-commission-rate-type"><?php echo __( 'Commission rate type', 'slicewp' ); ?></label>
        </th>
        <td>
            <select name="slicewp_product_category_commission_rate_type" style="width:95%" id="slicewp-product-category-commission-rate-type">
                <option value=""><?php echo __( 'General Settings Default', 'slicewp' ); ?></option>
                <?php foreach( slicewp_get_commission_type_rate_types( 'sale' ) as $rate_type => $rate_type_label ) : ?>
                    <option value="<?php echo esc_attr( $rate_type ); ?>"<?php selected( $commission_rate_type, $rate_type );?>><?php echo esc_html( $rate_type_label ); ?></option>
                <?php endforeach; ?>
            </select>
            <p class="description"><?php echo __( 'The commission rate type for this product category.', 'slicewp' ); ?></p>
        </td>
    </tr>

    <tr class="slicewp-option-field-wrapper form-field show slicewp-hide-if-disabled-commissions slicewp-option-field-wrapper-commission-rate slicewp-commission-type-sale">
        <th scope="row">
            <label for="slicewp-product-category-commission-rate"><?php echo __( 'Commission rate', 'slicewp' ); ?></label>
        </th>
        <td>
            <input type="text" name="slicewp_product_category_commission_rate" id="slicewp-product-category-commission-rate" value="<?php echo esc_attr( $commission_rate ); ?>">
            <p class="description"><?php echo __( 'The commission rate for this product category.', 'slicewp' ); ?></p>
        </td>
    </tr>

    <?php

}


/**
 * Saves the product category commission rate into the category meta
 * 
 * @param int $category_id
 * 
 */
function slicewp_pcr_save_product_category_commission_settings_woo( $category_id ) {

    // Update the product category rate type
    if ( ! empty( $_POST['slicewp_product_category_commission_rate_type'] ) ) {

        update_term_meta( $category_id, 'slicewp_commission_rate_type', sanitize_text_field( $_POST['slicewp_product_category_commission_rate_type'] ) );
    
    } else {

        delete_term_meta( $category_id, 'slicewp_commission_rate_type' );
    
    }
    
    // Update the product category rate
    if ( ! empty ( $_POST['slicewp_product_category_commission_rate'] ) ) {

        update_term_meta( $category_id, 'slicewp_commission_rate', sanitize_text_field( $_POST['slicewp_product_category_commission_rate'] ) );
    
    } else {

        delete_term_meta( $category_id, 'slicewp_commission_rate' );
    
    }
    
}


/**
 * Calculates the product commission amount.
 * 
 * @param float $commission_amount
 * @param float $amount
 * @param array $args
 * 
 * @return float $commission_amount
 * 
 */
function slicewp_pcr_calculate_commission_amount_woo( $commission_amount, $amount, $args ) {

    // Check that the commission is from WooCommerce.
    if ( $args['origin'] != 'woo' ) {
        return $commission_amount;
    }

    // Only sales and subscriptions are treated here.
    if ( ! in_array( $args['type'], array( 'sale', 'subscription') ) ) {
        return $commission_amount;
    }

    // Check if the commission rate is per order.
    if ( slicewp_is_commission_basis_per_order() ) {
        return $commission_amount;
    }

    // Get the product.
    $product_id = absint( $args['product_id'] );
    $product    = wc_get_product( $product_id );

    // Verify if we have a product variation.
    if ( in_array( $product->get_type(), array( 'variation', 'subscription_variation' ) ) ) {

        $variation_id = $product_id;
        $product_id   = $product->get_parent_id();

        // Get the product variation commission type and rate.
        $product_commission_rate      = get_post_meta( $variation_id, 'slicewp_commission_rate_' . $args['type'], true );
        $product_commission_rate_type = get_post_meta( $variation_id, 'slicewp_commission_rate_type_' . $args['type'], true );
        
        // Check if the product variation commission type and rate are valid.
        if ( ! empty( $product_commission_rate_type ) && ! empty( $product_commission_rate ) && is_numeric( $product_commission_rate ) ) { 

            // Calculate the commission using the product variation type and rate.
            $commission_amount = ( $product_commission_rate_type == 'percentage' ? round( ( $amount * $product_commission_rate / 100 ), 2 ) : $product_commission_rate );

            // Calculate the commission amount for fixed amounts per product.
            if ( $args['type'] == 'sale' && $product_commission_rate_type == 'fixed_amount' ) {

                $commission_amount = $product_commission_rate * ( ! empty( $args['quantity'] ) ? $args['quantity'] : 1 );

            }
            
            return $commission_amount;

        }

    }

    // Get the product commission type and rate.
    $product_commission_rate      = get_post_meta( $product_id, 'slicewp_commission_rate_' . $args['type'], true );
    $product_commission_rate_type = get_post_meta( $product_id, 'slicewp_commission_rate_type_' . $args['type'], true );

    // Check if the product commission type and rate are valid.
    if ( ! empty( $product_commission_rate_type ) && ! empty( $product_commission_rate ) && is_numeric( $product_commission_rate ) ) { 

        // Calculate the commission using the product type and rate.
        $commission_amount = ( $product_commission_rate_type == 'percentage' ? round( ( $amount * $product_commission_rate / 100 ), 2 ) : $product_commission_rate );

        // Calculate the commission amount for fixed amounts per product.
        if ( $args['type'] == 'sale' && $product_commission_rate_type == 'fixed_amount' ) {

            $commission_amount = $product_commission_rate * ( ! empty( $args['quantity'] ) ? $args['quantity'] : 1 );

        }

        return $commission_amount;

    }

    // Get the product categories.
    $categories = get_the_terms( $product_id, 'product_cat' );

    // Get the first category of the product.
    if ( ! empty( $categories[0]->term_id ) ) {
        
        // Get the product category commission type and rate.
        $category_commission_rate      = get_term_meta( $categories[0]->term_id, 'slicewp_commission_rate', true );
        $category_commission_rate_type = get_term_meta( $categories[0]->term_id, 'slicewp_commission_rate_type', true );

        // Check if the product category commission type and rate are ok.
        if ( ! empty( $category_commission_rate_type ) && ! empty( $category_commission_rate ) && is_numeric( $category_commission_rate ) ) { 

            // Calculate the commission using the product type and rate.
            $commission_amount = ( $category_commission_rate_type == 'percentage' ? round( ( $amount * $category_commission_rate / 100 ), 2 ) : $category_commission_rate );

            // Calculate the commission amount for fixed amounts per product.
            if ( $args['type'] == 'sale' && $category_commission_rate_type == 'fixed_amount' ) {

                $commission_amount = $category_commission_rate * ( ! empty( $args['quantity'] ) ? $args['quantity'] : 1 );

            }

            return $commission_amount;

        }

    }

    // Nothing changed. Return the untouched commission amount.
    return $commission_amount;

}