<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Handles the settings fields and meta-data saving on SliceWP's admin side.
 *
 */
class SliceWP_Admin_Recurring_Commissions {

	/**
	 * Initializez the admin.
	 *
	 */
	public static function init() {

		// Adds the recurring commissions general settings fields
		add_action( 'slicewp_view_settings_tab_general_bottom', array( __CLASS__, 'add_recurring_commissions_general_settings' ) );

		// Adds the recurring commissions fields to the add/edit affiliate pages
		add_action( 'slicewp_view_affiliates_add_affiliate_bottom', array( __CLASS__, 'add_recurring_commissions_affiliate' ) );
		add_action( 'slicewp_view_affiliates_edit_affiliate_bottom', array( __CLASS__, 'add_recurring_commissions_affiliate' ) );

		// Adds the recurring commissions fields to the add/edit affiliate group pages.
		add_action( 'slicewp_view_affiliate_groups_add_affiliate_group_bottom', array( __CLASS__, 'add_recurring_commissions_affiliate_group' ) );
		add_action( 'slicewp_view_affiliate_groups_edit_affiliate_group_bottom', array( __CLASS__, 'add_recurring_commissions_affiliate_group' ) );

		// Saves the affiliate specific recurring commissions settings
		add_action( 'slicewp_insert_affiliate', array( __CLASS__, 'save_recurring_commissions_affiliate' ) );
		add_action( 'slicewp_update_affiliate', array( __CLASS__, 'save_recurring_commissions_affiliate' ) );

		// Saves the affiliate group specific recurring commissions settings.
		add_action( 'slicewp_insert_collection', array( __CLASS__, 'save_recurring_commissions_affiliate_group' ) );
		add_action( 'slicewp_update_collection', array( __CLASS__, 'save_recurring_commissions_affiliate_group' ) );

	}

	/**
	 * Adds the recurring commissions general settings fields.
	 *
	 */
	public static function add_recurring_commissions_general_settings() {

		include 'views/view-recurring-commissions-general-settings.php';

	}

	/**
	 * Adds the recurring commissions fields to the add/edit affiliate pages.
	 *
	 */
	public static function add_recurring_commissions_affiliate() {

		include 'views/view-recurring-commissions-affiliate.php';

	}

	/**
	 * Adds the recurring commissions fields to the add/edit affiliate group pages.
	 *
	 */
	public static function add_recurring_commissions_affiliate_group() {

		include 'views/view-recurring-commissions-affiliate-group.php';

	}

	/**
	 * Saves the affiliate specific recurring commissions settings.
	 *
	 * @param int $affiliate_id
	 *
	 */
	public static function save_recurring_commissions_affiliate( $affiliate_id ) {

		if ( ! slicewp_doing_admin_action( 'add_affiliate' ) && ! slicewp_doing_admin_action( 'update_affiliate' ) ) {
			return;
		}

		// Enable recurring commissions.
		if ( ! empty( $_POST['recurring_commissions'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'recurring_commissions', sanitize_text_field( $_POST['recurring_commissions'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'recurring_commissions' );
		}

		// Commissions recurring rates.
		if ( isset( $_POST['commission_rate_recurring'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'commission_rate_recurring', sanitize_text_field( $_POST['commission_rate_recurring'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'commission_rate_recurring' );
		}

		if ( ! empty( $_POST['commission_rate_type_recurring'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'commission_rate_type_recurring', sanitize_text_field( $_POST['commission_rate_type_recurring'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'commission_rate_type_recurring' );
		}

		// Recurrence.
		if ( ! empty( $_POST['commissions_recurrence'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'commissions_recurrence', sanitize_text_field( $_POST['commissions_recurrence'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'commissions_recurrence' );
		}

		// Recurrence limit.
		if( isset( $_POST['commissions_recurrence_limit'] ) ) {
			slicewp_update_affiliate_meta( $affiliate_id, 'commissions_recurrence_limit', absint( $_POST['commissions_recurrence_limit'] ) );
		} else {
			slicewp_delete_affiliate_meta( $affiliate_id, 'commissions_recurrence_limit' );
		}

	}


	/**
	 * Saves the affiliate group specific recurring commissions settings.
	 *
	 * @param int $affiliate_group_id
	 *
	 */
	public static function save_recurring_commissions_affiliate_group( $affiliate_group_id ) {

		if ( ! slicewp_doing_admin_action( 'add_affiliate_group' ) && ! slicewp_doing_admin_action( 'update_affiliate_group' ) ) {
			return;
		}

		// Enable recurring commissions.
		if ( ! empty( $_POST['recurring_commissions'] ) ) {
			slicewp_update_collection_meta( $affiliate_group_id, '_recurring_commissions', sanitize_text_field( $_POST['recurring_commissions'] ) );
		} else {
			slicewp_delete_collection_meta( $affiliate_group_id, '_recurring_commissions' );
		}

		// Commissions recurring rates.
		if ( isset( $_POST['commission_rate_recurring'] ) ) {
			slicewp_update_collection_meta( $affiliate_group_id, '_commission_rate_recurring', sanitize_text_field( $_POST['commission_rate_recurring'] ) );
		} else {
			slicewp_delete_collection_meta( $affiliate_group_id, '_commission_rate_recurring' );
		}

		if ( ! empty( $_POST['commission_rate_type_recurring'] ) ) {
			slicewp_update_collection_meta( $affiliate_group_id, '_commission_rate_type_recurring', sanitize_text_field( $_POST['commission_rate_type_recurring'] ) );
		} else {
			slicewp_delete_collection_meta( $affiliate_group_id, '_commission_rate_type_recurring' );
		}

		// Recurrence.
		if ( ! empty( $_POST['commissions_recurrence'] ) ) {
			slicewp_update_collection_meta( $affiliate_group_id, '_commissions_recurrence', sanitize_text_field( $_POST['commissions_recurrence'] ) );
		} else {
			slicewp_delete_collection_meta( $affiliate_group_id, '_commissions_recurrence' );
		}
			
		// Recurrence limit.
		if( ! empty( $_POST['commissions_recurrence_limit'] ) ) {
			slicewp_update_collection_meta( $affiliate_group_id, '_commissions_recurrence_limit', sanitize_text_field( $_POST['commissions_recurrence_limit'] ) );
		} else {
			slicewp_delete_collection_meta( $affiliate_group_id, '_commissions_recurrence_limit' );
		}

	}
	
}

SliceWP_Admin_Recurring_Commissions::init();