<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Recurring Commissions" add-on class.
 * 
 */
class SliceWP_Add_On_Recurring_Commissions extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'recurring_commissions';

		// Name.
		$this->name = 'Recurring Commissions';

		// Description.
		$this->description = 'Enables you to reward affiliates for recurring payments made by an active subscription.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-recurring-commissions.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/recurring-commissions/';

		// Settings URL.
		$this->settings_url = add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'general' ), admin_url( 'admin.php' ) ) . '#slicewp-card-settings-recurring-commissions';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

		add_action( 'slicewp_activated_add_on', array( $this, 'set_general_settings' ) );

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'base/functions.php',
			'base/abstracts/abstract-class-integration-recurring-commissions.php',
			'base/integrations/easy-digital-downloads/functions.php',
			'base/integrations/getpaid/functions.php',
			'base/integrations/memberpress/functions.php',
			'base/integrations/paid-member-subscriptions/functions.php',
			'base/integrations/paid-memberships-pro/functions.php',
			'base/integrations/restrict-content-pro/functions.php',
			'base/integrations/studiocart/functions.php',
			'base/integrations/surecart/functions.php',
			'base/integrations/upsell/functions.php',
			'base/integrations/woocommerce/functions.php',
			'admin/class-admin-recurring-commissions.php'
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


	/**
     * Registers and enqueues scripts and styles on the admin side.
     * 
     */
    public function enqueue_admin_scripts() {

        // Add-on styles.
		wp_register_style( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-style', $this->get_dir_url() . 'assets/css/style-admin.css', array(), $this->get_parent_plugin_version() );
		wp_enqueue_style( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-style' );

		// Add-on script.
		wp_register_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script', $this->get_dir_url() . 'assets/js/script-admin.js', array( 'jquery', 'slicewp-script' ), $this->get_parent_plugin_version() );
		wp_enqueue_script( 'slicewp-' . esc_attr( str_replace( '_', '-', $this->slug ) ) . '-script' );

    }


	/**
	 * Sets the default general settings on add-on activation.
	 * 
	 * @param string $add_on_slug
	 *
	 */
	public function set_general_settings( $add_on_slug ) {

		if ( $add_on_slug != $this->slug ) {
			return;
		}

		$settings = slicewp_get_option( 'settings', array() );

		if ( ! is_array( $settings ) ) {
			return;
		}

		if ( ! isset( $settings['commission_rate_recurring'] ) ) {
			$settings['commission_rate_recurring'] = 10;
		}

		if ( ! isset( $settings['commission_rate_type_recurring'] ) ) {
			$settings['commission_rate_type_recurring'] = 'percentage';
		}

		if ( ! isset( $settings['commissions_recurrence'] ) ) {
			$settings['commissions_recurrence'] = 'unlimited';
		}

		slicewp_update_option( 'settings', $settings );

	}

}


/**
 * Registers the "Recurring Commissions" add-on.
 * 
 * @param array $add_ons
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_recurring_commissions( $add_ons ) {

	$add_ons['recurring_commissions'] = 'SliceWP_Add_On_Recurring_Commissions';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_recurring_commissions', 100 );