jQuery( function($) {

    /**
     * Activate/Deactivate add-on.
     * 
     */
     $(document).on( 'click', '.slicewp-api-key-settings-wrapper .slicewp-switch.slicewp-is-ajax', function(e) {
        
        e.preventDefault();

        var $this  = $(this);
        var $input = $this.find( 'input' );

        if ( $this.hasClass( 'slicewp-loading' ) ) {
            return false;
        }

        $this.addClass( 'slicewp-loading' );

        // Prepare AJAX call data.
        var data = {
            action        : 'slicewp_action_ajax_' + ( $input.is( ':checked' ) ? 'deactivate' : 'activate' ) + '_api_key',
            api_key_id    : $input.val(),
            slicewp_token : $('#slicewp_token').val()
        }

        $.post( ajaxurl, data, function( response ) {
        
            if ( response === 0 ) {
                return false;
            }

            if ( response.success ) {

                setTimeout( function() {

                    if ( $input.is( ':checked' ) ) {

                        $input.attr( 'checked', false );

                    } else {

                        $input.attr( 'checked', true );

                    }

                    $this.removeClass( 'slicewp-loading' );

                }, 500 );

            } else {

                setTimeout( function() {

                    if ( $input.is( ':checked' ) ) {

                        $input.attr( 'checked', true );

                    } else {

                        $input.attr( 'checked', false );

                    }

                    $this.removeClass( 'slicewp-loading' );
                    
                }, 500 );

            }

        });

    });


    /**
     * Update API keys.
     * 
     */
    var success_message_timeouts = [];

    $(document).on( 'click', '.slicewp-update-api-key', function(e) {

        e.preventDefault();

        var $update_button = $(this);

        if ( $update_button.hasClass( 'slicewp-disabled' ) ) {
            return false;
        }

        var $settings_panel = $update_button.closest( '.slicewp-api-key-settings-panel' );

        // Disable fields and add spinner.
        $settings_panel.find( 'select, input' ).attr( 'disabled', 'disabled' );
        $settings_panel.find( '.slicewp-success-notice' ).hide();
        $update_button.addClass( 'slicewp-disabled' );
        $update_button.after( '<div class="spinner"></div>' );

        // Prepare AJAX call data.
        var data = {
            action              : 'slicewp_action_ajax_update_api_key',
            api_key_id          : $settings_panel.find( '[data-name="api_key_id"]' ).val(),
            api_key_name        : $settings_panel.find( '[data-name="api_key_name"]' ).val(),
            api_key_permissions : $settings_panel.find( '[data-name="api_key_permissions"]' ).val(),
            api_key_user_id     : $settings_panel.find( '[data-name="api_key_user_id"]' ).val(),
            slicewp_token       : $('#slicewp_token').val()
        }

        $.post( ajaxurl, data, function( response ) {
        
            if ( response === 0 ) {
                return false;
            }

            setTimeout( function() {

                if ( response.success ) {

                    // Remove error message.
                    $settings_panel.find( '.slicewp-field-notice.slicewp-field-notice-error' ).remove();

                    // Add success message.
                    $settings_panel.find( '.slicewp-success-notice' ).css( 'display', 'inline-flex' ).hide().fadeIn();

                    // Hide the success message after some time.
                    if ( typeof success_message_timeouts[$settings_panel.find( '[data-name="api_key_id"]' ).val()] != 'undefined' ) {
                        clearTimeout( success_message_timeouts[$settings_panel.find( '[data-name="api_key_id"]' ).val()] );
                    }

                    success_message_timeouts[$settings_panel.find( '[data-name="api_key_id"]' ).val()] = setTimeout( function() {
                        $settings_panel.find( '.slicewp-success-notice' ).fadeOut();
                    }, 2500 );

                } else {

                    // Add error message, if it doesn't exist.
                    if ( $settings_panel.find( '.slicewp-field-notice.slicewp-field-notice-error' ).length == 0 ) {
                        $settings_panel.prepend( '<div class="slicewp-field-notice slicewp-field-notice-error"></div>' );
                    }

                    if ( typeof response.data.message != 'undefined' ) {
                        $settings_panel.find( '.slicewp-field-notice.slicewp-field-notice-error' ).html( response.data.message );
                    }

                }

                $settings_panel.find( 'select, input' ).removeAttr( 'disabled' );
                $settings_panel.find( '.spinner' ).remove();
                $update_button.removeClass( 'slicewp-disabled' );
                
            }, 500 );

        });

    });


    /**
     * Delete API key.
     * 
     */
    $(document).on( 'click', '.slicewp-api-key-settings-wrapper .slicewp-trash', function(e) {

        e.preventDefault();

        // Handle confirmation cases.
        var confirmation = true;

        if ( typeof $(this).attr( 'data-confirmation-message' ) != 'undefined' ) {

            confirmation = confirm( $(this).attr( 'data-confirmation-message' ) );

        }

        if ( confirmation == false ) {
            return false;
        }

        var $link = $(this);
        var $wrapper = $link.closest( '.slicewp-api-key-settings-wrapper' );

        $link.blur();

        // Add spinner.
        $wrapper.append( '<div class="slicewp-overlay"><div class="spinner"></div></div>' );
        $wrapper.find( '.slicewp-overlay' ).fadeIn( 100 );

        // Prepare AJAX call data.
        var data = {
            action        : 'slicewp_action_ajax_delete_api_key',
            api_key_id    : $wrapper.find( '[data-name="api_key_id"]' ).val(),
            slicewp_token : $('#slicewp_token').val()
        }

        $.post( ajaxurl, data, function( response ) {
        
            if ( response === 0 ) {
                return false;
            }

            setTimeout( function() {

                if ( response.success ) {

                    $wrapper.find( '.spinner' ).animate({ opacity: 'toggle' }, 150 );

                    $wrapper.stop( true, false ).animate({ height: 'toggle', opacity: 'toggle' }, 250, function() {
                        $wrapper.remove();
                    });

                    // Show the empty API key panel.
                    if ( $('.slicewp-api-key-settings-wrapper').length == 1 && ! $('#slicewp-api-keys-empty').is( ':visible' ) ) {
                        $('#slicewp-settings-api-keys-header').animate( { height: 'toggle', opacity: 'toggle' }, 150, function() {
                            $('#slicewp-api-keys-empty').animate( { height: 'toggle', opacity: 'toggle' }, 300 );
                        });

                    }

                }
                
            }, 500 );

        });

    });


    /**
     * Show/hide API key settings panel.
     * 
     */
    $(document).on( 'click', '.slicewp-api-key-settings-wrapper .slicewp-expand-item', function(e) {

        e.preventDefault();

        $(this).closest( '.slicewp-api-key-settings-wrapper' ).toggleClass( 'slicewp-active' );
        $(this).closest( '.slicewp-api-key-settings-wrapper' ).find( '.slicewp-api-key-settings-panel' ).slideToggle( 200 );

        $(this).blur();

    });


    /**
     * Change API key name from list header when changing the name from the input field.
     * 
     */
    $(document).on( 'keyup', '[data-name="api_key_name"]', function() {

        $(this).closest( '.slicewp-api-key-settings-wrapper' ).find( '.slicewp-settings-api-key-name > span' ).html( $(this).val() );

    });


    /**
     * Show the add new API key form.
     * 
     */
    $(document).on( 'click', '.slicewp-add-new-api-key', function(e) {

        e.preventDefault();

        var $this = $(this);

        // Show the form.
        $('#slicewp-api-key-form-new').animate( { height: 'toggle', opacity: 'toggle' }, 275 );

        // Transform the button.
        setTimeout( function() {

            $this.find( '.slicewp-add-new-api-key-label' ).hide();
            $this.find( '.slicewp-generate-api-key-label' ).show();

            $this.addClass( 'slicewp-generate-api-key slicewp-button-primary' );
            $this.removeClass( 'slicewp-add-new-api-key slicewp-button-secondary' );

            $this.siblings( '.slicewp-cancel-add-new-api-key' ).fadeIn( 100 );
            
        }, 150 );

        // Focus the first field.
        setTimeout( function() {

            $('#slicewp-new-api-key-name').focus();

        }, 150 );

    });


    /**
     * Hide the add new API key form when clicking on the "Cancel" button.
     * 
     */
    $(document).on( 'click', '.slicewp-cancel-add-new-api-key', function(e) {

        e.preventDefault();

        var $this = $(this);

        $this.fadeOut( 50 );

        // Show the form.
        $('#slicewp-api-key-form-new').animate( { height: 'toggle', opacity: 'toggle' }, 300, function() {
            $('#slicewp-api-key-form-new').find( '.slicewp-field-notice' ).remove();
        });

        // Transform the button.
        setTimeout( function() {

            $this.siblings( '.slicewp-generate-api-key' ).find( '.slicewp-add-new-api-key-label' ).show();
            $this.siblings( '.slicewp-generate-api-key' ).find( '.slicewp-generate-api-key-label' ).hide();

            $this.siblings( '.slicewp-generate-api-key' ).addClass( 'slicewp-add-new-api-key slicewp-button-secondary' );
            $this.siblings( '.slicewp-generate-api-key' ).removeClass( 'slicewp-generate-api-key slicewp-button-primary' );
            
        }, 150 );

    });


    /**
     * Generate new API key.
     * 
     */
    $(document).on( 'click', '.slicewp-generate-api-key', function(e) {

        e.preventDefault();

        var $button = $(this);
        var $form   = $('#slicewp-api-key-form-new');

        if ( $button.hasClass( 'slicewp-disabled' ) ) {
            return false;
        }

        // Disable fields.
        $form.find( 'input, select' ).attr( 'disabled', true );

        // Disable button.
        $button.addClass( 'slicewp-disabled' );

        // Add spinner.
        $button.siblings( '.slicewp-cancel-add-new-api-key' ).fadeOut( 125, function() {

            $button.after( '<div class="spinner"></div>' );
            $button.siblings( '.spinner' ).fadeIn( 125 );

        });

        // Prepare AJAX call data.
        var data = {
            action              : 'slicewp_action_ajax_generate_api_key',
            api_key_name        : $form.find( '[data-name="api_key_name"]' ).val(),
            api_key_permissions : $form.find( '[data-name="api_key_permissions"]' ).val(),
            api_key_user_id     : $form.find( '[data-name="api_key_user_id"]' ).val(),
            slicewp_token       : $('#slicewp_token').val()
        }

        $.post( ajaxurl, data, function( response ) {

            if ( response === 0 ) {
                return false;
            }

            setTimeout( function() {

                if ( response.success ) {

                    // Hide the add new API key form.
                    $form.animate( { height: 'toggle', opacity: 'toggle' }, 300, function() {

                        // Reenable and reset fields.
                        $form.find( 'input' ).val( '' );
                        $form.find( 'input, select' ).removeAttr( 'disabled' );

                        // Append the returned HTML.
                        $('#slicewp-card-api-keys .slicewp-card-inner').append( response.data.html );
                        $('#slicewp-card-api-keys .slicewp-card-inner .slicewp-api-key-settings-wrapper').last().animate( { height: 'toggle', opacity: 'toggle' }, 300 );
                        
                    });

                    // Hide the empty API key panel.
                    if ( $('#slicewp-api-keys-empty').is( ':visible' ) ) {
                        $('#slicewp-api-keys-empty').animate( { height: 'toggle', opacity: 'toggle' }, 300, function() {
                            $('#slicewp-settings-api-keys-header').animate( { height: 'toggle', opacity: 'toggle' }, 300 );
                        });
                    }

                    // Reenable button.
                    $button.removeClass( 'slicewp-disabled' );

                    $button.find( '.slicewp-add-new-api-key-label' ).show();
                    $button.find( '.slicewp-generate-api-key-label' ).hide();

                    $button.addClass( 'slicewp-add-new-api-key slicewp-button-secondary' );
                    $button.removeClass( 'slicewp-generate-api-key slicewp-button-primary' );

                    // Remove spinner.
                    $button.siblings( '.spinner' ).fadeOut( 50, function() {
                        $button.siblings( '.spinner' ).remove();
                    });

                } else {

                    // Add error message, if it doesn't exist.
                    if ( $form.find( '.slicewp-field-notice.slicewp-field-notice-error' ).length == 0 ) {
                        $form.find( 'h3' ).after( '<div class="slicewp-field-notice slicewp-field-notice-error"></div>' );
                    }

                    if ( typeof response.data.message != 'undefined' ) {
                        $form.find( '.slicewp-field-notice.slicewp-field-notice-error' ).html( response.data.message );
                    }

                    // Reenable the fields.
                    $form.find( 'input, select' ).removeAttr( 'disabled' );

                    // Reenable the button.
                    $button.removeClass( 'slicewp-disabled' );

                    // Remove spinner and show the cancel button.
                    $button.siblings( '.spinner' ).fadeOut( 50, function() {

                        $button.siblings( '.spinner' ).remove();

                        $button.siblings( '.slicewp-cancel-add-new-api-key' ).fadeIn( 125 );

                    });
                    
                }

            }, 500 );

        });

    });

});