<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

$api_keys = slicewp_get_api_keys( array( 'number' => -1, 'order' => 'ASC' ) );

if ( ! empty( $api_keys ) ) {

    foreach ( $api_keys as $index => $api_key ) {

        $user = get_userdata( absint( $api_key->get( 'user_id' ) ) );

        if ( ! $user ) {
            unset( $api_keys[$index] );
        }

    }

    $api_keys = array_values( $api_keys );

}

?>

<div id="slicewp-card-api-keys" class="slicewp-card">

	<div class="slicewp-card-header">
		<span class="slicewp-card-title"><?php echo __( 'API Keys', 'slicewp' ); ?></span>
	</div>

	<div class="slicewp-card-inner">

        <div id="slicewp-api-keys-empty" <?php echo ( ! empty( $api_keys ) ? 'style="display: none;"' : '' ); ?>>
            <div>
                <p><?php echo __( "You currently don't have any API keys.", 'slicewp' ); ?></p>
            </div>
        </div>

        <div id="slicewp-settings-api-keys-header" class="slicewp-tooltip-wide" <?php echo ( empty( $api_keys ) ? 'style="display: none;"' : '' ); ?>>
            <div class="slicewp-settings-api-key-name"><?php echo __( 'Name', 'slicewp' ); ?></div>
            <div class="slicewp-settings-api-key-consumer-key"><?php echo __( 'Consumer Key', 'slicewp' ); ?> <?php echo slicewp_output_tooltip( __( 'For security reasons, API keys are no longer accessible after creation. If you lose a key, you will need to generate a new one and update any integration that uses it.', 'slicewp' ) ); ?></div>
            <div class="slicewp-settings-api-key-actions"><!-- --></div>
        </div>

        <?php foreach( $api_keys as $api_key ): ?>

            <div class="slicewp-api-key-settings-wrapper slicewp-expandable-item">

                <div class="slicewp-api-key-settings-header">

                    <div class="slicewp-settings-api-key-name">

                        <div class="slicewp-switch slicewp-is-ajax">

							<span class="slicewp-loader"></span>

							<input id="slicewp-enable-api-key-<?php echo absint( $api_key->get( 'id' ) ); ?>" class="slicewp-toggle slicewp-toggle-round" name="" type="checkbox" value="<?php echo absint( $api_key->get( 'id' ) ); ?>" <?php echo ( $api_key->get( 'status' ) == 'active' ? 'checked="checked"' : '' ); ?> />
							<label for="slicewp-enable-api-key-<?php echo absint( $api_key->get( 'id' ) ); ?>"></label>

						</div>

                        <span><?php echo $api_key->get( 'name' ); ?></span>

                    </div>

                    <div class="slicewp-settings-api-key-consumer-key"><?php echo substr_replace( $api_key->get( 'consumer_key' ), '******', 5, strlen( $api_key->get( 'consumer_key' ) ) - 10 ); ?></div>

                    <div class="slicewp-settings-api-key-actions">
                        <a href="#" class="slicewp-expand-item"><?php echo __( 'Details', 'slicewp' ); ?><?php echo slicewp_get_svg( 'outline-chevron-down' ); ?></a>
                        <a href="#" class="slicewp-trash" data-confirmation-message="<?php echo __( 'Are you sure you want to delete this API key? Any integrations using it will stop working.', 'slicewp' ); ?>"><?php echo __( 'Delete', 'slicewp' ); ?></a>
                    </div>

                </div>

                <div class="slicewp-api-key-settings-panel">

                    <!-- API key ID -->
                    <input type="hidden" data-name="api_key_id" value="<?php echo absint( $api_key->get( 'id' ) ); ?>" />
                    <!-- / API key name -->
                    
                    <!-- API key name -->
                    <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

                        <div class="slicewp-field-label-wrapper">
                            <label for="slicewp-api-key-name-<?php echo absint( $api_key->get( 'id' ) ); ?>"><?php echo __( 'Name', 'slicewp' ); ?> *</label>
                            <?php echo slicewp_output_tooltip( __( 'Friendly name for identifying this key.', 'slicewp' ) ); ?>
                        </div>

                        <input id="slicewp-api-key-name-<?php echo absint( $api_key->get( 'id' ) ); ?>" type="text" value="<?php echo esc_attr( $api_key->get( 'name' ) ); ?>" data-name="api_key_name" />

                    </div>
                    <!-- / API key name -->

                    <!-- API key owner (user_id) -->
                    <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

                        <div class="slicewp-field-label-wrapper slicewp-tooltip-wide">
                            <label><?php echo __( 'Owner', 'slicewp' ); ?> *</label>
                            <?php echo slicewp_output_tooltip( __( 'The selected user will be used for authentication when attempting API calls. This user must have an administrator role.', 'slicewp' ) ); ?>
                        </div>

                        <?php slicewp_output_select2_user_search( array( 'id' => 'slicewp-api-key-user-id-' . absint( $api_key->get( 'id' ) ), 'name' => 'user_id', 'placeholder' => __( 'Select user...', 'slicewp' ), 'user_role' => 'administrator', 'data_attributes' => array( 'name' => 'api_key_user_id' ), 'value' => absint( $api_key->get( 'user_id' ) ) ) ); ?>

                    </div>
                    <!-- / API key owner (user_id) -->

                    <!-- API key permissions -->
                    <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

                        <div class="slicewp-field-label-wrapper">
                            <label><?php echo __( 'Permissions', 'slicewp' ); ?> *</label>
                            <?php echo slicewp_output_tooltip( __( 'Select the access type of this key.', 'slicewp' ) ); ?>
                        </div>

                        <select data-name="api_key_permissions" class="slicewp-select2">
                            <option value="read" <?php echo ( $api_key->get( 'permissions' ) == 'read' ? 'selected="selected"' : '' ); ?>><?php echo __( 'Read', 'slicewp' ); ?></option>
                            <option value="write" <?php echo ( $api_key->get( 'permissions' ) == 'write' ? 'selected="selected"' : '' ); ?>><?php echo __( 'Write', 'slicewp' ); ?></option>
                            <option value="read_write" <?php echo ( $api_key->get( 'permissions' ) == 'read_write' ? 'selected="selected"' : '' ); ?>><?php echo __( 'Read/Write', 'slicewp' ); ?></option>
                        </select>

                    </div>
                    <!-- / API key permissions -->

                    <!-- API key date created -->
                    <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

                        <div class="slicewp-field-label-wrapper">
                            <label><?php echo __( 'Created at', 'slicewp' ); ?></label>
                        </div>

                        <input type="text" value="<?php echo esc_attr( slicewp_date_i18n( $api_key->get( 'date_created' ) ) ); ?>" disabled />

                    </div>
                    <!-- / API key date created -->

                    <div class="slicewp-api-key-settings-panel-footer">
                        <a href="#" class="slicewp-button-primary slicewp-update-api-key"><?php echo __( 'Update API key', 'slicewp' ); ?></a>
                        <span class="slicewp-success-notice"><?php echo slicewp_get_svg( 'solid-check-circle' ) . __( 'Updated successfully!', 'slicewp' ); ?></span>
                    </div>

                </div>

            </div>

        <?php endforeach; ?>

	</div>

	<div class="slicewp-card-footer">

        <!-- Add new API key form -->
        <div id="slicewp-api-key-form-new">

            <h3><?php echo __( 'Add new API key', 'slicewp' ); ?></h3>

            <!-- API key name -->
            <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

                <div class="slicewp-field-label-wrapper">
                    <label for="slicewp-new-api-key-name"><?php echo __( 'Name', 'slicewp' ); ?> *</label>
                    <?php echo slicewp_output_tooltip( __( 'Friendly name for identifying this key.', 'slicewp' ) ); ?>
                </div>

                <input id="slicewp-new-api-key-name" type="text" value="" data-name="api_key_name" />

            </div>
            <!-- / API key name -->

            <!-- API key owner (user_id) -->
            <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

                <div class="slicewp-field-label-wrapper slicewp-tooltip-wide">
                    <label><?php echo __( 'Owner', 'slicewp' ); ?> *</label>
                    <?php echo slicewp_output_tooltip( __( 'The selected user will be used for authentication when attempting API calls. This user must have an administrator role.', 'slicewp' ) ); ?>
                </div>

                <?php slicewp_output_select2_user_search( array( 'id' => 'slicewp-new-api-key-user-id', 'name' => 'user_id', 'placeholder' => __( 'Select user...', 'slicewp' ), 'user_role' => 'administrator', 'data_attributes' => array( 'name' => 'api_key_user_id' ), 'value' => absint( get_current_user_id() ) ) ); ?>

            </div>
            <!-- / API key owner (user_id) -->

            <!-- API key permissions -->
            <div class="slicewp-field-wrapper slicewp-field-wrapper-inline">

                <div class="slicewp-field-label-wrapper">
                    <label><?php echo __( 'Permissions', 'slicewp' ); ?> *</label>
                    <?php echo slicewp_output_tooltip( __( 'Select the access type of this key.', 'slicewp' ) ); ?>
                </div>

                <select data-name="api_key_permissions" class="slicewp-select2">
                    <option value="read"><?php echo __( 'Read', 'slicewp' ); ?></option>
                    <option value="write"><?php echo __( 'Write', 'slicewp' ); ?></option>
                    <option value="read_write"><?php echo __( 'Read/Write', 'slicewp' ); ?></option>
                </select>

            </div>
            <!-- / API key permissions -->

        </div>
        <!-- / Add new API key form -->

		<div class="slicewp-flex">

			<a href="#" class="slicewp-add-new-api-key slicewp-button-secondary">
                <span class="slicewp-add-new-api-key-label"><?php echo __( 'Add new API key', 'slicewp' ); ?></span>
                <span class="slicewp-generate-api-key-label"><?php echo __( 'Generate API key', 'slicewp' ); ?></span>
            </a>

            <a href="#" class="slicewp-cancel-add-new-api-key slicewp-button-tertiary"><?php echo __( 'Cancel', 'slicewp' ); ?></a>

		</div>

	</div>

</div>