<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * @todo maybe add "count" parameter to return just the count
 * 
 */


/**
 * Abstract class for the REST API controller.
 * 
 */
abstract class SliceWP_REST_API_Controller {

    /**
	 * Endpoint namespace.
	 *
	 * @var    string
     * @access protected
     * 
	 */
    protected $namespace = 'slicewp/v1';

    /**
	 * Route base.
	 *
	 * @var    string
     * @access protected
     * 
	 */
    protected $rest_base = '';


    /**
     * Constructor.
     * 
     */
    public function __construct() {

        add_action( 'rest_api_init', array( $this, 'register_routes' ) );

    }

    /**
     * Registers the different routes.
     * 
     */
    public function register_routes() {}

    /**
     * Returns an array of objects data as a rest response.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function get_item( $request ) {}

    /**
     * Returns the object data for the given ID as a rest response.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function get_items( $request ) {}

    /**
     * Delete the object with the given ID.
     * 
     * @param WP_REST_Request $request
     * 
     */
    public function delete_item( $request ) {}

    /**
     * Callback for the permissions check.
     * 
     * @return bool
     * 
     */
    public function permissions_check() {

        return current_user_can( 'manage_options' );

    }

    /**
	 * Return only writable props from given schema.
	 *
	 * @param array $schema
     * 
	 * @return bool
     * 
	 */
    protected function filter_writable_properties( $schema ) {

        return empty( $schema['readonly'] );

    }

    /**
     * Validates if the provided argument is of type URL.
     * 
     * @param mixed $value
     * 
     * @return bool|WP_Error
     * 
     */
    public function validate_request_arg_url( $value ) {

        if ( filter_var( $value, FILTER_VALIDATE_URL ) === false ) {
            return new WP_Error( 'rest_invalid_url', 'Invalid URL.' );
        }

        return true;

    }


    /**
     * Unserializez meta data, preparing it for response.
     * 
     * @param array $meta_data
     * 
     * @return array
     * 
     */
    protected function prepare_item_meta_for_response( $meta_data ) {

        if ( ! is_array( $meta_data ) ) {
            return $meta_data;
        }

        foreach ( $meta_data as $meta_key => $meta_values ) {

            if ( is_array( $meta_values ) ) {
                $meta_data[$meta_key] = array_map( 'maybe_unserialize', $meta_values );
            } else {
                $meta_data[$meta_key] = maybe_unserialize( $meta_values );
            }

        }

        return $meta_data;

    }

}