<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Class that handles database queries for the API keys.
 *
 */
Class SliceWP_Object_DB_API_Keys extends SliceWP_Object_DB {
	
	/**
	 * Construct.
	 *
	 */
	public function __construct() {

		global $wpdb;

		$this->table_name 		 = $wpdb->prefix . 'slicewp_api_keys';
		$this->primary_key 		 = 'id';
		$this->context 	  		 = 'api_key';
		$this->query_object_type = 'SliceWP_API_Key';

	}


	/**
	 * Return the table columns.
	 *
	 */
	public function get_columns() {

		return array(
			'id' 		          => '%d',
			'user_id'	          => '%d',
            'name'                => '%s',
			'consumer_key'        => '%s',
            'consumer_secret'     => '%s',
            'permissions'         => '%s',
			'status'		      => '%s',
			'date_created' 	      => '%s',
			'date_modified'       => '%s'
		);

	}


	/**
	 * Returns an array of SliceWP_API_KEy objects from the database.
	 *
	 * @param array $args
	 * @param bool  $count - whether to return just the count for the query or not
	 *
	 * @return mixed array|int
	 *
	 */
	public function get_api_keys( $args = array(), $count = false ) {

		global $wpdb;

		$defaults = array(
			'number'       => 20,
			'offset'       => 0,
			'orderby'      => 'id',
			'order'        => 'DESC',
			'user_id'	   => 0,
			'consumer_key' => '',
            'status'       => ''
		);

		$args = wp_parse_args( $args, $defaults );

		/**
		 * Filter the query arguments just before making the db call
		 *
		 * @param array $args
		 *
		 */
		$args = apply_filters( 'slicewp_get_api_keys_args', $args );

		// Number args
		if ( $args['number'] < 1 ) {
            $args['number'] = 999999;
        }

		// Join clause.
		$join = '';

		// Where clause.
		$where = "WHERE 1=1";

		// User ID where clause.
		if ( ! empty( $args['user_id'] ) ) {

			$user_id = absint( $args['user_id'] );
			$where  .= " AND user_id = '{$user_id}'";

		}

        // Consumer KEY where clause.
        if ( ! empty( $args['consumer_key'] ) ) {

            $consumer_key = sanitize_text_field( $args['consumer_key'] );
			$where       .= " AND consumer_key = '{$consumer_key}'";

        }

		// Include date_min filter in where clause.
		if ( ! empty( $args['date_min'] )) {

			$date_min =  sanitize_text_field( $args['date_min']);
			$where  .= " AND date_created >= '{$date_min}' ";

		}

		// Include date_max filter in where clause.
		if ( ! empty( $args['date_max'] )) {

			$date_max =  sanitize_text_field( $args['date_max']);
			$where  .= " AND date_created <= '{$date_max}' ";

		}

		// Orderby.
		$orderby = sanitize_text_field( $args['orderby'] );

		// Order.
		$order = ( 'DESC' === strtoupper( $args['order'] ) ? 'DESC' : 'ASC' );

		$clauses = compact( 'where', 'join', 'orderby', 'order', 'count' );

		$results = $this->get_results( $clauses, $args, 'slicewp_get_api_key' );

		return $results;

	}

	
	/**
	 * Creates and updates the database table for the API keys.
	 *
	 */
	public function create_table() {

		global $wpdb;

		$table_name 	 = $this->table_name;
		$charset_collate = $wpdb->get_charset_collate();

		$query = "CREATE TABLE {$table_name} (
			id bigint(20) NOT NULL AUTO_INCREMENT,
			user_id bigint(20) NOT NULL,
            name tinytext NOT NULL,
            consumer_key tinytext NOT NULL,
            consumer_secret tinytext NOT NULL,
            permissions tinytext NOT NULL,
            status tinytext NOT NULL,
			date_created datetime NOT NULL,
			date_modified datetime NOT NULL,
			PRIMARY KEY  id (id)
		) {$charset_collate};";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $query );

	}

}