<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Register the class that handles database queries for the API keys.
 *
 * @param array $classes
 *
 * @return array
 *
 */
function slicewp_register_database_classes_api_keys( $classes ) {

	$classes['api_keys'] = 'SliceWP_Object_DB_API_Keys';

	return $classes;

}
add_filter( 'slicewp_register_database_classes', 'slicewp_register_database_classes_api_keys' );


/**
 * Returns an array with SliceWP_API_Key objects from the database.
 *
 * @param array $args
 * @param bool  $count
 *
 * @return array
 *
 */
function slicewp_get_api_keys( $args = array(), $count = false ) {

	$api_keys = slicewp()->db['api_keys']->get_api_keys( $args, $count );

	/**
	 * Add a filter hook just before returning
	 *
	 * @param array $api_keys
	 * @param array $args
	 * @param bool  $count
	 *
	 */
	return apply_filters( 'slicewp_get_api_keys', $api_keys, $args, $count );

}


/**
 * Gets an API key from the database.
 *
 * @param mixed int|object
 *
 * @return SliceWP_API_Key|null
 *
 */
function slicewp_get_api_key( $api_key ) {

	return slicewp()->db['api_keys']->get_object( $api_key );

}


/**
 * Gets an API key from the database, based on the provided consumer_key value.
 * 
 * @param string $consumer_key
 * 
 * @return SliceWP_API_Key|null
 * 
 */
function slicewp_get_api_key_by_consumer_key( $consumer_key ) {

    $api_keys = slicewp_get_api_keys( array( 'consumer_key' => $consumer_key ) );

	if ( empty( $api_keys ) ) {
        return null;
    }

	if ( ! $api_keys[0] instanceof SliceWP_API_Key ) {
        return null;
    }

	return $api_keys[0];

}


/**
 * Inserts a new API key into the database.
 *
 * @param array $data
 *
 * @return mixed int|false
 *
 */
function slicewp_insert_api_key( $data ) {

	return slicewp()->db['api_keys']->insert( $data );

}


/**
 * Updates a API key in the database.
 *
 * @param int 	$api_key_id
 * @param array $data
 *
 * @return bool
 *
 */
function slicewp_update_api_key( $api_key_id, $data ) {

	return slicewp()->db['api_keys']->update( $api_key_id, $data );

}


/**
 * Deletes an API key from the database.
 *
 * @param int $api_key_id
 *
 * @return bool
 *
 */
function slicewp_delete_api_key( $api_key_id ) {

	return slicewp()->db['api_keys']->delete( $api_key_id );

}