<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * @todo add leads api controller
 * 
 */

/**
 * "REST API" add-on class.
 * 
 */
class SliceWP_Add_On_REST_API extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'rest_api';

		// Name.
		$this->name = 'REST API';

		// Description.
		$this->description = 'The REST API adds Get, Create, Update and Delete operations, offering developers and external applications control over the affiliate datasets.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-rest-api.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/rest-api/';

		// Settings URL.
		$this->settings_url = add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'tools' ), admin_url( 'admin.php' ) ) . '#slicewp-card-api-keys';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

        add_action( 'slicewp_activated_add_on', array( $this, 'set_forced_core_update' ) );
		add_filter( 'slicewp_update_check_do_update', array( $this, 'do_forced_core_update' ) );

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		$files = array(
            'base/abstracts/abstract-class-rest-api-controller.php',
            'base/api-controllers/class-rest-api-controller-affiliates.php',
            'base/api-controllers/class-rest-api-controller-commissions.php',
            'base/api-controllers/class-rest-api-controller-visits.php',
            'base/api-controllers/class-rest-api-controller-customers.php',
            'base/api-controllers/class-rest-api-controller-payouts.php',
            'base/api-controllers/class-rest-api-controller-payments.php',
            'base/api-keys/class-api-key.php',
            'base/api-keys/class-object-db-api-keys.php',
            'base/api-keys/functions.php',
            'base/class-api-auth.php',
            'admin/functions.php',
            'admin/functions-actions-ajax.php',
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}


    /**
	 * Set force update core on add-on activation.
	 * 
	 * @param string $add_on_slug
	 * 
	 */
	public function set_forced_core_update( $add_on_slug ) {

		if ( $add_on_slug != $this->slug ) {
			return;
		}

		slicewp_update_option( 'force_core_update', 1 );

	}


	/**
	 * Force update core procedure if needed.
	 * 
	 * @param bool $do_update
	 * 
	 * @return bool
	 * 
	 */
	public function do_forced_core_update( $do_update ) {

		if ( ! $this->is_active() ) {
			return $do_update;
		}

		$_do_update = slicewp_get_option( 'force_core_update' );

		if ( ! empty( $_do_update ) ) {

			$do_update = true;

			slicewp_update_option( 'force_core_update', '' );
			
		}

		return $do_update;

	}

}


/**
 * Registers the "Store Credit" add-on.
 * 
 * @param array $add_ons
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_rest_api( $add_ons ) {

	$add_ons['rest_api'] = 'SliceWP_Add_On_REST_API';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_rest_api', 220 );