<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Include the affiliate store credit balance field in the admin affiliate add/edit forms.
 * 
 * @param string $form
 * 
 */
function slicewp_affiliate_form_field_store_credit_balance( $form ) {

    if ( ! in_array( $form, array( 'add_affiliate', 'edit_affiliate' ) ) ) {
		return;
	}

    include_once 'views/form-field-store-credit-balance.php';

}
add_action( 'slicewp_admin_form_fields', 'slicewp_affiliate_form_field_store_credit_balance' );


/**
 * Include the do single payment card.
 * 
 */
function slicewp_view_payouts_review_payment_bottom_do_single_payment_store_credit() {

	include_once 'views/view-payouts-do-single-payment.php';

}
add_action( 'slicewp_view_payouts_review_payment_bottom', 'slicewp_view_payouts_review_payment_bottom_do_single_payment_store_credit' );


/**
 * Register admin notices sent via the URL.
 * 
 */
function slicewp_register_query_url_admin_notices_store_credit() {

	// Because we are on "admin_init", make sure core is active.
	if ( ! function_exists( 'slicewp' ) ) {
		return;
	}

	if ( empty( $_GET['slicewp_message'] ) ) {
		return;
	}

	// Single payment success.
	slicewp_admin_notices()->register_notice( 'payout_single_payment_store_credit_success', '<p>' . __( "The payment has been marked as paid and the affiliate's store credit balance has been updated.", 'slicewp' ) . '</p>' );

	// Bulk payments success.
	slicewp_admin_notices()->register_notice( 'payout_bulk_payments_store_credit_success', '<p>' . __( 'The payments have been marked as paid and the store credit balance of affiliates have been updated.', 'slicewp' ) . '</p>' );

}
add_action( 'admin_init', 'slicewp_register_query_url_admin_notices_store_credit' );


/**
 * Adds the "Pay with Store Credit" option to the payments tables.
 * 
 * @param array $row_actions
 * @param array $item
 * 
 * @return array
 * 
 */
function slicewp_list_table_payments_row_actions_store_credit( $row_actions, $item ) {

	if ( 'store_credit' != $item['payout_method'] ) {
		return $row_actions;
	}

	if ( 'paid' == $item['status'] ) {
		return $row_actions;
	}

	$row_actions = array_reverse( $row_actions );

    $payout_methods = slicewp_get_payout_methods();
	$confirmation   = ( ! empty( $payout_methods['store_credit']['messages']['payout_action_confirmation_single_payment'] ) ? $payout_methods['store_credit']['messages']['payout_action_confirmation_single_payment'] : '' );

    $row_actions['pay_with_store_credit'] = '<a ' . ( ! empty( $confirmation ) ? 'onclick="return confirm(' . esc_attr( '"' . $confirmation . '"' ) . ');"' : '' ) . ' href="' . esc_url( wp_nonce_url( add_query_arg( array( 'slicewp_action' => 'do_single_payment', 'payout_method' => 'store_credit', 'payment_id' => $item['id'] ) ), 'slicewp_do_single_payment', 'slicewp_token' ) ) . '">' . __( 'Pay in Store Credit', 'slicewp' ) . '</a>';

	$row_actions = array_reverse( $row_actions );

	return $row_actions;

}
add_filter( 'slicewp_list_table_payout_payments_row_actions', 'slicewp_list_table_payments_row_actions_store_credit', 15, 2 );
add_filter( 'slicewp_list_table_payments_row_actions', 'slicewp_list_table_payments_row_actions_store_credit', 15, 2 );


/**
 * Adds extra HTML after the "Payout Method" field found in the do bulk payments admin form.
 * 
 * @param int $payout_id
 * 
 */
function slicewp_form_do_bulk_payments_payout_method_bottom_store_credit( $payout_id ) {

	if ( empty( $payout_id ) ) {
		return;
	}

    $payments = slicewp_get_payments( array( 'number' => -1, 'payout_id' => $payout_id, 'payout_method' => 'store_credit', 'status' => 'unpaid', 'fields' => 'amount' ) );

    if ( empty( $payments ) ) {
		return;
	}

    ?>

        <div class="slicewp-select2-option-selection-description" data-option="store_credit">
            <p><?php echo sprintf( _n( 'There is %d unpaid payment in this payout, totaling %s, that can be paid in store credit.', 'There are %d unpaid payments in this payout, totaling %s, that can be paid in store credit.', count( $payments ), 'slicewp' ), count( $payments ), slicewp_format_amount( array_sum( $payments ), slicewp_get_setting( 'active_currency', 'USD' ) ) ); ?></p>
            <p><?php echo __( 'By clicking the button below, the amount of these payments will be added to the affiliates as store credit.', 'slicewp' ) ?></p>
        </div>

    <?php

}
add_action( 'slicewp_form_do_bulk_payments_payout_method_bottom', 'slicewp_form_do_bulk_payments_payout_method_bottom_store_credit' );


/**
 * Update the affiliate's store credit balance on admin add/update affiliate.
 * 
 * @param int $affiliate_id
 * 
 */
function slicewp_admin_action_save_user_store_credit_balance( $affiliate_id ) {

    if ( ! doing_action( 'slicewp_admin_action_add_affiliate' ) && ! doing_action( 'slicewp_admin_action_update_affiliate' ) ) {
		return;
	}

    if ( ! isset( $_POST['user_store_credit'] ) ) {
		return;
	}

    slicewp_update_affiliate_store_credit_balance( $affiliate_id, sanitize_text_field( $_POST['user_store_credit'] ) );

}
add_action( 'slicewp_insert_affiliate', 'slicewp_admin_action_save_user_store_credit_balance' );
add_action( 'slicewp_update_affiliate', 'slicewp_admin_action_save_user_store_credit_balance' );