<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Handles "store_credit" single payment.
 *
 * @param int $payment_id
 *
 */
function slicewp_do_single_payment_store_credit( $payment_id ) {

	$payment = slicewp_get_payment( $payment_id );

    if ( is_null( $payment ) ) {
        return;
    }

    if ( ! in_array( $payment->get( 'status' ), array( 'unpaid', 'requested' ) ) ) {
        return;
    }

    // Prepare payment data.
    $payment_data = array(
        'status' 		=> 'paid',
        'date_modified' => slicewp_mysql_gmdate()
    );

    // Update payment to paid.
    $updated = slicewp_update_payment( $payment->get( 'id' ), $payment_data );

    if ( ! $updated ) {

        slicewp_admin_notices()->register_notice( 'do_single_payment_store_credit_fail', '<p>' . __( 'Something went wrong. Could not pay affiliate in store credit. Please try again.', 'slicewp' ) . '</p>', 'error' );
        slicewp_admin_notices()->display_notice( 'do_single_payment_store_credit_fail' );

        return;

    }

    // Increase the affiliate's store credit balance.
    slicewp_increase_affiliate_store_credit_balance( $payment->get( 'affiliate_id' ), $payment->get( 'amount' ) );

    // Update all commissions to paid.
    $commission_ids = slicewp_get_commissions( array( 'number' => -1, 'payment_id' => $payment_id, 'fields' => 'id' ) );
    $commission_ids = array_map( 'absint', $commission_ids );

    foreach ( $commission_ids as $commission_id ) {

        $commission_data = array(
            'date_modified' => slicewp_mysql_gmdate(),
            'status'		=> 'paid'
        );

        slicewp_update_commission( $commission_id, $commission_data );
    
    }

	// Redirect to the current page.
	wp_redirect( remove_query_arg( array( 'slicewp_action', 'slicewp_token', 'payout_method' ), add_query_arg( array( 'slicewp_message' => 'payout_single_payment_store_credit_success' ) ) ) );
	exit;

}
add_action( 'slicewp_do_single_payment_store_credit', 'slicewp_do_single_payment_store_credit', 50 );


/**
 * Handles "store_credit" bulk payments.
 *
 * @param int $payout_id
 *
 */
function slicewp_do_bulk_payments_store_credit( $payout_id ) {

	$payments = slicewp_get_payments( array( 'number' => -1, 'payout_id' => $payout_id, 'payout_method' => 'store_credit', 'status' => array( 'unpaid', 'requested' ) ) );

	// Go through each payment and pay with store credit.
	foreach ( $payments as $payment ) {

		// Update payment.
		$payment_data = array(
			'date_modified' => slicewp_mysql_gmdate(),
			'status' 		=> 'paid'
		);

		$updated = slicewp_update_payment( $payment->get( 'id' ), $payment_data );

		// If the payment wasn't updated, go to next payment.
		if ( ! $updated ) {
            continue;
        }

        // Increase the affiliate's store credit balance.
        slicewp_increase_affiliate_store_credit_balance( $payment->get( 'affiliate_id' ), $payment->get( 'amount' ) );

		// If the payment was updated, update each of the generated commissions.
		$commission_ids = slicewp_get_commissions( array( 'number' => -1, 'payment_id' => $payment->get( 'id' ), 'fields' => 'id' ) );
		$commission_ids = array_map( 'absint', $commission_ids );

		foreach ( $commission_ids as $commission_id ) {

            $commission_data = array(
                'date_modified' => slicewp_mysql_gmdate(),
                'status'		=> 'paid'
            );

			$updated = slicewp_update_commission( $commission_id, $commission_data );
		
		}

	}

	// Redirect to the current page.
	wp_redirect( add_query_arg( array( 'page' => 'slicewp-payouts', 'subpage' => 'view-payout', 'payout_id' => absint( $payout_id ), 'slicewp_message' => 'payout_bulk_payments_store_credit_success' ), admin_url( 'admin.php' ) ) );
	exit;

}
add_action( 'slicewp_do_bulk_payments_store_credit', 'slicewp_do_bulk_payments_store_credit', 10, 2 );