<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * "Store Credit" add-on class.
 * 
 */
class SliceWP_Add_On_Store_Credit extends SliceWP_Add_On {

	/**
	 * Constructor.
	 * 
	 */
	public function __construct() {

		// Slug.
		$this->slug = 'store_credit';

		// Name.
		$this->name = 'Store Credit for WooCommerce';

		// Description.
		$this->description = 'Pay your affiliates with store credit, that they can then use to make discounted purchases from your WooCommerce store.';

		// Icon URL.
		$this->icon_url = $this->get_dir_url() . 'assets/img/add-on-icon-store-credit.png';

		// Documentation URL.
		$this->documentation_url = 'https://slicewp.com/products/store-credit/';

		// Settings URL.
		$this->settings_url = add_query_arg( array( 'page' => 'slicewp-settings', 'tab' => 'general' ), admin_url( 'admin.php' ) ) . '#slicewp-card-payouts-settings';

		// Author information.
		$this->author 	  = 'SliceWP';
		$this->author_url = 'https://slicewp.com/';

		parent::__construct();

	}


	/**
	 * Include files.
	 * 
	 */
	protected function include_files() {

		// If the legacy add-on is active, don't load any files.
		if ( _slicewp_is_legacy_single_add_on_active( $this->slug ) ) {
			return;
		}

		$files = array(
			'base/functions.php',
			'base/functions-actions.php',
			'integrations/class-integration-woocommerce.php',
			'admin/functions.php'
		);
 
		foreach ( $files as $file ) {

			include plugin_dir_path( __FILE__ ) . 'includes/' . $file;

		}

	}

}


/**
 * Registers the "Store Credit" add-on.
 * 
 * @param array $add_ons
 * 
 * @return array
 * 
 */
function slicewp_register_add_on_store_credit( $add_ons ) {

	$add_ons['store_credit'] = 'SliceWP_Add_On_Store_Credit';

	return $add_ons;

}
add_filter( 'slicewp_register_add_on', 'slicewp_register_add_on_store_credit', 70 );