jQuery( function($) {

	/**
     * Strips one query argument from a given URL string
     *
     */
    function remove_query_arg( key, sourceURL ) {

        var rtn = sourceURL.split("?")[0],
            param,
            params_arr = [],
            queryString = (sourceURL.indexOf("?") !== -1) ? sourceURL.split("?")[1] : "";

        if (queryString !== "") {
            params_arr = queryString.split("&");
            for (var i = params_arr.length - 1; i >= 0; i -= 1) {
                param = params_arr[i].split("=")[0];
                if (param === key) {
                    params_arr.splice(i, 1);
                }
            }

            rtn = rtn + "?" + params_arr.join("&");

        }

        if(rtn.split("?")[1] == "") {
            rtn = rtn.split("?")[0];
        }

        return rtn;
    }


    /**
     * Adds an argument name, value pair to a given URL string
     *
     */
    function add_query_arg( key, value, sourceURL ) {

        sourceURL = remove_query_arg( key, sourceURL );

        return sourceURL + '&' + key + '=' + value;

    }


    /**
     * The function will change the filter dates based on the dropdown selection
     *
     */
    var period_select_flag = null;

    $(document).on( 'change', '#slicewp-reports-period-select', function(e) {

        var today       = new Date();
        var start_date  = '';

        var day_in_ms   = 24 * 60 * 60 * 1000;

        var today_year  = today.getFullYear();
        var today_month = today.getMonth() + 1;
        var today_date  = today.getDate();


        if ( $(this).val() == 'last_seven_days' ) {

            start_date = new Date( today - day_in_ms * 6 );
            end_date = today;

        }

        if ( $(this).val() == 'last_thirty_days' ) {

            start_date = new Date( today - day_in_ms * 29 );
            end_date = today;

        }

        if ( $(this).val() == 'this_month' ) {

            start_date = new Date( today - day_in_ms * ( today_date - 1 ) );
            end_date = today;

        }

        if ( $(this).val() == 'last_month' ) {

            end_date = new Date( today - day_in_ms * today_date );

            start_date_year = end_date.getFullYear();
            start_date_month = end_date.getMonth();

            start_date = new Date( start_date_year, start_date_month );

        }

        if ( $(this).val() == 'last_three_months' ) {

            end_date = new Date( today - day_in_ms * today_date );

            start_date_year = end_date.getFullYear();
            start_date_month = end_date.getMonth();

            start_date = new Date( start_date_year, start_date_month-2 );

        }

        if ( $(this).val() == 'last_six_months' ) {

            end_date = new Date( today - day_in_ms * today_date );

            start_date_year = end_date.getFullYear();
            start_date_month = end_date.getMonth();

            start_date = new Date( start_date_year, start_date_month-5 );

        }

        if ( $(this).val() == 'this_year' ) {

            end_date = today;
            start_date = new Date( today_year, 0, 1 );

        }
        
        if ( $(this).val() == 'last_year' ) {

            end_date = new Date( today_year-1, 11, 31 );
            start_date = new Date( today_year-1, 0, 1 );

        }

        // Hide the custom periods fields
        $('#slicewp-reports-period-start-wrapper').hide();
        $('#slicewp-reports-period-end-wrapper').hide();

        if ( $(this).val() == 'custom' ) {

            // Show the custom periods fields
            $('#slicewp-reports-period-start-wrapper').show();
            $('#slicewp-reports-period-end-wrapper').show();

            if( period_select_flag === false )
                $('#slicewp-reports-period-start').focus();
        
        }

        if ( start_date != '' ) {

            $('#slicewp-reports-period-start').val( iso_format_date( start_date ) );
            $('#slicewp-reports-period-end').val( iso_format_date( end_date ) );
        
        }

        period_select_flag = false;

    });

    $('#slicewp-reports-period-select').trigger('change');


    /**
     * Format the date to ISO
     * 
     * @param {date} date 
     */
    function iso_format_date( date ) {

        var date_year = date.getFullYear();
        var date_month = date.getMonth() + 1;
        var date_day = date.getDate();

        date_month = ( date_month < 10 ? '0' + date_month : date_month );
        date_day = ( date_day < 10 ? '0' + date_day : date_day );

        return date_year + '-' + date_month + '-' + date_day;

    }


    /**
     * The function will return the Top Referring Affiliates.
     * 
     */
     if ( $('#slicewp-top-referring-affiliates').length > 0 ) {

        var data = {
            'action'   : 'slicewp_top_referring_affiliates',
            'token'    : $('#slicewp_token').val(),
            'date_min' : $('#date_min').val(),
            'date_max' : $('#date_max').val(),
            'url'      : $('[name="_wp_http_referer"]').val()
        };

        $.post( ajaxurl, data, function(response) {
            
            $('#slicewp-top-referring-affiliates').replaceWith( response );

        });

    }


    /**
     * The function will return the Top Earning Affiliates.
     * 
     */
    if ( $('#slicewp-top-earning-affiliates').length > 0 ) {

        var data = {
            'action'   : 'slicewp_top_earning_affiliates',
            'token'    : $('#slicewp_token').val(),
            'date_min' : $('#date_min').val(),
            'date_max' : $('#date_max').val(),
            'url'      : $('[name="_wp_http_referer"]').val()
        };

        $.post( ajaxurl, data, function(response) {
            
            $('#slicewp-top-earning-affiliates').replaceWith( response );

        });

    }


    /**
     * The function will return the Top Converting Affiliates.
     * 
     */
     if ( $('#slicewp-top-converting-affiliates').length > 0 ) {

        var data = {
            'action'   : 'slicewp_top_converting_affiliates',
            'token'    : $('#slicewp_token').val(),
            'date_min' : $('#date_min').val(),
            'date_max' : $('#date_max').val(),
            'url'      : $('[name="_wp_http_referer"]').val()
        };

        $.post( ajaxurl, data, function(response) {
            
            $('#slicewp-top-converting-affiliates').replaceWith( response );

        });

    }


    /**
	 * Show/hide commission rate fields when enabling/disabling commission rates per affiliate.
	 *
	 */
	$(document).on( 'change', '#slicewp-enable-commission-rates', function() {

		if ( $(this).is( ':checked' ) ) {

			$(this).closest( '.slicewp-field-wrapper' ).removeClass( 'slicewp-last' );

			$(this).closest( '.slicewp-field-wrapper' ).siblings('.slicewp-field-wrapper-commission-rate').show();
			$(this).closest( '.slicewp-field-wrapper' ).siblings('.slicewp-field-wrapper-commission-rate').find( 'select' ).trigger( 'change' );

		} else {

			$(this).closest( '.slicewp-field-wrapper' ).addClass( 'slicewp-last' );

			$(this).closest( '.slicewp-field-wrapper' ).siblings( '.slicewp-field-wrapper' ).hide();

		}

	});

	$('#slicewp-enable-commission-rates').trigger( 'change' );


    /**
     * Opens the "Add to group" screen overlay and modal.
     * 
     */
    $(document).on( 'click', '.slicewp-list-table-row-action[data-action="add_to_group"]', function(e) {

        e.preventDefault();

        var $row         = $(this).closest( 'tr' );
        var $row_actions = $(this).closest( '.column-actions' );

        $row_actions.find( '.slicewp-button-toggle-actions.slicewp-active, .slicewp-actions-dropdown.slicewp-active' ).removeClass( 'slicewp-active' );

        var affiliate_data = {
            id            : $row.find( '[name="affiliate_ids[]"]' ).val(),
            name          : $row.find( '.column-name .slicewp-affiliate-name span' ).html(),
            avatar_src    : $row.find( '.column-name .slicewp-affiliate-name img' ).attr( 'src' ),
            avatar_srcset : $row.find( '.column-name .slicewp-affiliate-name img' ).attr( 'srcset' )
        };

        populate_add_to_group_modal( [affiliate_data] );

        $('.slicewp-modal-add-affiliates-to-group').parent().addClass( 'slicewp-active' );

    });


    /**
     * Opens the "Add to group" screen overlay and modal.
     * 
     */
    $(document).on( 'click', '.bulkactions .slicewp-form-submit', function(e) {

        var selected = $(this).closest( '.bulkactions' ).find( 'select' ).val();

        if ( selected != 'add_to_group' ) {
            return true;
        }

        var affiliate_ids = $('[name="affiliate_ids[]"]:checked').map( function() {
            return $(this).val();
        }).get();

        if ( affiliate_ids.length == 0 ) {
            return true;
        }

        e.preventDefault();
        
        $(this).removeClass( 'slicewp-disabled' );
        $(this).find( 'span' ).css( { opacity: 1 } );
        $(this).find( '.spinner' ).remove();

        // Add the data to the overlay modal.
        var affiliates_data = [];

        for ( var i = 0; i < affiliate_ids.length; i++ ) {

            var $row = $('.check-column [name="affiliate_ids[]"][value="' + affiliate_ids[i] + '"]').closest( 'tr' );

            var affiliate_data = {
                id            : $row.find( '[name="affiliate_ids[]"]' ).val(),
                name          : $row.find( '.column-name .slicewp-affiliate-name span' ).html(),
                avatar_src    : $row.find( '.column-name .slicewp-affiliate-name img' ).attr( 'src' ),
                avatar_srcset : $row.find( '.column-name .slicewp-affiliate-name img' ).attr( 'srcset' )
            };

            affiliates_data.push( affiliate_data );

        }

        populate_add_to_group_modal( affiliates_data );

        $('.slicewp-modal-add-affiliates-to-group').parent().addClass( 'slicewp-active' );

        return false;

    });


    /**
     * Populates the add affiliate to group modal with the given affiliate data.
     * 
     * @param array affiliates_data
     * 
     */
    function populate_add_to_group_modal( affiliates_data ) {

        var $modal = $('.slicewp-modal-add-affiliates-to-group');

        // Set correct heading.
        if ( affiliates_data.length == 1 ) {
            $modal.find( 'h1 [data-selection="single"]' ).show();
            $modal.find( 'h1 [data-selection="multiple"]' ).hide();
        } else {
            $modal.find( 'h1 [data-selection="single"]' ).hide();
            $modal.find( 'h1 [data-selection="multiple"]' ).show();
        }

        // Populate the affiliate avatars.
        var affiliate_avatars = affiliates_data.map( function( affiliate_data ) {
            return '<img src="' + affiliate_data.avatar_src + '" srcset="' + affiliate_data.avatar_srcset + '" />';
        });

        if ( affiliate_avatars.length <= 3 ) {
            $modal.find( '.slicewp-affiliates-avatars' ).html( affiliate_avatars.join( '' ) );
        } else {
            $modal.find( '.slicewp-affiliates-avatars' ).html( affiliate_avatars.slice( 0, 2 ).join( '' ) + '<div>+' + ( affiliate_avatars.length - 2 ) + '</div>' );   
        }

        // Populate the affiliate names.
        var affiliate_names = affiliates_data.map( function( affiliate_data ) {
            return '<span class="slicewp-affiliate-name">' + affiliate_data.name + '</span>';
        });

        if ( affiliate_names.length == 1 ) {
            $modal.find( '.slicewp-affiliates-names' ).html( affiliate_names.join( '' ) );
        } else if ( affiliate_names.length == 2 ) {
            $modal.find( '.slicewp-affiliates-names' ).html( affiliate_names.join( ' and ' ) );
        } else if ( affiliate_names.length == 3 ) {
            $modal.find( '.slicewp-affiliates-names' ).html( affiliate_names[0] + ', ' + affiliate_names.slice( 1, 3 ).join( ' and ' ) );
        } else {
            $modal.find( '.slicewp-affiliates-names' ).html( affiliate_names.slice( 0, 2 ).join( ', ' ) + ' and ' + ( affiliate_names.length - 2 ) + ' others' );
        }

        // Populate the affiliate IDs hidden field.
        var affiliate_ids = affiliates_data.map( function( affiliate_data ) {
            return affiliate_data.id;
        });
        
        $modal.find( '[name="affiliate_ids"]').val( affiliate_ids.join( ',' ) );

        // Reset affiliate group selector.
        $modal.find( 'select option' ).attr( 'selected', false ).first().attr( 'selected', true );
        $modal.find( 'select' ).trigger( 'change' );

    }


    /**
     * Enables/disables the submit button of the "add affiliates to group" modal.
     * 
     */
    $(document).on( 'change', '.slicewp-modal-add-affiliates-to-group select', function() {

        if ( $(this).val() == '' ) {
            $(this).closest( 'form' ).find( '.slicewp-form-submit' ).attr( 'disabled', true );
        } else {
            $(this).closest( 'form' ).find( '.slicewp-form-submit' ).attr( 'disabled', false );
        }

    });


    /**
     * Moves the "slicewp-field-notice-license-expired" notice to the License Key field.
     * 
     */
    if ( $('[name="license_key"]').length > 0 && $('#slicewp-field-notice-license-expired').length > 0 ) {

        $('[name="license_key"]').closest( '.slicewp-field-wrapper' ).append( $('#slicewp-field-notice-license-expired') );
        $('#slicewp-field-notice-license-expired').show();

    }


});