<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;



Class SliceWP_Submenu_Page_Affiliate_Groups extends SliceWP_Submenu_Page {

	/**
	 * Helper init method that runs on parent __construct.
	 *
	 */
	protected function init() {

		add_action( 'admin_init', array( $this, 'register_admin_notices' ), 10 );

	}


	/**
	 * Callback method to register admin notices that are sent via URL parameters.
	 *
	 */
	public function register_admin_notices() {

		if ( empty( $_GET['slicewp_message'] ) ) {
			return;
		}

		// Affiliate group insert success.
		slicewp_admin_notices()->register_notice( 'affiliate_group_insert_success', '<p>' . __( 'Affiliate group added successfully.', 'slicewp' ) . '</p>' );

		// Affiliate group updated successfully.
		slicewp_admin_notices()->register_notice( 'affiliate_group_update_success', '<p>' . __( 'Affiliate group updated successfully.', 'slicewp' ) . '</p>' );

		// Affiliate group updated fail.
		slicewp_admin_notices()->register_notice( 'affiliate_group_update_fail', '<p>' . __( 'Something went wrong. Could not update the affiliate group.', 'slicewp' ) . '</p>', 'error' );

		// Affiliate group delete success.
		slicewp_admin_notices()->register_notice( 'affiliate_group_delete_success', '<p>' . __( 'Affiliate group deleted successfully.', 'slicewp' ) . '</p>' );

		if ( ! empty( $_GET['updated'] ) ) {

			// Affiliate group bulk delete success.
			slicewp_admin_notices()->register_notice( 'bulk_action_affiliate_groups_delete_success', '<p>' . sprintf( __( '%d affiliate group(s) deleted successfully.', 'slicewp' ), absint( $_GET['updated'] ) ) . '</p>' );

			// Affiliate group make default success.
			if ( $_GET['slicewp_message'] == 'affiliate_group_make_default_success' ) {

				$collection = slicewp_get_collection( absint( $_GET['updated'] ) );

				slicewp_admin_notices()->register_notice( 'affiliate_group_make_default_success', '<p>' . sprintf( __( "%s group is now the default one.", 'slicewp' ), '<strong>' . $collection->get( 'name' ) . '</strong>' ) . '</p>' );

			}
			
		}
		
	}


	/**
	 * Callback for the HTML output for the affiliate groups page.
	 *
	 */
	public function output() {

		if ( empty( $this->current_subpage ) ) {

			include 'views/view-affiliate-groups.php';

		} else {

			if ( $this->current_subpage == 'add-affiliate-group' ) {
				include 'views/view-add-affiliate-group.php';
			}

			if ( $this->current_subpage == 'edit-affiliate-group' ) {
				include 'views/view-edit-affiliate-group.php';
			}

		}

	}

}