<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Include the commission rates view for the affiliate.
 *
 */
function slicewp_view_affiliates_add_affiliate_bottom_affiliate_commission_rates() {

	include_once 'views/view-affiliate-commission-rates.php';

}
add_action( 'slicewp_view_affiliates_add_affiliate_bottom', 'slicewp_view_affiliates_add_affiliate_bottom_affiliate_commission_rates' );
add_action( 'slicewp_view_affiliates_edit_affiliate_bottom', 'slicewp_view_affiliates_add_affiliate_bottom_affiliate_commission_rates' );


/**
 * Saves the affiliate meta-data when inserting or updating an affiliate.
 *
 */
function slicewp_save_affiliate_commission_rates( $affiliate_id ) {

    // Bail if the action isn't "add_affiliate" or "update_affiliate".
    if ( ! slicewp_verify_request_action( 'add_affiliate' ) && ! slicewp_verify_request_action( 'update_affiliate' ) ) {
        return;
    }

	// Enable Custom Commission Rates.
	if ( ! empty( $_POST['enable_commission_rates'] ) ) {
        slicewp_update_affiliate_meta( $affiliate_id, 'enable_commission_rates', 1 );
    } else {
        slicewp_delete_affiliate_meta( $affiliate_id, 'enable_commission_rates' );
    }

	// Commission rates.
	$commission_types = slicewp_get_available_commission_types();

	foreach ( $commission_types as $type => $details ) {

		if ( ! isset( $_POST['commission_rate_' . $type] ) ) {
            continue;
        }

		if ( ! isset( $_POST['commission_rate_type_' . $type] ) ) {
            continue;
        }

		slicewp_update_affiliate_meta( $affiliate_id, 'commission_rate_' . $type, sanitize_text_field( $_POST['commission_rate_' . $type] ) );
		slicewp_update_affiliate_meta( $affiliate_id, 'commission_rate_type_' . $type, sanitize_text_field( $_POST['commission_rate_type_' . $type] ) );

	}

	// Fixed amount commission basis.
	if ( isset( $_POST['commission_fixed_amount_rate_basis'] ) ) {
        slicewp_update_affiliate_meta( $affiliate_id, 'commission_fixed_amount_rate_basis', sanitize_text_field( $_POST['commission_fixed_amount_rate_basis'] ) );
    }	

}
add_action( 'slicewp_insert_affiliate', 'slicewp_save_affiliate_commission_rates' );
add_action( 'slicewp_update_affiliate', 'slicewp_save_affiliate_commission_rates' );


/**
 * Outputs a promo notice for version 1.0.8.
 * 
 * @deprecated - This function is deprecated, but left in code as a template that can be used for future promo notices.
 * 
 */
function slicewp_admin_notice_pro_version_1_0_8() {

	if ( empty( $_GET['page'] ) || ! is_string( $_GET['page'] ) || false === strpos( $_GET['page'], 'slicewp' ) ) {
		return;
	}

	if ( version_compare( SLICEWP_PRO_VERSION, '1.0.10', '>' ) ) {
		return;
	}

	$dismissed_admin_notices = get_option( 'slicewp_dismissed_admin_notices', array() );

	if ( in_array( 'pro_version_1_0_8', $dismissed_admin_notices ) ) {
		return;
	}

	?>

		<style>
			.slicewp-admin-notice { position: relative; display: flex; padding: 0 !important; border-left: 0 !important; }
			.slicewp-admin-notice:before { content: ''; display: block; position: absolute; top: -1px; left: 0; bottom: -1px; width: 4px; background: rgba( 248, 79, 141, 1 ); }

			.slicewp-admin-notice-icon-wrapper { background: rgba( 248, 79, 141, 0.05 ); padding: 15px 13px; margin-left: 4px; }
			.slicewp-admin-notice-icon-wrapper img { max-width: 24px; height: auto; }

			.slicewp-admin-notice-content { padding: 15px; }
			.slicewp-admin-notice-content > :first-child { margin-top: 0; }
			.slicewp-admin-notice-content > :last-child { margin-bottom: 0; }
		</style>

		<div class="slicewp-admin-notice notice notice-info">

			<div class="slicewp-admin-notice-icon-wrapper">
				<img src="<?php echo SLICEWP_PLUGIN_DIR_URL; ?>assets/img/slicewp-logo-icon-350x350.png" />
			</div>

			<div class="slicewp-admin-notice-content">
				<h3><strong><?php echo __( 'Say hello to affiliate groups!', 'slicewp' ); ?></strong></h3>
				<p style="font-size: 14px;"><?php echo __( "This new update is huge! It brings you affiliate groups, a feature designed to offer you even more flexibility and control over your affiliate program.", 'slicewp' ); ?></p>

				<a target="_blank" style="margin-top: 10px; margin-right: 10px;" href="<?php echo esc_url( 'https://slicewp.com/blog/product-update-affiliate-groups/' ); ?>" class="button-primary"><?php echo __( 'Explore affiliate groups', 'slicewp' ); ?></a>
				<a href="<?php echo wp_nonce_url( add_query_arg( array( 'slicewp_action' => 'dismiss_notice', 'notice_slug' => 'pro_version_1_0_8' ) ), 'slicewp_dismiss_notice', 'slicewp_token' ); ?>"><?php echo __( 'Dismiss notice', 'slicewp' ); ?></a>
			</div>

		</div>

	<?php

}
// add_action( 'admin_notices', 'slicewp_admin_notice_pro_version_1_0_8' );