<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

$affiliate_id = ( ! empty( $_GET['affiliate_id'] ) ? sanitize_text_field( $_GET['affiliate_id'] ) : 0 );

?>

<div class="slicewp-card">

	<div class="slicewp-card-header">
		<span class="slicewp-card-title"><?php echo __( 'Commission Rates', 'slicewp' ); ?></span>

		<div class="slicewp-card-actions">
			<a href="https://slicewp.com/docs/commission-rates/#commission-rates-per-affiliate" target="_blank" class="slicewp-button-info" title="<?php echo esc_attr( __( 'Click to learn more...', 'slicewp' ) ); ?>"><svg height="18" width="18" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><g><path d="M13 9h-2V7h2v2zm0 2h-2v6h2v-6zm-1-7c-4.41 0-8 3.59-8 8s3.59 8 8 8 8-3.59 8-8-3.59-8-8-8m0-2c5.523 0 10 4.477 10 10s-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2z"></path></g></svg></a>
		</div>
	</div>

	<div class="slicewp-card-inner">

		<!-- Enable Custom Commission Rates -->
		<div class="slicewp-field-wrapper slicewp-field-wrapper-inline slicewp-last">

			<div class="slicewp-field-label-wrapper">
				<label for="slicewp-enable-commission-rates"><?php echo __( 'Commission Rates', 'slicewp' ); ?></label>
			</div>
			
			<div class="slicewp-switch">

				<input id="slicewp-enable-commission-rates" class="slicewp-toggle slicewp-toggle-round" name="enable_commission_rates" type="checkbox" value="1" <?php checked( ! empty( $_POST['enable_commission_rates'] ) ? esc_attr( $_POST['enable_commission_rates'] ) : slicewp_get_affiliate_meta( $affiliate_id, 'enable_commission_rates', true ), '1' ) ?> />
				<label for="slicewp-enable-commission-rates"></label>

			</div>

			<label for="slicewp-enable-commission-rates"><?php echo __( 'Enable custom commission rates for this affiliate.', 'slicewp' ); ?></label>

		</div>
		<!-- / Enable Custom Commission Rates -->

		<!-- Commissions Rates -->
		<?php 
			$commission_types = slicewp_get_available_commission_types( true );
		?>

		<?php foreach ( $commission_types as $type => $details ): ?>

			<?php if ( $type == 'recurring' || $type == 'lifetime_sale' ) continue; ?>

			<?php
				$rate 	   = slicewp_get_affiliate_meta( $affiliate_id, 'commission_rate_' . $type, true );
				$rate_type = slicewp_get_affiliate_meta( $affiliate_id, 'commission_rate_type_' . $type, true );
			?>

			<div class="slicewp-field-wrapper slicewp-field-wrapper-inline slicewp-field-wrapper-commission-rate" style="display: none;">

				<div class="slicewp-field-label-wrapper">
					<label for="slicewp-commission-rate-<?php echo str_replace( '_', '-', $type ); ?>">
						<?php echo sprintf( __( '%s rate', 'slicewp' ), $details['label'] ); ?>
					</label>
				</div>
				
				<input id="slicewp-commission-rate-<?php echo str_replace( '_', '-', $type ); ?>" name="commission_rate_<?php echo $type; ?>" type="number" step="any" min="0" value="<?php echo ( ! empty( $_POST['commission_rate_' . $type] ) ? esc_attr( $_POST['commission_rate_' . $type] ) : $rate ); ?>" />					

				<select <?php echo( count( $details['rate_types'] ) == 1 ? '' : 'name="commission_rate_type_' . esc_attr( $type ) . '"' ); ?> class="slicewp-select2" <?php echo ( count( $details['rate_types'] ) == 1 ? 'disabled' : '' ); ?>>
					<?php foreach( $details['rate_types'] as $details_rate_type ): ?>
						<option value="<?php echo esc_attr( $details_rate_type ); ?>" <?php selected( $rate_type, $details_rate_type ); ?>><?php echo ( $details_rate_type == 'percentage' ? __( 'Percentage (%)', 'slicewp' ) : __( 'Fixed Amount', 'slicewp' ) ); ?></option>
					<?php endforeach; ?>
				</select>

				<?php if ( count( $details['rate_types'] ) == 1 ) : ?>
					<input type="hidden" name="commission_rate_type_<?php echo esc_attr( $type ); ?>" value="<?php echo( esc_attr( $details_rate_type ) ); ?>" />
				<?php endif; ?>

			</div>

		<?php endforeach; ?>
		<!-- / Commisions Rates -->

		<!-- Sale Fixed Amount Commission Basis -->
		<div class="slicewp-field-wrapper slicewp-field-wrapper-inline slicewp-last" style="display: none;">

			<div class="slicewp-field-label-wrapper">
				<label>
					<?php echo __( 'Sale Commission Basis', 'slicewp' ); ?>
				</label>
			</div>

			<select id="slicewp-fixed-amount-commission-basis" name="commission_fixed_amount_rate_basis" class="slicewp-select2">
				<option value="product" <?php echo ( slicewp_get_affiliate_meta( $affiliate_id, 'commission_fixed_amount_rate_basis', true ) == 'product' ? 'selected="selected"' : '' ); ?>><?php echo __( 'Fixed amount per product', 'slicewp' ); ?></option>
				<option value="order" <?php echo ( slicewp_get_affiliate_meta( $affiliate_id, 'commission_fixed_amount_rate_basis', true ) == 'order' ? 'selected="selected"' : '' ); ?>><?php echo __( 'Fixed amount per order', 'slicewp' ); ?></option>
			</select>

		</div>
		<!-- / Sale Fixed Amount Commission Basis -->

	</div>

</div>