<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Register the Reports admin submenu page.
 *
 */
function slicewp_register_submenu_page_reports( $submenu_pages ) {

	if ( ! is_array( $submenu_pages ) ) {
		return $submenu_pages;
	}

	$submenu_pages['reports'] = array(
		'class_name' => 'SliceWP_Submenu_Page_Reports',
		'data' 		 => array(
			'page_title' => __( 'Reports', 'slicewp' ),
			'menu_title' => __( 'Reports', 'slicewp' ),
			'capability' => apply_filters( 'slicewp_submenu_page_capability_reports', 'manage_options' ),
			'menu_slug'  => 'slicewp-reports'
		)
	);

	return $submenu_pages;

}
add_filter( 'slicewp_register_submenu_page', 'slicewp_register_submenu_page_reports', 50 );


/**
 * Compare the Filter dates with the previous ones
 * 
 * @param $current_value
 * @param $previous_value
 * 
 * @return string;
 * 
 */
function slicewp_compute_percentage( $current_value, $previous_value ){
	
	if ( $previous_value != 0 ) {

		$comparison = ( $current_value - $previous_value ) / $previous_value * 100;
		$comparison = round( $comparison, 2 );
		return $comparison . '%';

	} else {
		return '-';
	}

}


/**
 * Get the top referring affiliates.
 */
function slicewp_ajax_top_referring_affiliates() {

	if ( empty( $_POST['token'] ) || ! wp_verify_nonce( $_POST['token'], 'slicewp_reports' ) ) {
		wp_die();
	}

	// Get the start date from the filter, or set it to the default value if not present.
	$date_min = ( ! empty( $_POST['date_min'] ) ? new DateTime( $_POST['date_min'] ) : ( new DateTime() )->sub( new DateInterval('P7D') ) );
	$date_min->setTime( 00, 00, 00 );

	// Get the end date from the filter, or set it to the default value if not present.
	$date_max = ( ! empty( $_POST['date_max'] ) ? new DateTime( $_POST['date_max'] ) : new DateTime() );
	$date_max->setTime( 23, 59, 59 );

	$args = array(
		'number'   => -1,
		'fields'   => 'affiliate_id',
		'date_min' => get_gmt_from_date( $date_min->format( 'Y-m-d H:i:s' ) ),
		'date_max' => get_gmt_from_date( $date_max->format( 'Y-m-d H:i:s' ) )
	);

	$visits = slicewp_get_visits( $args );

	// Sum visit by affiliate.
	$visits_count = array_count_values( $visits );

	// Sort descending.
	arsort( $visits_count, SORT_NUMERIC );

	// Get only first 10.
	$visits_count = array_slice( $visits_count, 0, 10, true );

	$top_affiliates = array();
	
	foreach ( $visits_count as $affiliate_id => $count ) {

		$affiliate = slicewp_get_affiliate( $affiliate_id );

		if ( is_null( $affiliate ) ) {
			continue;
		}

		$user = get_userdata( $affiliate->get('user_id') );

		$top_affiliates[$affiliate_id]['object'] = $affiliate;
		$top_affiliates[$affiliate_id]['id']     = $affiliate_id;
		$top_affiliates[$affiliate_id]['name'] 	 = slicewp_get_affiliate_name( $affiliate );
		$top_affiliates[$affiliate_id]['email']  = $user->user_email;
		$top_affiliates[$affiliate_id]['visits'] = $count;

	}

	// Display the Top Referring Affiliates table
	echo '<table class="slicewp-card-table-full-width">';

		echo '<thead>';
			echo '<tr>';
				echo '<th>' . __( 'Affiliate', 'slicewp' ) . '</th>';
				echo '<th class="slicewp-column-affiliate-visits">' . __( 'Visits', 'slicewp' ) . '</th>';
			echo '</tr>';
		echo '</thead>';
		
		echo '<tbody>';

			if ( ! empty( $top_affiliates ) ) {

				foreach ( $top_affiliates as $affiliate ) {

					$url = add_query_arg( array( 'tab' => 'visits', 'affiliate_id' => $affiliate['id'], 'user_search' => $affiliate['name'] . ' (' . $affiliate['email'] . ')' ), $_POST['url'] );
					
					echo '<tr>';

						echo '<td>';
							echo '<a href="' . esc_url( $url ) . '">';
								echo get_avatar( $affiliate['object']->get( 'user_id' ), 64 );
								echo '<span>' . $affiliate['name'] . '</span>';
							echo '</a>';
						echo '</td>';

						echo '<td>' . $affiliate['visits'] . '</td>';
						
					echo '</tr>';

				}

			} else {

				echo '<tr><td colspan="2">' . __( 'No affiliates found for selected period.', 'slicewp' ) . '</td></tr>';

			}

		echo '<tbody>';

	echo '</table>';

    wp_die();
	
}
add_action( 'wp_ajax_slicewp_top_referring_affiliates', 'slicewp_ajax_top_referring_affiliates' );


/**
 * Get the Top Earning Affiliates.
 *
 */
function slicewp_ajax_top_earning_affiliates() {

	if ( empty( $_POST['token'] ) || ! wp_verify_nonce( $_POST['token'], 'slicewp_reports' ) ) {
		wp_die();
	}

	//Get the start date from the filter, or set it to the default value if not present
	$date_min = ( ! empty( $_POST['date_min'] ) ? new DateTime( $_POST['date_min'] ) : ( new DateTime() )->sub( new DateInterval('P7D') ) );
	$date_min->setTime( 00, 00, 00 );

	//Get the end date from the filter, or set it to the default value if not present
	$date_max = ( ! empty( $_POST['date_max'] ) ? new DateTime( $_POST['date_max'] ) : new DateTime() );
	$date_max->setTime( 23, 59, 59 );

	$args = array(
		'number'   => -1,
		'fields'   => array( 'affiliate_id', 'amount' ),
		'date_min' => get_gmt_from_date( $date_min->format( 'Y-m-d H:i:s' ) ),
		'date_max' => get_gmt_from_date( $date_max->format( 'Y-m-d H:i:s' ) ),
		'status'   => array( 'paid', 'unpaid' )
	);

	$commissions = array_map( 'slicewp_object_to_array', slicewp_get_commissions( $args ) );

	// Sum commissions amounts by affiliate.
	$commissions_sum = array();

	foreach ( $commissions as $key => $commission ) {

		$commissions_sum[$commission['affiliate_id']] = ( isset( $commissions_sum[$commission['affiliate_id']] ) ? $commissions_sum[$commission['affiliate_id']] + $commission['amount'] : $commission['amount'] );

	}

	// Sort descending.
	arsort( $commissions_sum, SORT_NUMERIC );

	// Get only first 10.
	$commissions_sum = array_slice( $commissions_sum, 0, 10, true );

	$top_affiliates = array();
	
	foreach ( $commissions_sum as $affiliate_id => $sum ) {

		$affiliate = slicewp_get_affiliate( $affiliate_id );

		if ( is_null( $affiliate ) ) {
			continue;
		}

		$user = get_userdata( $affiliate->get('user_id') );

		$top_affiliates[$affiliate_id]['object']   = $affiliate;
		$top_affiliates[$affiliate_id]['id']       = $affiliate_id;
		$top_affiliates[$affiliate_id]['name'] 	   = slicewp_get_affiliate_name( $affiliate_id );
		$top_affiliates[$affiliate_id]['email']    = $user->user_email;
		$top_affiliates[$affiliate_id]['earnings'] = $sum;

	}

	// Display the Top Earning Affiliates table.
	echo '<table class="slicewp-card-table-full-width">';

		echo '<thead>';
			echo '<tr>';
				echo '<th>' . __( 'Affiliate', 'slicewp' ) . '</th>';
				echo '<th class="slicewp-column-affiliate-earnings">' . __( 'Earnings', 'slicewp' ) . '</th>';
			echo '</tr>';
		echo '</thead>';
		
		echo '<tbody>';

			if ( ! empty( $top_affiliates ) ) {

				foreach ( $top_affiliates as $affiliate ) {

					$url = add_query_arg( array( 'tab' => 'commissions', 'affiliate_id' => $affiliate['id'], 'user_search' => $affiliate['name'] . ' (' . $affiliate['email'] . ')' ), $_POST['url'] );

					echo '<tr>';
						
						echo '<td>';
							echo '<a href="' . esc_url( $url ) . '">';
								echo get_avatar( $affiliate['object']->get( 'user_id' ), 64 );
								echo '<span>' . $affiliate['name'] . '</span>';
							echo '</a>';
						echo '</td>';
					
						echo '<td>' . slicewp_format_amount( $affiliate['earnings'], slicewp_get_setting( 'active_currency', 'USD' ) ) . '</td>';

					echo '</tr>';

				}

			} else {

				echo '<tr><td colspan="2">' . __( 'No affiliates found for selected period.', 'slicewp' ) . '</td></tr>';

			}

		echo '<tbody>';

	echo '</table>';

    wp_die();

}
add_action( 'wp_ajax_slicewp_top_earning_affiliates', 'slicewp_ajax_top_earning_affiliates' );


/**
 * Get the Top Converting Affiliates.
 *
 */
function slicewp_ajax_top_converting_affiliates() {

	if ( empty( $_POST['token'] ) || ! wp_verify_nonce( $_POST['token'], 'slicewp_reports' ) ) {
		wp_die();
	}
	
	//Get the start date from the filter, or set it to the default value if not present
	$date_min = ( ! empty( $_POST['date_min'] ) ? new DateTime( $_POST['date_min'] ) : ( new DateTime() )->sub( new DateInterval('P7D') ) );
	$date_min->setTime( 00, 00, 00 );

	//Get the end date from the filter, or set it to the default value if not present
	$date_max = ( ! empty( $_POST['date_max'] ) ? new DateTime( $_POST['date_max'] ) : new DateTime() );
	$date_max->setTime( 23, 59, 59 );
	
	//Prepare the arguments for Top Converting Affiliates
    $top_converting_affiliates_args = array(
        'number'                => 10,
        'commission_date_min'	=> get_gmt_from_date( $date_min->format( 'Y-m-d H:i:s' ) ),
        'commission_date_max'	=> get_gmt_from_date( $date_max->format( 'Y-m-d H:i:s' ) ),
        'orderby'               => 'conversions_period',
        'order'	                => 'desc'
    );

	//Read the Top Converting Affiliates from database
    $top_converting_affiliates  = slicewp_get_affiliates( $top_converting_affiliates_args );
	$_top_converting_affiliates = array();

	//Parse the Top Converting Affiliates array
	foreach ( $top_converting_affiliates as $affiliate ) {

		//For each affiliate, get the number of conversions
		$affiliate_conversions_number_args = array(
			'date_min'	    => get_gmt_from_date( $date_min->format( 'Y-m-d H:i:s' ) ),
			'date_max'	    => get_gmt_from_date( $date_max->format( 'Y-m-d H:i:s' ) ),
			'affiliate_id'  => $affiliate->get('id'),
			'converted'     => true
		);

		$affiliate_conversions_number = slicewp_get_visits( $affiliate_conversions_number_args, true );
		
		//For each affiliate, get the number of visits
		$affiliate_visits_number_args = array(
			'date_min'	    => get_gmt_from_date( $date_min->format( 'Y-m-d H:i:s' ) ),
			'date_max'	    => get_gmt_from_date( $date_max->format( 'Y-m-d H:i:s' ) ),
			'affiliate_id'  => $affiliate->get('id')
		);
		$affiliate_visits_number = slicewp_get_visits( $affiliate_visits_number_args, true );

		//Compute the Conversion Rate
		$conversion_rate = ( $affiliate_visits_number != 0 ? round( $affiliate_conversions_number/$affiliate_visits_number  * 100, 2 ) : 0 );
		
		//Save the affiliate name and his conversion rate into a new array
		if ( $conversion_rate != 0 ) {

			$user = get_userdata( $affiliate->get('user_id') );
			$email = $user->user_email;

			$_top_converting_affiliates[$affiliate->get('id')]['object'] = $affiliate;
			$_top_converting_affiliates[$affiliate->get('id')]['id'] = $affiliate->get('id');
			$_top_converting_affiliates[$affiliate->get('id')]['name'] = slicewp_get_affiliate_name( $affiliate->get('id') );
			$_top_converting_affiliates[$affiliate->get('id')]['email'] = $email;
			$_top_converting_affiliates[$affiliate->get('id')]['conversion_rate'] = $conversion_rate;

		}

	}
	
	// Display the Top Converting Affiliates table
	echo '<table class="slicewp-card-table-full-width">';

		echo '<thead>';
			echo '<tr>';
				echo '<th>' . __( 'Affiliate', 'slicewp' ) . '</th>';
				echo '<th class="slicewp-column-affiliate-conversion">' . __( 'Conversion', 'slicewp' ) . '</th>';
			echo '</tr>';
		echo '</thead>';
		
		echo '<tbody>';

			if ( ! empty( $_top_converting_affiliates ) ) {
				
				foreach ( $_top_converting_affiliates as $affiliate ) {

					$url = add_query_arg( array( 'tab' => 'visits', 'affiliate_id' => $affiliate['id'], 'user_search' => $affiliate['name'] . ' (' . $affiliate['email'] . ')' ), $_POST['url'] );
					
					echo '<tr>';
						
						echo '<td>';
							echo '<a href="' . esc_url( $url ) . '">';
								echo get_avatar( $affiliate['object']->get( 'user_id' ), 64 );
								echo '<span>' . $affiliate['name'] . '</span>';
							echo '</a>';
						echo '</td>';

						echo '<td>' . $affiliate['conversion_rate'] . '%' . '</td>';
					echo '</tr>';
					
				}

			} else {

				echo '<tr><td colspan="2">' . __( 'No affiliates found for selected period.', 'slicewp' ) . '</td></tr>';

			}

		echo '</tbody>';

	echo '</table>';

    wp_die();

}
add_action( 'wp_ajax_slicewp_top_converting_affiliates', 'slicewp_ajax_top_converting_affiliates' );