<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Get the Total Affiliates report data
 *
 */
$args = array();
$report_affiliates_total = slicewp_get_affiliates( $args, true );

/**
 * Get the Period Affiliates report data
 *
 */
$report_total_selected_period = slicewp_get_affiliates( $args_selected, true );
$report_total_compare_period = slicewp_get_affiliates( $args_compare, true );

?>


<!-- Tab: Affiliates Reports -->
<div class="slicewp-tab <?php echo ( $active_tab == 'affiliates' ? 'slicewp-active' : '' ); ?>" data-tab="affiliates">

    <div class="slicewp-grid slicewp-grid-columns-2">

        <div class="slicewp-grid-item">

            <!-- Total Affiliates -->
            <div class="slicewp-card slicewp-card-reports">

                <div class="slicewp-card-header">
                    <?php echo __( 'Total Affiliates', 'slicewp-reports' ); ?>
                </div>

                <div class="slicewp-card-inner">

                    <div class="slicewp-card-kpi">

                        <span class="slicewp-card-kpi-value"><?php echo sprintf( __( '%s', 'slicewp-reports' ), $report_affiliates_total ); ?></span>

                    </div>

                    <span class="slicewp-card-kpi-timeframe">All Time</span>

                </div>
                
            </div><!-- / Total Affiliates -->

        </div>

        <div class="slicewp-grid-item">

            <!-- Affiliates for Period -->
            <div class="slicewp-card slicewp-card-reports">

                <div class="slicewp-card-header">
                    <?php echo __( 'Affiliates', 'slicewp-reports' ); ?>
                </div>

                <div class="slicewp-card-inner">

                    <div class="slicewp-card-kpi">
                        
                        <span class="slicewp-card-kpi-value"><?php echo sprintf( __( '%s', 'slicewp-reports'), $report_total_selected_period ); ?></span>

                        <div>

                            <?php echo slicewp_output_tooltip( sprintf( __( 'Compared to: %s %s - %s', 'slicewp-reports'), '<br>', $previous_date_min->format('Y-m-d'), $previous_date_max->format('Y-m-d') ) ); ?>

                            <div class="slicewp-card-kpi-direction <?php echo ( slicewp_compute_percentage( $report_total_selected_period, $report_total_compare_period ) == 0 ? '' : ( slicewp_compute_percentage( $report_total_selected_period, $report_total_compare_period ) > 0 ? 'slicewp-positive' : 'slicewp-negative' ) ); ?>">

                                <span class="dashicons dashicons-arrow-up"></span>
                                <span class="dashicons dashicons-arrow-down"></span>

                                <?php echo sprintf( __( '%s', 'slicewp-reports'), slicewp_compute_percentage( $report_total_selected_period, $report_total_compare_period ) ); ?>

                            </div>

                        </div>

                    </div>

                    <span class="slicewp-card-kpi-timeframe"><?php echo ( $reports_period_filter == 'custom' ? sprintf( __( 'Last %s Days', 'slicewp-reports'), $date_difference ) : $reports_period_filter_options[$reports_period_filter] ); ?></span>

                </div>

            </div><!-- / Affiliates for Period -->

        </div>

    </div>

    <!-- Charts -->
    <?php

        // Get affiliates.
        $affiliates = slicewp_get_affiliates( array_merge( array( 'number' => -1, 'order' => 'ASC' ), $args_selected ) );

        // Set date_created based on site's timezone, not GMT as it's saved in the DB.
        foreach ( $affiliates as $key => $affiliate ) {

            $affiliates[$key]->set( 'date_created', get_date_from_gmt( $affiliate->get( 'date_created' ) ) );

        }

        // Init chart.
        $chart = new SliceWP_Chart_Affiliates( array(
            'raw_data' => $affiliates,
            'args'     => array( 'date_min' => $date_min->format( 'Y-m-d H:i:s' ), 'date_max' => $date_max->format( 'Y-m-d H:i:s' ) )
        ) );

        $chart->output();
    ?>
    <!-- / Charts -->

    <div class="slicewp-grid slicewp-grid-columns-3">

        <div class="slicewp-grid-item">

            <!-- Top Earning Affiliates -->
            <div class="slicewp-card" style="margin-top: 0;">

                <div class="slicewp-card-header">
                    <span class="slicewp-card-title"><?php echo __( 'Highest Referring Affiliates', 'slicewp-reports' ); ?></span>
                </div>

                <div class="slicewp-card-inner">
                    <div class="slicewp-card-top">
                        <div id="slicewp-top-referring-affiliates">
                            <div class="spinner" style="visibility: visible;"></div>
                        </div>
                    </div>
                </div>

            </div><!-- / Top Earning Affiliates -->

        </div>

        <div class="slicewp-grid-item">

            <!-- Top Earning Affiliates -->
            <div class="slicewp-card" style="margin-top: 0;">

                <div class="slicewp-card-header">
                    <span class="slicewp-card-title"><?php echo __( 'Highest Earning Affiliates', 'slicewp-reports' ); ?></span>
                </div>

                <div class="slicewp-card-inner">
                    <div class="slicewp-card-top">
                        <div id="slicewp-top-earning-affiliates">
                            <div class="spinner" style="visibility: visible;"></div>
                        </div>
                    </div>
                </div>

            </div><!-- / Top Earning Affiliates -->

        </div>

        <div class="slicewp-grid-item">

            <!-- Top Converting Affiliates -->
            <div class="slicewp-card" style="margin-top: 0;">

                <div class="slicewp-card-header">
                    <span class="slicewp-card-title"><?php echo __( 'Highest Converting Affiliates', 'slicewp-reports' ); ?></span>
                </div>

                <div class="slicewp-card-inner">
                    <div class="slicewp-card-top">
                        <div id="slicewp-top-converting-affiliates">
                            <div class="spinner" style="visibility: visible;"></div>
                        </div>
                    </div>
                </div>

            </div><!-- / Top Converting Affiliates -->
        
        </div>

    </div>

</div><!-- / Tab: Affiliates Reports -->