<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

$tabs = array(
	'commissions' => array(
		'label' => __( 'Commissions', 'slicewp' ),
		'icon'	=> slicewp_get_svg( 'outline-chart-pie' )
	),
	'visits' => array(
		'label' => __( 'Visits', 'slicewp' ),
		'icon'	=> slicewp_get_svg( 'outline-cursor-click' )
	),
	'affiliates' => array(
		'label' => __( 'Affiliates', 'slicewp' ),
		'icon'	=> slicewp_get_svg( 'outline-user-group' )
	),
	'payments' => array(
		'label' => __( 'Payments', 'slicewp' ),
		'icon'	=> slicewp_get_svg( 'outline-cash' )
	)
);


/**
 * Filter the tabs for the reports edit screen
 *
 * @param array $tabs
 *
 */
$tabs = apply_filters( 'slicewp_submenu_page_reports_tabs', $tabs );

$active_tab = ( ! empty( $_GET['tab'] ) ? sanitize_text_field( $_GET['tab'] ) : 'commissions' );


/**
 * Define the period filters
 * 
 */
$reports_period_filter_options = array(
	'last_seven_days'	=> __( 'Last 7 Days', 'slicewp-reports' ),
	'last_thirty_days'	=> __( 'Last 30 Days', 'slicewp-reports' ),
	'this_month'		=> __( 'This Month', 'slicewp-reports' ),
	'last_month'		=> __( 'Last Month', 'slicewp-reports' ),
	'last_three_months'	=> __( 'Last 3 Months', 'slicewp-reports' ),
	'last_six_months'	=> __( 'Last 6 Months', 'slicewp-reports' ),
	'this_year'			=> __( 'This Year', 'slicewp-reports' ),
	'last_year'			=> __( 'Last Year', 'slicewp-reports' ),
	'custom'			=> __( 'Custom', 'slicewp-reports' ),
);


/**
 * Prepare the needed variables
 * 
 */
$affiliate_id = ( ( ! empty( $_GET['affiliate_id'] ) && ( $active_tab != 'affiliates' ) ) ? absint( $_GET['affiliate_id'] ) : '' );

/**
 * Compute the filter dates
 *
 */

// Get the start date from the filter, or set it to the default value if not present
$date_min = ( ! empty( $_GET['date_min'] ) ? new DateTime( $_GET['date_min'] ) : ( new DateTime() )->sub( new DateInterval('P6D') ) );
$date_min->setTime( 00, 00, 00 );

// Get the end date from the filter, or set it to the default value if not present
$date_max = ( ! empty( $_GET['date_max'] ) ? new DateTime( $_GET['date_max'] ) : new DateTime() );
$date_max->setTime( 23, 59, 59 );

// Get the selected period from filter
$reports_period_filter = ! empty( $_GET['reports_period_filter'] ) ? $_GET['reports_period_filter'] : 'last_seven_days';

//Compute the comparison dates based on the filtered period
switch( $reports_period_filter ) {

	case 'last_seven_days':
		$previous_date_min = ( new DateTime( $date_min->format( 'Y-m-d H:i:s' ) ) )->sub( new DateInterval( 'P7D' ) ) ;
		$previous_date_max = ( new DateTime( $date_max->format( 'Y-m-d H:i:s' ) ) )->sub( new DateInterval( 'P7D' ) ) ;
		break;

	case 'last_thirty_days':
		$previous_date_min = ( new DateTime( $date_min->format( 'Y-m-d H:i:s' ) ) )->sub( new DateInterval( 'P30D' ) ) ;
		$previous_date_max = ( new DateTime( $date_max->format( 'Y-m-d H:i:s' ) ) )->sub( new DateInterval( 'P30D' ) ) ;
		break;

	case 'this_month':
		$previous_date_min = ( new DateTime( $date_min->format('Y-m-d H:i:s') ) )->sub( new DateInterval( 'P1M' ) ) ;
		$previous_date_max = ( new DateTime( $date_max->format('Y-m-d H:i:s') ) )->sub( new DateInterval( 'P1M' ) ) ;
		break;

	case 'last_month':
		$previous_date_min = ( new DateTime( $date_min->format( 'Y' ) . '-' . $date_min->format( 'm' ) . '-15 12:00:00' ) )->sub( new DateInterval( 'P1M' ) ) ;
		$previous_date_min->setDate( $previous_date_min->format( 'Y' ), $previous_date_min->format( 'm' ), '1');
		$previous_date_max = ( new DateTime( $previous_date_min->format( 'Y' ) . '-' . $previous_date_min->format( 'm' ) . '-' . $previous_date_min->format( 't' ) ) );
		break;
		
	case 'last_three_months':
		$previous_date_min = ( new DateTime( $date_min->format( 'Y' ) . '-' . $date_min->format( 'm' ) . '-15 12:00:00' ) )->sub( new DateInterval( 'P3M' ) ) ;
		$previous_date_min->setDate( $previous_date_min->format( 'Y' ), $previous_date_min->format( 'm' ), '1');
		$previous_date_max = ( new DateTime( $previous_date_min->format( 'Y' ) . '-' . $previous_date_min->format( 'm' ) . '-15 12:00:00' ) );
		$previous_date_max->add( new DateInterval( 'P2M' ) );
		$previous_date_max->setDate( $previous_date_max->format( 'Y' ), $previous_date_max->format('m'), $previous_date_max->format( 't' ) );
		break;

	case 'last_six_months':
		$previous_date_min = ( new DateTime( $date_min->format( 'Y' ) . '-' . $date_min->format( 'm' ) . '-15 12:00:00' ) )->sub( new DateInterval( 'P6M' ) ) ;
		$previous_date_min->setDate( $previous_date_min->format( 'Y' ), $previous_date_min->format( 'm' ), '1');
		$previous_date_max = ( new DateTime( $previous_date_min->format( 'Y' ) . '-' . $previous_date_min->format( 'm' ) . '-15 12:00:00' ) );
		$previous_date_max->add( new DateInterval( 'P5M' ) );
		$previous_date_max->setDate( $previous_date_max->format( 'Y' ), $previous_date_max->format( 'm' ), $previous_date_max->format( 't' ));
		break;

	case 'this_year':
		$previous_date_min = ( new DateTime( $date_min->format( 'Y-m-d H:i:s' ) ) )->sub( new DateInterval( 'P1Y' ) ) ;
		$previous_date_max = ( new DateTime( $date_max->format( 'Y-m-d H:i:s' ) ) )->sub( new DateInterval( 'P1Y' ) ) ;
		break;

	case 'last_year':
		$previous_date_min = ( new DateTime( $date_min->format( 'Y-m-d H:i:s' ) ) )->sub( new DateInterval( 'P1Y' ) ) ;
		$previous_date_max = ( new DateTime( $date_max->format( 'Y-m-d H:i:s' ) ) )->sub( new DateInterval( 'P1Y' ) ) ;
		break;
	
	case 'custom':
		$date_difference = $date_min->diff( $date_max );
		$previous_date_min = ( new DateTime( $date_min->format( 'Y-m-d H:i:s' ) ) )->sub( $date_difference ) ;
		$previous_date_max = ( new DateTime( $date_max->format( 'Y-m-d H:i:s' ) ) )->sub( $date_difference ) ;
		$previous_date_max->sub( new DateInterval( 'P1D' ) );

		$date_difference = $date_difference->format('%d') + 1;
		break;

	default:
		break;	

}

// Set the time for comparison dates
$previous_date_min->setTime( 00, 00, 00 );
$previous_date_max->setTime( 23, 59, 59 );

/**
 * Build the args for database selection of the filtered period
 *
 */
$args_selected = array(
	'affiliate_id'	=> $affiliate_id,
	'date_min'		=> get_gmt_from_date( $date_min->format( 'Y-m-d H:i:s' ) ),
	'date_max'		=> get_gmt_from_date( $date_max->format( 'Y-m-d H:i:s' ) )
);

// Build the args for database selection of the comparison period
$args_compare = array(
	'affiliate_id'	=> $affiliate_id,
	'date_min' 		=> get_gmt_from_date( $previous_date_min->format( 'Y-m-d H:i:s' ) ),
	'date_max'		=> get_gmt_from_date( $previous_date_max->format( 'Y-m-d H:i:s' ) )
);


?>

<div class="wrap slicewp-wrap slicewp-wrap-reports">

	<form action="" method="GET">

		<!-- Page Heading -->
		<h1 class="wp-heading-inline"><?php echo __( 'Reports', 'slicewp-reports' ); ?></h1>
		<hr class="wp-header-end" />

		<!-- Tab Navigation -->
		<div class="slicewp-card">

			<!-- Navigation Tab Links -->
			<ul class="slicewp-nav-tab-wrapper">
				<?php 
					foreach( $tabs as $tab_slug => $tab ) {
						
						echo '<li class="slicewp-nav-tab ' . ( $tab_slug == $active_tab ? 'slicewp-active' : '' ) . '">';

							echo '<a href=" ' . esc_url( add_query_arg( array( 'page' => 'slicewp-reports', 'tab' => $tab_slug ) ) ) . ' ">';

								// Icon.
								if ( strpos( $tab['icon'], 'dashicons-' ) === 0 ) {
									echo '<span class="dashicons ' . esc_attr( $tab['icon'] ) . '"></span>';
								} else {
									echo wp_kses( $tab['icon'], slicewp_get_kses_allowed_html() );
								}

								// Label.
								echo esc_attr( $tab['label'] );

							echo '</a>';

						echo '</li>';

					}
				?>
			</ul>

			<!-- Hidden active tab -->
			<input type="hidden" name="tab" value="<?php echo esc_attr( $active_tab ); ?>" />

		</div>

		<div id="slicewp-reports-filters" class="slicewp-table-filters">

			<?php if ( $active_tab != 'affiliates' ): ?>

				<!-- Affiliate User ID -->
				<div class="slicewp-field-wrapper slicewp-field-wrapper-users-autocomplete">

					<?php slicewp_output_select2_user_search( array( 'id' => 'slicewp-affiliate-id', 'name' => 'affiliate_id', 'placeholder' => __( 'Select affiliate...', 'slicewp' ), 'user_type' => 'affiliate', 'value' => ( ! empty( $_GET['affiliate_id'] ) ? absint( $_GET['affiliate_id'] ) : '' ) ) ); ?>
					
				</div>
			
			<?php endif; ?>

			<!-- Period -->
			<div class="slicewp-field-wrapper">
				
				<select id="slicewp-reports-period-select" name="reports_period_filter" class="slicewp-select2">
					<option value="last_seven_days" <?php echo ( ! empty( $_GET['reports_period_filter']) && $_GET['reports_period_filter'] == 'last_seven_days' ? 'selected' : '' ); ?>><?php echo __('Last 7 Days', 'slicewp-reports'); ?></option>
					<option value="last_thirty_days" <?php echo ( ! empty( $_GET['reports_period_filter']) && $_GET['reports_period_filter'] == 'last_thirty_days' ? 'selected' : '' ); ?>><?php echo __('Last 30 Days', 'slicewp-reports'); ?></option>
					<option value="this_month" <?php echo ( ! empty( $_GET['reports_period_filter']) && $_GET['reports_period_filter'] == 'this_month' ? 'selected' : '' ); ?>><?php echo __('This Month', 'slicewp-reports'); ?></option>
					<option value="last_month" <?php echo ( ! empty( $_GET['reports_period_filter']) && $_GET['reports_period_filter'] == 'last_month' ? 'selected' : '' ); ?>><?php echo __('Last Month', 'slicewp-reports'); ?></option>
					<option value="last_three_months" <?php echo ( ! empty( $_GET['reports_period_filter']) && $_GET['reports_period_filter'] == 'last_three_months' ? 'selected' : '' ); ?>><?php echo __('Last 3 Months', 'slicewp-reports'); ?></option>
					<option value="last_six_months" <?php echo ( ! empty( $_GET['reports_period_filter']) && $_GET['reports_period_filter'] == 'last_six_months' ? 'selected' : '' ); ?>><?php echo __('Last 6 Months', 'slicewp-reports'); ?></option>
					<option value="this_year" <?php echo ( ! empty( $_GET['reports_period_filter']) && $_GET['reports_period_filter'] == 'this_year' ? 'selected' : '' ); ?>><?php echo __('This Year', 'slicewp-reports'); ?></option>
					<option value="last_year" <?php echo ( ! empty( $_GET['reports_period_filter']) && $_GET['reports_period_filter'] == 'last_year' ? 'selected' : '' ); ?>><?php echo __('Last Year', 'slicewp-reports'); ?></option>
					<option value="custom" <?php echo ( ! empty( $_GET['reports_period_filter']) && $_GET['reports_period_filter'] == 'custom' ? 'selected' : '' ); ?>><?php echo __('Custom', 'slicewp-reports'); ?></option>
				</select>

			</div>
			
			<!-- Date Min -->
			<div id="slicewp-reports-period-start-wrapper" class="slicewp-field-wrapper slicewp-field-wrapper-datepicker" style="display: none">

				<input type="text" id="slicewp-reports-period-start" name="date_min" class="slicewp-datepicker" autocomplete="off" placeholder="<?php echo __( 'From', 'slicewp-reports' ); ?>" value="<?php echo ( ! empty( $_GET['date_min'] ) ? esc_attr( $_GET['date_min'] ) : '' )?>" />

			</div>

			<!-- Date Max -->
			<div id="slicewp-reports-period-end-wrapper" class="slicewp-field-wrapper slicewp-field-wrapper-datepicker" style="display: none">

				<input type="text" id="slicewp-reports-period-end" name="date_max" class="slicewp-datepicker" autocomplete="off" placeholder="<?php echo __( 'To', 'slicewp-reports' ); ?>" value="<?php echo ( ! empty( $_GET['date_max'] ) ? esc_attr( $_GET['date_max'] ) : '' )?>" />

			</div>

			<input type="submit" class="slicewp-button-secondary" value="<?php echo __( 'Filter', 'slicewp-reports' ); ?>" />
			
		</div>

		<?php

		// Include the Reports View
		$dir_path = plugin_dir_path( __FILE__ );

		if ( $active_tab == 'commissions' && file_exists( $dir_path . 'view-reports-commissions.php' ) ) {
			include $dir_path . 'view-reports-commissions.php';
		}

		if ( $active_tab == 'visits' && file_exists( $dir_path . 'view-reports-visits.php' ) ) {
			include $dir_path . 'view-reports-visits.php';
		}

		if ( $active_tab == 'affiliates' && file_exists( $dir_path . 'view-reports-affiliates.php' ) ) {
			include $dir_path . 'view-reports-affiliates.php';
		}

		if ( $active_tab == 'payments' && file_exists( $dir_path . 'view-reports-payments.php' ) ) {
			include $dir_path . 'view-reports-payments.php';
		}

		?>

		<!-- Action and nonce -->
		<input type="hidden" id="date_min" value="<?php echo $date_min->format( 'Y-m-d H:i:s' ); ?>" />
		<input type="hidden" id="date_max" value="<?php echo $date_max->format( 'Y-m-d H:i:s' ); ?>" />

		<input type="hidden" name="page" value="slicewp-reports" />
		<input type="hidden" name="slicewp_action" value="filter_reports" />		
		<?php wp_nonce_field( 'slicewp_reports', 'slicewp_token', false ); ?>
		
	</form>
	
	<?php wp_referer_field( true ); ?>

</div>