<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Modifies the commission amount based on the affiliate's commission rates.
 *
 * @param float $commission_amount
 * @param float $amount
 * @param array $args
 *
 * @return float
 *
 */
function slicewp_calculate_commission_amount_affiliate_commission_rates( $commission_amount, $amount, $args ) {

	if ( empty( $args['type'] ) || $args['type'] == 'recurring' ) {
        return $commission_amount;
    }

	if ( empty( $args['affiliate_id'] ) ) {
        return $commission_amount;
    }

	$affiliate_id = absint( $args['affiliate_id'] );

	// Check if custom commissions are enabled.
	if ( empty( slicewp_get_affiliate_meta( $affiliate_id, 'enable_commission_rates', true ) ) ) {
        return $commission_amount;
    }

	$rate 	   = slicewp_get_affiliate_meta( $affiliate_id, 'commission_rate_' . $args['type'], true );
	$rate_type = slicewp_get_affiliate_meta( $affiliate_id, 'commission_rate_type_' . $args['type'], true );

	if ( ! is_numeric( $rate ) || empty( $rate_type ) ) {
        return $commission_amount;
    }

	$commission_amount = ( $rate_type == 'percentage' ? round( ( $amount * $rate / 100 ), 2 ) : $rate );

	// Calculate the commission amount for fixed amounts per product.
	if ( $args['type'] == 'sale' && $rate_type == 'fixed_amount' && slicewp_get_affiliate_meta( $affiliate_id, 'commission_fixed_amount_rate_basis', true ) == 'product' ) {

		$commission_amount = $rate * ( ! empty( $args['quantity'] ) ? $args['quantity'] : 1 );

	}

	return $commission_amount;

}
add_filter( 'slicewp_calculate_commission_amount', 'slicewp_calculate_commission_amount_affiliate_commission_rates', 20, 3 );


/**
 * Checks to see if the commissions are set to be calculated on a per order basis for the affiliate.
 *
 * @param bool $return
 *
 * @return bool
 *
 */
function slicewp_is_commission_basis_per_order_from_per_affiliate( $return ) {

	// Get and check to see if referrer exists.
	$affiliate_id = slicewp_get_referrer_affiliate_id();

	if ( empty( $affiliate_id ) ) {
        return $return;
    }

	// Check if custom commission rates are enabled for the affiliate.
	$enable_commission_rates = slicewp_get_affiliate_meta( $affiliate_id, 'enable_commission_rates', true );

	if ( empty( $enable_commission_rates ) ) {
        return $return;
    }

	// If the affiliate doesn't have a commission rate set exit.
	$commission_rate_sale = slicewp_get_affiliate_meta( $affiliate_id, 'commission_rate_type_sale', true );

	if ( empty( $commission_rate_sale ) ) {
        return $return;
    }

	if ( 'fixed_amount' == slicewp_get_affiliate_meta( $affiliate_id, 'commission_rate_type_sale', true ) ) {

		if ( 'order' == slicewp_get_affiliate_meta( $affiliate_id, 'commission_fixed_amount_rate_basis', true ) ) {
            $return = true;
        } else {
            $return = false;
        }

	}

	if ( 'percentage' == slicewp_get_affiliate_meta( $affiliate_id, 'commission_rate_type_sale', true ) ) {
        $return = false;
    }

	return $return;

}
add_filter( 'slicewp_is_commission_basis_per_order', 'slicewp_is_commission_basis_per_order_from_per_affiliate', 50 );


/**
 * Updates the commission rates displayed in the affiliate account from the values set for the affiliate.
 *
 * @param array $affiliate_commission_rates
 * @param int	$affiliate_id
 * 
 * @return array $affiliate_commission_rates
 * 
 */
function slicewp_affiliate_commission_rates_from_per_affiliate( $affiliate_commission_rates, $affiliate_id ) {

	// Check if custom commission rates are enabled for the affiliate.
	$enable_commission_rates = slicewp_get_affiliate_meta( $affiliate_id, 'enable_commission_rates', true );

	if ( empty( $enable_commission_rates ) ) {
        return $affiliate_commission_rates;
    }

	// If the affiliate doesn't have a commission rate set exit.
	foreach ( $affiliate_commission_rates as $type => $details ) {

		if ( $type == 'recurring' || $type == 'lifetime_sale' ) {
            continue;
        }

		$rate 	   = slicewp_get_affiliate_meta( $affiliate_id, 'commission_rate_' . $type , true );
		$rate_type = slicewp_get_affiliate_meta( $affiliate_id, 'commission_rate_type_' . $type, true );

		if ( is_numeric( $rate ) && ! empty( $rate_type ) ){

			$affiliate_commission_rates[$type]['rate'] 		= $rate; 
			$affiliate_commission_rates[$type]['rate_type'] = $rate_type; 
		
		}

	}

	// Return the affiliate commission rates.
	return $affiliate_commission_rates;

}
add_filter( 'slicewp_affiliate_commission_rates', 'slicewp_affiliate_commission_rates_from_per_affiliate', 50, 2 );