<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Payments by status chart class.
 *
 */
class SliceWP_Chart_Payments_Status extends SliceWP_Chart {

	/**
	 * Constructor.
	 *
	 */
	public function __construct( $args = array() ) {

		parent::__construct( $args );

		$this->id 	   = 'payments_status';
		$this->filters = array( 'dataset_select', 'time_unit_select', 'type_switch' );

		$this->generate_datasets();

	}


	/**
	 * Generates all datasets.
	 *
	 */
	protected function generate_datasets() {

		$statuses = slicewp_get_payment_available_statuses();

		foreach ( $statuses as $status_slug => $status_name ) {

			$this->datasets[$status_slug . '_amount'] = array(
				'label' 	=> sprintf( __( '%s amounts', 'slicewp' ), $status_name ),
				'data'  	=> $this->generate_dataset_data( $this->raw_data_filter_by_status( $status_slug ), 'amount' ),
				'is_amount' => true,
				'color'		=> $this->get_status_color( $status_slug )
			);

			$this->datasets[$status_slug . '_count'] = array(
				'label' 	=> sprintf( __( '%s payments', 'slicewp' ), $status_name ),
				'data'  	=> $this->generate_dataset_data( $this->raw_data_filter_by_status( $status_slug ) ),
				'color'		=> $this->get_status_color( $status_slug )
			);

		}

	}


	/**
	 * Filters the raw data by the given status and returns the objects that match the status.
	 *
	 * @param string $status
	 *
	 * @return array
	 *
	 */
	public function raw_data_filter_by_status( $status ) {

		$data = array();

		foreach ( $this->raw_data as $object ) {

			if ( $status == $object->get( 'status' ) ) {
				$data[] = $object;
			}

		}

		return $data;

	}


	/**
	 * Outputs the payments dataset select filter.
	 *
	 */
	public function output_filter_dataset_select() {

		$statuses = slicewp_get_payment_available_statuses();

		?>

			<div class="slicewp-field-wrapper slicewp-field-wrapper-chart-dataset">
                <select name="chart_filter_status" class="slicewp-select2 slicewp-chart-filter-dataset">
                	<option value="<?php echo htmlspecialchars( json_encode( array_map( function( $status_slug ) { return $status_slug . '_amount'; }, array_keys( $statuses ) ) ), ENT_QUOTES, 'UTF-8' ); ?>"><?php echo sprintf( __( 'Payment amounts (%s)' ), slicewp_get_currency_symbol( slicewp_get_setting( 'active_currency', 'USD' ) ) ); ?></option>
                	<option value="<?php echo htmlspecialchars( json_encode( array_map( function( $status_slug ) { return $status_slug . '_count'; }, array_keys( $statuses ) ) ), ENT_QUOTES, 'UTF-8' ); ?>"><?php echo __( 'Payments count', 'slicewp' ); ?></option>
                </select>
            </div>

		<?php

	}


	/**
	 * Returns the color name associated with the given status.
	 *
	 * @param string $status
	 *
	 * @return string
	 *
	 */
	protected function get_status_color( $status ) {

		switch ( $status ) {

			case 'paid':
				$color = '#1abc9c';
				break;

			case 'unpaid':
				$color = '#3498db';
				break;

			case 'processing':
				$color = '#f39c12';
				break;

			case 'failed':
				$color = '#c0392b';
				break;

			default:
				$color = '#567491';
				break;

		}

		return $color;

	}

}