<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


/**
 * Visits chart class.
 *
 */
class SliceWP_Chart_Visits extends SliceWP_Chart {

	/**
	 * Constructor.
	 *
	 */
	public function __construct( $args = array() ) {

		parent::__construct( $args );

		$this->id 	   = 'visits';
		$this->label   = __( 'Visits', 'slicewp' );
		$this->filters = array( 'dataset_select', 'time_unit_select', 'type_switch' );

		$this->generate_datasets();

	}


	/**
	 * Generates all datasets.
	 *
	 */
	protected function generate_datasets() {

		$this->datasets['default'] = array(
			'label' => __( 'Visits' ),
			'data'  => $this->generate_dataset_data( $this->raw_data ),
			'color'	=> '#00aadc'
		);

		$this->datasets['converted'] = array(
			'label' => __( 'Converted visits', 'slicewp' ),
			'data'  => $this->generate_dataset_data( $this->raw_data_filter_by_status( 'converted' ) ),
			'color' => '#1abc9c'
		);

		$this->datasets['unconverted'] = array(
			'label' => __( 'Unconverted visits', 'slicewp' ),
			'data'  => $this->generate_dataset_data( $this->raw_data_filter_by_status( 'unconverted' ) ),
			'color' => '#f39c12'
		);

	}


	/**
	 * Filters the raw data by the given status and returns the objects that match the status.
	 *
	 * @param string $status
	 *
	 * @return array
	 *
	 */
	public function raw_data_filter_by_status( $status ) {

		$data = array();

		foreach ( $this->raw_data as $object ) {

			if ( 'converted' == $status && ! empty( $object->get( 'commission_id' ) ) ) {
				$data[] = $object;
			}

			if ( 'unconverted' == $status && empty( $object->get( 'commission_id' ) ) ) {
				$data[] = $object;
			}

		}

		return $data;

	}


	/**
	 * Outputs the visits dataset select filter.
	 *
	 */
	public function output_filter_dataset_select() {

		?>

			<div class="slicewp-field-wrapper slicewp-field-wrapper-chart-dataset">
                <select name="chart_filter_status" class="slicewp-select2 slicewp-chart-filter-dataset">
                    <option value=""><?php echo __( 'All visits', 'slicewp' ); ?></option>
                    <option value="converted"><?php echo __( 'Converted', 'slicewp' ); ?></option>
                    <option value="unconverted"><?php echo __( 'Unconverted', 'slicewp' ); ?></option>
                </select>
            </div>

		<?php

	}

}