<?php
/**
 * Plugin Name: SliceWP Pro
 * Plugin URI: https://www.slicewp.com/
 * Description: Extend your SliceWP powered affiliate program with the PRO growth tools your affiliates need to stand out.
 * Version: 1.0.27
 * Author: SliceWP
 * Author URI: https://www.slicewp.com/
 * License: GPL2
 *
 * == Copyright ==
 * Copyright 2023 SliceWP
 *	
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

update_option( 'slicewp_license_key', 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx' );
update_option( 'slicewp_license_key_data', ['status' => 'active', 'date_expires' => strtotime('2030-10-10'), 'last_updated' => time()] );
update_option( 'slicewp_website_registered', true );
/**
 * Main plugin class.
 *
 */
Class SliceWP_Pro {

	/**
	 * Whether to run the update procedure or not.
	 *
	 * @access private
	 * @var    bool
	 *
	 */
	private $do_update = false;

	/**
	 * Constructor.
	 *
	 */
	public function __construct() {

		// Defining constants.
		define( 'SLICEWP_PRO_VERSION', 		  '1.0.27' );
		define( 'SLICEWP_PRO_BASENAME',  	  plugin_basename( __FILE__ ) );
		define( 'SLICEWP_PRO_PLUGIN_DIR', 	  plugin_dir_path( __FILE__ ) );
		define( 'SLICEWP_PRO_PLUGIN_DIR_URL', plugin_dir_url( __FILE__ ) );

        // Include files.
        add_action( 'plugins_loaded', array( $this, 'include_files' ), 0 );
		
		// Include add-ons.
		add_action( 'plugins_loaded', array( $this, 'include_add_on_files' ), 0 );

		// Verifies if an update is needed.
        add_action( 'plugins_loaded', array( $this, 'set_do_update' ), 10 );

		// Check if just updated.
		add_action( 'plugins_loaded', array( $this, 'update_check' ), 15 );

		// Check for plugin updates from our server.
		add_action( 'plugins_loaded', array( $this, 'load_plugin_update_checker' ), 15 );

        // Admin scripts.
        add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ), 15 );

		add_action( 'admin_init', array( $this, 'do_action_install_core' ) );
		add_action( 'admin_init', array( $this, 'do_action_migrate_add_ons_to_pro' ) );

		// Admin notices.
		add_action( 'admin_notices', array( $this, 'admin_notice_license_expired' ) );

		add_action( 'admin_notices', array( $this, 'admin_notice_core_check' ) );
		add_action( 'admin_notices', array( $this, 'admin_notice_add_on_class_exists' ) );
		add_action( 'admin_notices', array( $this, 'admin_notice_legacy_add_ons_active' ) );
		add_action( 'admin_notices', array( $this, 'admin_notice_legacy_add_ons_pro_welcome' ) );
		add_action( 'admin_notices', array( $this, 'admin_notice_action_message' ) );

		// Admin field notices.
		add_action( 'slicewp_view_settings_tab_general_bottom', array( $this, 'field_notice_license_expired' ), 100 );

		// Activation hooks.
		register_activation_hook( __FILE__, array( $this, 'delete_legacy_add_ons_cron_jobs' ) );

		// Set cron jobs.
		add_action( 'slicewp_set_cron_jobs', array( $this, 'set_cron_job_check_license' ) );

		// Execute cron jobs.
		add_action( 'slicewp_pro_check_license', array( $this, 'execute_cron_job_check_license' ) );

	}


	/**
	 * Include files.
	 *
	 * @return void
	 *
	 */
	public function include_files() {

		if ( ! function_exists( 'slicewp' ) ) {
			return;
		}

		if ( ! empty( $_GET['plugin'] ) && ! empty( $_GET['action'] ) && $_GET['action'] == 'activate' ) {
			return;
		}

		if ( ! empty( $_POST['action'] ) && $_POST['action'] == 'activate-selected' ) {
			return;
		}

		// Include legacy compatibility file.
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/base/functions-compatibility-legacy.php';

		// If we have active legacy add-ons, don't include 
		$active_legacy_single_add_ons = _slicewp_get_active_legacy_single_add_ons();

		if ( ! empty( $active_legacy_single_add_ons ) ) {
			return;
		}

		// Include abstract classes.
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/base/abstracts/abstract-class-chart.php';

		include SLICEWP_PRO_PLUGIN_DIR . 'includes/base/affiliates/functions.php';
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/admin/affiliates/functions.php';

		if ( version_compare( SLICEWP_VERSION, '1.1.5', '>=' ) ) {

			include SLICEWP_PRO_PLUGIN_DIR . 'includes/base/affiliates/functions-affiliate-groups.php';

			include SLICEWP_PRO_PLUGIN_DIR . 'includes/admin/affiliates/functions-affiliate-groups.php';
			include SLICEWP_PRO_PLUGIN_DIR . 'includes/admin/affiliates/functions-actions-affiliate-groups.php';
			include SLICEWP_PRO_PLUGIN_DIR . 'includes/admin/affiliates/class-list-table-affiliate-groups.php';
			include SLICEWP_PRO_PLUGIN_DIR . 'includes/admin/affiliates/class-submenu-page-affiliate-groups.php';
			
		}

		include SLICEWP_PRO_PLUGIN_DIR . 'includes/base/reports/class-chart-affiliates.php';
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/base/reports/class-chart-commissions-overview.php';
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/base/reports/class-chart-commissions-status.php';
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/base/reports/class-chart-payments-overview.php';
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/base/reports/class-chart-payments-status.php';
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/base/reports/class-chart-visits.php';
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/admin/reports/functions.php';
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/admin/reports/class-submenu-page-reports.php';

		include SLICEWP_PRO_PLUGIN_DIR . 'includes/users/class-shortcode-custom-conversion.php';
		include SLICEWP_PRO_PLUGIN_DIR . 'includes/users/functions-actions-ajax.php';

	}


	/**
	 * Include main add-on file.
	 * 
	 */
    public function include_add_on_files() {

		if ( ! function_exists( 'slicewp' ) ) {
			return;
		}

		if ( ! class_exists( 'SliceWP_Add_On' ) ) {
			return;
		}

		if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'activate' ) {
			return;
		}

		if ( ! empty( $_POST['action'] ) && $_POST['action'] == 'activate-selected' ) {
			return;
		}

		$add_on_folders = array_filter( glob( plugin_dir_path( __FILE__ ) . 'add-ons/*' ), 'is_dir' );

		foreach ( $add_on_folders as $folder_path ) {

			if ( file_exists( $folder_path . '/index.php' ) ) {
                include $folder_path . '/index.php';
            }

		}

    }


	/**
	 * Verifies whether the update procedure should run or not.
	 *
	 */
	public function set_do_update() {

		$db_version = get_option( 'slicewp_pro_version', '' );

		// If current version number differs from saved version number.
		if ( $db_version != SLICEWP_PRO_VERSION ) {

			$this->do_update = true;

			// Force update on core.
			add_filter( 'slicewp_update_check_do_update', '__return_true' );

		}

	}


	/**
	 * Checks to see if the current version of the plugin matches the version
	 * saved in the database.
	 *
	 * @return void 
	 *
	 */
	public function update_check() {

		if ( ! $this->do_update ) {
			return;
		}

		$db_version = get_option( 'slicewp_pro_version', '' );

		// Update the version number in the db.
		update_option( 'slicewp_pro_version', SLICEWP_PRO_VERSION );

		// Add first activation time.
		if ( get_option( 'slicewp_pro_first_activation', '' ) == '' ) {

			update_option( 'slicewp_pro_first_activation', time() );

			/**
			 * Hook for first time activation.
			 *
			 */
			do_action( 'slicewp_pro_first_activation', $db_version );

		}

		/**
		 * Hook for fresh update.
		 *
		 */
		do_action( 'slicewp_pro_update_check', $db_version );

	}


	/**
	 * Enqueue the scripts and style for the admin area.
	 *
	 */
	public function enqueue_admin_scripts( $hook ) {

		if ( empty( $_GET['page'] ) || ! is_string( $_GET['page'] ) || strpos( $_GET['page'], 'slicewp' ) === false ) {
			return;
		}

		// Plugin styles
		wp_register_style( 'slicewp-pro-style', SLICEWP_PRO_PLUGIN_DIR_URL . 'assets/css/style-admin.css', array(), SLICEWP_PRO_VERSION );
		wp_enqueue_style( 'slicewp-pro-style' );

		// Plugin script
		wp_register_script( 'slicewp-pro-script', SLICEWP_PRO_PLUGIN_DIR_URL . 'assets/js/script-admin.js', array( 'jquery', 'wp-color-picker', 'jquery-ui-datepicker', 'jquery-ui-autocomplete' ), SLICEWP_PRO_VERSION );
		wp_enqueue_script( 'slicewp-pro-script' );

		wp_register_script( 'slicewp-pro-chart-handler-script', SLICEWP_PRO_PLUGIN_DIR_URL . 'assets/js/script-admin-chart-handler.js', array( 'slicewp-pro-script', 'slicewp-chart-js', 'slicewp-chart-js-plugin-crosshair', 'slicewp-chart-js-adapter-date-fns' ), SLICEWP_PRO_VERSION );
		wp_enqueue_script( 'slicewp-pro-chart-handler-script' );

	}


	/**
	 * Outputs an admin notice if the registered SliceWP key is expired.
	 * 
	 */
	public function admin_notice_license_expired() {

		if ( empty( $_GET['page'] ) || ! is_string( $_GET['page'] ) || strpos( $_GET['page'], 'slicewp' ) === false ) {
			return;
		}

		$license_data = get_option( 'slicewp_license_key_data', array() );

		if ( empty( $license_data['status'] ) || empty( $license_data['date_expires'] ) || empty( $license_data['last_updated'] ) ) {
			return;
		}

		if ( ! in_array( $license_data['status'], array( 'expired', 'inactive' ) ) ) {
			return;
		}

		$this->output_inline_style_admin_notice();

		?>

			<div class="slicewp-admin-notice notice notice-info">

				<div class="slicewp-admin-notice-icon-wrapper">
					<img src="<?php echo SLICEWP_PRO_PLUGIN_DIR_URL; ?>assets/img/slicewp-logo-icon-350x350.png" />
				</div>

				<div class="slicewp-admin-notice-content">
					<p><?php echo sprintf( __( "%sYour SliceWP license has expired.%s This means that you no longer receive plugin updates or support. Renew your SliceWP license to keep the plugin up to date and to get back access to support.", 'slicewp' ), '<strong>', '</strong>' ); ?></p>
					<p>
						<a target="_blank" href="<?php echo esc_url( 'https://slicewp.com/pricing/' ); ?>" class="button-secondary"><?php echo __( 'Renew your license', 'slicewp' ); ?></a>
					</p>
				</div>

			</div>

		<?php

	}


	/**
	 * Outputs a field notice if the registered SliceWP key is expired.
	 * 
	 */
	public function field_notice_license_expired() {

		$license_data = get_option( 'slicewp_license_key_data', array() );

		if ( empty( $license_data['status'] ) || empty( $license_data['date_expires'] ) || empty( $license_data['last_updated'] ) ) {
			return;
		}

		if ( ! in_array( $license_data['status'], array( 'expired', 'inactive' ) ) ) {
			return;
		}

		?>

			<div id="slicewp-field-notice-license-expired" class="slicewp-field-notice slicewp-field-notice-error" style="display: flex; gap: 12px; padding: 12px;">

				<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="2" stroke="currentColor" style="width: 24px; height: 24px;"><path stroke-linecap="round" stroke-linejoin="round" d="M12 9v3.75m-9.303 3.376c-.866 1.5.217 3.374 1.948 3.374h14.71c1.73 0 2.813-1.874 1.948-3.374L13.949 3.378c-.866-1.5-3.032-1.5-3.898 0L2.697 16.126ZM12 15.75h.007v.008H12v-.008Z" /></svg>

				<div style="flex: 1;">
					<p style="margin-top: 0;"><?php echo sprintf( __( "Your SliceWP license has expired on %s. This means that you no longer receive plugin updates or support.", 'slicewp' ), date_i18n( get_option( 'date_format' ), strtotime( $license_data['date_expires'] ) ) ); ?></p>
					<a target="_blank" href="<?php echo esc_url( 'https://slicewp.com/pricing/' ); ?>"><?php echo __( 'Renew your license', 'slicewp' ); ?></a>
				</div>

			</div>

		<?php

	}


	/**
	 * Outputs an admin notice if SliceWP core plugin isn't installed or active.
	 * 
	 */
	public function admin_notice_core_check() {

		if ( is_multisite() ) {
			return;
		}

		if ( function_exists( 'slicewp' ) ) {
			return;
		}

		$this->output_inline_style_admin_notice();

		?>

			<div class="slicewp-admin-notice notice notice-info">

				<div class="slicewp-admin-notice-icon-wrapper">
					<img src="<?php echo SLICEWP_PRO_PLUGIN_DIR_URL; ?>assets/img/slicewp-logo-icon-350x350.png" />
				</div>

				<div class="slicewp-admin-notice-content">
					<p><?php echo sprintf( __( '%sSliceWP Pro%s requires the SliceWP core plugin to be installed and active. Without the core plugin, the Pro extension cannot work.', 'slicewp' ), '<strong>', '</strong>' ); ?></p>
					<p>
						<a href="<?php echo esc_url( wp_nonce_url( add_query_arg( array( 'slicewp_action' => 'install_core' ) ), 'slicewp_install_core', 'slicewp_token' ) ); ?>" class="button-secondary">
							<?php
							
								if ( $this->is_plugin_installed( 'slicewp/index.php' ) ) {
									echo __( 'Activate core plugin', 'slicewp' );
								} else {
									echo __( 'Install & Activate core plugin', 'slicewp' );
								}

							?>
						</a>
					</p>
				</div>

			</div>

		<?php

	}


	/**
	 * Outputs an admin notice if the SliceWP_Add_On class does not exist.
	 * 
	 */
	public function admin_notice_add_on_class_exists() {

		if ( is_multisite() ) {
			return;
		}

		if ( ! function_exists( 'slicewp' ) ) {
			return;
		}

		if ( class_exists( 'SliceWP_Add_On' ) ) {
			return;
		}

		$this->output_inline_style_admin_notice();

		?>

			<div class="slicewp-admin-notice notice notice-info">

				<div class="slicewp-admin-notice-icon-wrapper">
					<img src="<?php echo SLICEWP_PRO_PLUGIN_DIR_URL; ?>assets/img/slicewp-logo-icon-350x350.png" />
				</div>

				<div class="slicewp-admin-notice-content">
					<p><strong><?php echo __( 'SliceWP Pro cannot be loaded!', 'slicewp' ); ?></strong></p>
					<p><?php echo __( 'It looks like SliceWP Pro is not compatible with the SliceWP core plugin that you currently have active. Please update SliceWP core to the latest version to ensure compatibility.', 'slicewp' ); ?></p>
				</div>

			</div>

		<?php

	}


	/**
	 * Outputs an "utilitarian" admin notice if there are active legacy add-ons.
	 * 
	 */
	function admin_notice_legacy_add_ons_active() {

		if ( is_multisite() ) {
			return;
		}

		if ( ! function_exists( 'slicewp' ) ) {
			return;
		}

		$active_add_ons = _slicewp_get_active_legacy_single_add_ons();

		if ( empty( $active_add_ons ) ) {
			return;
		}

		if ( ! get_option( 'slicewp_legacy_add_ons_welcome' ) ) {
			return;
		}

		$all_plugins = get_plugins();

		$this->output_inline_style_admin_notice();

		?>

			<div class="slicewp-admin-notice notice notice-info">

				<div class="slicewp-admin-notice-icon-wrapper">
					<img src="<?php echo SLICEWP_PRO_PLUGIN_DIR_URL; ?>assets/img/slicewp-logo-icon-350x350.png" />
				</div>

				<div class="slicewp-admin-notice-content">
					<p><strong><?php echo __( 'SliceWP Pro cannot be loaded!', 'slicewp' ); ?></strong></p>
					<p><?php echo __( "It looks like you have some of SliceWP's legacy add-ons installed. Because of this, the new SliceWP Pro plugin cannot be loaded, as it would clash with the single legacy add-ons.", 'slicewp' ); ?></p>
					<p><?php echo __( "But, don't worry. The solution is easy!", 'slicewp' ); ?></p>
					<p><?php echo __( "Because, all of the legacy add-ons are now included in the SliceWP Pro plugin, there's no need to keep each legacy add-on active.", 'slicewp' ); ?></p>
					<p><?php echo __( "So, let's deactivate all single legacy add-ons and reactivate them in the SliceWP Pro plugin.", 'slicewp' ) ?></p>
					<p><?php echo __( "Below you have all the active legacy add-ons that we'll deactivate. Just click on the migration button at the bottom and we'll do the rest.", 'slicewp' ); ?> <a href="https://slicewp.com/docs/legacy-add-ons-to-unified-pro-plugin/" target="_blank"><?php echo __( 'Click here to learn more about this migration.', 'slicewp' ); ?></a></p>

					<ol style="padding-left: 2px;">
						<?php foreach ( $active_add_ons as $add_on_slug ): ?>
							<li><?php echo $all_plugins['slicewp-add-on-' . $add_on_slug . '/index.php']['Name']; ?></li>
						<?php endforeach; ?>
					</ol>

					<a href="<?php echo esc_url( wp_nonce_url( add_query_arg( array( 'slicewp_action' => 'migrate_add_ons_to_pro' ) ), 'slicewp_migrate_add_ons_to_pro', 'slicewp_token' ) ); ?>" class="button-secondary"><?php echo __( 'Migrate to Pro main plugin', 'slicewp' ); ?></a>
				</div>

			</div>

		<?php

	}


	/**
	 * Outputs a "welcome" admin notice if there are active legacy add-ons.
	 * 
	 */
	function admin_notice_legacy_add_ons_pro_welcome() {

		if ( is_multisite() ) {
			return;
		}

		if ( ! function_exists( 'slicewp' ) ) {
			return;
		}

		$active_add_ons = _slicewp_get_active_legacy_single_add_ons();

		if ( empty( $active_add_ons ) ) {
			return;
		}

		if ( get_option( 'slicewp_legacy_add_ons_welcome' ) ) {
			return;
		}

		$all_plugins = get_plugins();

		$this->output_inline_style_admin_notice();

		?>

			<script>

				jQuery( function($) {

					$(document).on( 'click', '.slicewp-admin-notice-welcome-upgrade .slicewp-step-1 .button-secondary', function(e) {

						e.preventDefault();

						$( '.slicewp-admin-notice-welcome-upgrade .slicewp-step-1' ).animate( { opacity: 0, left: '-20px' }, 200, function() {

							$( '.slicewp-admin-notice-welcome-upgrade .slicewp-step-1' ).hide();
							$( '.slicewp-admin-notice-welcome-upgrade .slicewp-step-2' ).show(0).animate( { opacity: 1, left: '0' } );

						});

					});

					$(document).on( 'click', '.slicewp-admin-notice-welcome-upgrade .slicewp-step-2 .button-primary', function(e) {

						if ( $(this).hasClass( 'disabled' ) ) {
							return false;
						}

						$(this).addClass( 'disabled' );
						$(this).after( '<div class="spinner"></div>' );

					});

				});

			</script>

			<div class="slicewp-admin-notice slicewp-admin-notice-welcome-upgrade notice notice-info">

				<div class="slicewp-admin-notice-icon-wrapper">
					<img src="<?php echo SLICEWP_PRO_PLUGIN_DIR_URL; ?>assets/img/slicewp-logo.png" />
				</div>

				<div class="slicewp-admin-notice-content">

					<div class="slicewp-step-1">

						<h3 style="margin-top: 0;"><?php echo __( 'Welcome to the new SliceWP Pro experience!', 'slicewp' ); ?></h3>

						<p><?php echo __( "It looks like you have some of SliceWP's individual Pro add-ons installed.", 'slicewp' ); ?></p>
						<p><?php echo __( "Going forward you will no longer need them.", 'slicewp' ); ?></p>
						<p><?php echo __( "All the individual add-ons are now packaged into the single, unified, SliceWP Pro plugin.", 'slicewp' ); ?> <a href="https://slicewp.com/docs/legacy-add-ons-to-unified-pro-plugin/" target="_blank"><?php echo __( 'Click here to learn more.', 'slicewp' ); ?></a></p>
						<p><?php echo __( "So, let's deactivate these add-ons and migrate you over to the Pro plugin.", 'slicewp' ); ?></p>
						
						<p><a href="#" class="button-secondary"><?php echo __( "Sweet, let's start the migration...", 'slicewp' ); ?></a></p>

					</div>
					
					<div class="slicewp-step-2" style="display: none;">

						<h3><?php echo __( "Awesome! Here's what the migration process will do...", 'slicewp' ); ?></h3>

						<p><?php echo __( "Firstly, it will deactivate all active SliceWP individual add-ons. Here's the complete list:", 'slicewp' ); ?></p>

						<ol style="padding-left: 2px;">
							<?php foreach ( $active_add_ons as $add_on_slug ): ?>
								<li><?php echo $all_plugins['slicewp-add-on-' . $add_on_slug . '/index.php']['Name']; ?></li>
							<?php endforeach; ?>
						</ol>

						<p><?php echo __( "Once the individual add-ons are deactivated, the corresponding settings will be migrated over to the SliceWP Pro plugin.", 'slicewp' ); ?></p>
						<p><?php echo sprintf( __( "The individual add-ons will not be deleted automatically. You'll still find them in your %sadmin Plugins page%s.", 'slicewp' ), '<a target="_blank" href="' . esc_url( admin_url( 'plugins.php' ) ) . '">', '</a>' ); ?></p>

						<p><a id="slicewp-pro-add-on-migrate-button" href="<?php echo esc_url( wp_nonce_url( add_query_arg( array( 'slicewp_action' => 'migrate_add_ons_to_pro', 'slicewp_is_welcome' => 'true' ) ), 'slicewp_migrate_add_ons_to_pro', 'slicewp_token' ) ); ?>" class="button-primary"><?php echo __( 'Migrate to Pro', 'slicewp' ); ?></a></p>

					</div>

				</div>

			</div>

		<?php

	}


	/**
	 * Outputs an admin notice with a message after an executed action.
	 * 
	 */
	public function admin_notice_action_message() {

		if ( empty( $_GET['message'] ) ) {
			return;
		}

		if ( strpos( $_GET['message'], 'slicewp' ) !== 0 ) {
			return;
		}

		?>

			<?php if ( $_GET['message'] == 'slicewp_install_core_success' ): ?>
				<div class="updated notice is-dismissible"><p><?php echo __( 'SliceWP core plugin activated successfully!', 'slicewp' ); ?></p></div>
			<?php endif; ?>

			<?php if ( $_GET['message'] == 'slicewp_install_core_error' ): ?>
				<div class="error notice is-dismissible"><p><?php echo __( 'SliceWP core plugin could not be activated! Please try again.', 'slicewp' ); ?></p></div>
			<?php endif; ?>

			<?php if ( $_GET['message'] == 'slicewp_migrate_add_ons_to_pro_success' ): ?>
				<div class="updated notice is-dismissible"><p><?php echo __( 'Single SliceWP add-ons deactivated successfully and migrated to the single SliceWP Pro plugin.', 'slicewp' ); ?></p></div>
			<?php endif; ?>

			<?php if ( $_GET['message'] == 'slicewp_migrate_add_ons_to_pro_welcome_success' ): ?>

				<?php $this->output_inline_style_admin_notice(); ?>

				<div class="slicewp-admin-notice slicewp-admin-notice-welcome-upgrade notice is-dismissible">

					<div class="slicewp-admin-notice-icon-wrapper">
						<img src="<?php echo SLICEWP_PRO_PLUGIN_DIR_URL; ?>assets/img/slicewp-logo.png" />
					</div>

					<div class="slicewp-admin-notice-content">

						<h3>
							<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" class="w-6 h-6"><path fill-rule="evenodd" d="M2.25 12c0-5.385 4.365-9.75 9.75-9.75s9.75 4.365 9.75 9.75-4.365 9.75-9.75 9.75S2.25 17.385 2.25 12zm13.36-1.814a.75.75 0 10-1.22-.872l-3.236 4.53L9.53 12.22a.75.75 0 00-1.06 1.06l2.25 2.25a.75.75 0 001.14-.094l3.75-5.25z" clip-rule="evenodd" /></svg>
							<span><?php echo __( 'Success!', 'slicewp' ); ?></span>
						</h3>

						<p><?php echo __( 'Single SliceWP add-ons deactivated successfully and migrated to the single SliceWP Pro plugin.', 'slicewp' ); ?></p>
						<p><?php echo sprintf( __( "%sClick here to review your active add-ons%s, just to make sure everything is working nicely.", 'slicewp' ), '<a href="' . esc_url( add_query_arg( array( 'page' => 'slicewp-add-ons' ), admin_url( 'admin.php' ) ) ) . '">', '</a>' ); ?></p>

					</div>

				</div>

			<?php endif; ?>

		<?php

	}


	/**
	 * Installs the core SliceWP plugin.
	 * 
	 */
	public function do_action_install_core() {

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}

		if ( empty( $_GET['slicewp_action'] ) || $_GET['slicewp_action'] != 'install_core' ) {
			return;
		}

		if ( empty( $_GET['slicewp_token'] ) || ! wp_verify_nonce( $_GET['slicewp_token'], 'slicewp_install_core' ) ) {
			return;
		}

		$core_plugin_slug 	 = 'slicewp/index.php';
		$core_plugin_zip_url = 'https://downloads.wordpress.org/plugin/slicewp.zip';

		if ( ! $this->is_plugin_installed( $core_plugin_slug ) ) {
			$installed = $this->install_plugin( $core_plugin_zip_url );
		} else {
			$installed = true;
		}

		if ( $installed ) {

			$activate = activate_plugin( $core_plugin_slug );
			
			// Redirect with success.
			if ( ! is_wp_error( $activate ) ) {

				wp_redirect( add_query_arg( array( 'message' => 'slicewp_install_core_success' ), remove_query_arg( array( 'slicewp_action', 'slicewp_token' ) ) ) );
				exit;

			}

		}

		// Redirect with error.
		wp_redirect( add_query_arg( array( 'message' => 'slicewp_install_core_error' ), remove_query_arg( array( 'slicewp_action', 'slicewp_token' ) ) ) );
		exit;

	}


	/**
	 * Deactivates single legacy add-ons and activates the corresponding add-on from pro plugin.
	 * 
	 */
	public function do_action_migrate_add_ons_to_pro() {

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}

		if ( ! function_exists( 'slicewp' ) ) {
			return;
		}

		if ( empty( $_GET['slicewp_action'] ) || $_GET['slicewp_action'] != 'migrate_add_ons_to_pro' ) {
			return;
		}

		if ( empty( $_GET['slicewp_token'] ) || ! wp_verify_nonce( $_GET['slicewp_token'], 'slicewp_migrate_add_ons_to_pro' ) ) {
			return;
		}

		$active_legacy_single_add_ons = _slicewp_get_active_legacy_single_add_ons();

		if ( empty( $active_legacy_single_add_ons ) ) {
			return;
		}

		$active_add_ons = slicewp_get_option( 'active_add_ons', array() );

		foreach ( $active_legacy_single_add_ons as $add_on_slug ) {

			// Deactivate the legacy add-on.
			deactivate_plugins( 'slicewp-add-on-' . $add_on_slug . '/index.php', true, false );

			// Activate the add-on in pro.
			if ( ! in_array( str_replace( '-', '_', $add_on_slug ), $active_add_ons ) ) {

				$active_add_ons[] = str_replace( '-', '_', $add_on_slug );

			}

		}

		slicewp_update_option( 'active_add_ons', $active_add_ons );

		// Mark that we ran the welcome to new pro version migration.
		if ( ! empty( $_GET['slicewp_is_welcome'] ) ) {

			slicewp_update_option( 'legacy_add_ons_welcome', 1 );

		}

		wp_redirect( add_query_arg( array( 'message' => ( ! empty( $_GET['slicewp_is_welcome'] ) ? 'slicewp_migrate_add_ons_to_pro_welcome_success' : 'slicewp_migrate_add_ons_to_pro_success' ) ), remove_query_arg( array( 'slicewp_action', 'slicewp_token', 'slicewp_is_welcome' ) ) ) );
		exit;

	}


	/**
	 * Deletes the cron jobs from the single add-ons.
	 * 
	 */
	public function delete_legacy_add_ons_cron_jobs() {

		$legacy_add_ons = array(
			'affiliate-coupons',
			'custom-affiliate-fields',
			'custom-affiliate-slug',
			'affiliate-landing-pages',
			'affiliate-leaderboard',
			'affiliate-social-share',
			'product-commission-rates',
			'affiliate-start-id',
			'multi-level-affiliates',
			'lead-commissions',
			'recurring-commissions',
			'lifetime-commissions',
			'store-credit',
			'paypal-payouts',
			'import-export',
			'mailchimp-integration',
			'mailerlite-integration',
			'convertkit-integration',
			'custom-conversion',
			'reports',
			'affiliate-commission-rates',
		);

		foreach ( $legacy_add_ons as $legacy_add_on_slug ) {

			$event = wp_get_scheduled_event( 'check_plugin_updates-slicewp-add-on-' . $legacy_add_on_slug );

			if ( ! $event ) {
				continue;
			}

			wp_clear_scheduled_hook( 'check_plugin_updates-slicewp-add-on-' . $legacy_add_on_slug );

		}

	}


	/**
	 * Verifies if a plugin is installed.
	 * 
	 * @param string $plugin_slug
	 * 
	 * @return bool
	 * 
	 */
	protected function is_plugin_installed( $plugin_slug ) {

		if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}

		$all_plugins = get_plugins();

		if ( ! empty( $all_plugins[ $plugin_slug ] ) ) {
			return true;
		}

		return false;

	}


	/**
	 * Installs the plugin from the given URL.
	 * 
	 * @param string $plugin_zip_url
	 * 
	 * @return bool
	 * 
	 */
	protected function install_plugin( $plugin_zip_url ) {

		if ( ! class_exists( 'Plugin_Upgrader' ) ) {
			include_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
		}
		
		wp_cache_flush();

		$upgrader  = new Plugin_Upgrader( new Automatic_Upgrader_Skin() );
		$installed = $upgrader->install( $plugin_zip_url );

		return ( is_wp_error( $installed ) ? false : true );

	}


	/**
	 * Outputs the styling for the admin notices.
	 * 
	 */
	protected function output_inline_style_admin_notice() {

		?>

			<style>
				.slicewp-admin-notice { position: relative; display: flex; padding: 0 !important; border-left: 0 !important; }
				.slicewp-admin-notice:before { content: ''; display: block; position: absolute; top: -1px; left: 0; bottom: -1px; width: 4px; background: rgba( 248, 79, 141, 1 ); }

				.slicewp-admin-notice-icon-wrapper { background: rgba( 248, 79, 141, 0.05 ); padding: 15px 13px; margin-left: 4px; }
				.slicewp-admin-notice-icon-wrapper img { max-width: 24px; height: auto; }

				.slicewp-admin-notice-content { padding: 15px; }
				.slicewp-admin-notice-content > :first-child { margin-top: 0; }
				.slicewp-admin-notice-content > :last-child { margin-bottom: 0; }

				/* Welcome to new Pro experience */
				.slicewp-admin-notice-welcome-upgrade.slicewp-admin-notice { display: block; border: 1px solid #c3c4c7 !important; }
				.slicewp-admin-notice-welcome-upgrade.slicewp-admin-notice:before { top: -1px; left: -1px; right: -1px; height: 4px; width: auto; }

				.slicewp-admin-notice-welcome-upgrade .slicewp-admin-notice-icon-wrapper { margin-left: 0; }
				.slicewp-admin-notice-welcome-upgrade .slicewp-admin-notice-icon-wrapper img { display: block; max-width: initial; max-height: 30px; margin: 0 auto; }
				
				.slicewp-admin-notice-welcome-upgrade .slicewp-admin-notice-content { padding: 25px; max-width: 600px; margin: 0 auto; }
				
				.slicewp-admin-notice-welcome-upgrade .slicewp-admin-notice-content h3 svg { width: 24px; color: #1abc9c; vertical-align: middle; }
				.slicewp-admin-notice-welcome-upgrade .slicewp-admin-notice-content h3 span { vertical-align: middle; }

				.slicewp-admin-notice-welcome-upgrade .slicewp-step-1,
				.slicewp-admin-notice-welcome-upgrade .slicewp-step-2 { position: relative; }

				.slicewp-admin-notice-welcome-upgrade .slicewp-step-1 { left: 0; }
				.slicewp-admin-notice-welcome-upgrade .slicewp-step-1 .button-secondary { margin-top: 0.5rem; }

				.slicewp-admin-notice-welcome-upgrade .slicewp-step-2 { opacity: 0; left: 30px; }
				.slicewp-admin-notice-welcome-upgrade .slicewp-step-2 .button-primary { vertical-align: middle; margin-top: 0.5rem; }
				.slicewp-admin-notice-welcome-upgrade .slicewp-step-2 .spinner { display: inline-block; float: none; visibility: visible; margin-top: 0.5rem; vertical-align: middle; }

			</style>

		<?php

	}


	/**
	 * Sets the "check license" cron job.
	 * 
	 */
	public function set_cron_job_check_license() {

		if ( wp_get_scheduled_event( 'slicewp_pro_check_license' ) ) {
			return;
		}

		wp_schedule_event( time(), 'daily', 'slicewp_pro_check_license' );

	}


	/**
	 * Executes the "check license" cron job.
	 * 
	 */
	public function execute_cron_job_check_license() {

		$license_key = get_option( 'slicewp_license_key', '' );

		if ( empty( $license_key ) ) {
			return;
		}

		// Check license against our server.
		$response = wp_remote_get( add_query_arg( array( 'edde_api_action' => 'check_license', 'license_key' => sanitize_text_field( $license_key ) ), 'https://slicewp.com/' ), array( 'timeout' => 30, 'sslverify' => false, 'headers' => array( 'Cache-Control' => 'no-cache' ) ) );

		// If the connection isn't successfull, return.
		if ( is_wp_error( $response ) ) {
			return;
		}

		// Get the response's body.
		$body = json_decode( wp_remote_retrieve_body( $response ), true );

		// If the license could not be validated, return.
		if ( ! empty( $body['error'] ) ) {
			return;
		}

		$body = (array)$body;

		// Add the last updated timestamp.
		$body['last_updated'] = date( 'Y-m-d H:i:s' );

		// Save license key data.
		update_option( 'slicewp_license_key_data', $body );

	}


	/**
	 * Initialize plugin update checker.
	 *
	 */
	public function load_plugin_update_checker() {

		if ( ! class_exists( 'SliceWP_PluginUpdateChecker' ) ) {
            return;
        }

		$license_key = get_option( 'slicewp_license_key' );

		if ( empty( $license_key ) ) {
            return;
        }

		$update_checker = new SliceWP_PluginUpdateChecker( add_query_arg( array( 'edde_api_action' => 'get_version', 'product_id' => 4023, 'license_key' => $license_key, 'url' => get_site_url() ), 'https://slicewp.com/' ), __FILE__, 'slicewp-pro' );

	}

}

new SliceWP_Pro;